package com.ejie.y38a.control;

import com.ejie.x38.control.exception.ControlException;
import com.ejie.x38.control.exception.MethodFailureException;
import com.ejie.x38.control.exception.ResourceNotFoundException;
import com.ejie.x38.control.exception.ServiceUnavailableException;
import com.ejie.x38.dto.JQGridJSONModel;
import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.ObjectConversionManager;
import com.ejie.y38a.service.EstasectService;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.y38a.model.Estasect;

/**
 * * EstasectController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/estasect")
public class EstasectController {

	private static final Logger logger = LoggerFactory
			.getLogger(EstasectController.class);

	@Autowired
	private EstasectService estasectService;

	@Autowired
	private Properties appConfiguration;

	/**
	 * Method 'getCreateForm'.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "maint", method = RequestMethod.GET)
	public ModelAndView getCreateForm(Model model) {
		model.addAttribute("defaultLanguage",
				appConfiguration.get("y38aAppWar.default.language"));
		model.addAttribute("defaultLayout",
				appConfiguration.get("y38aAppWar.default.layout"));
		return new ModelAndView("estasect", "model", model);
	}

	/**
	 * Method 'getById'.
	 * 
	 * @param eacodigo
	 *            String
	 * @return String
	 */
	@RequestMapping(value = "/{eacodigo}", method = RequestMethod.GET)
	public @ResponseBody
	Estasect getById(@PathVariable String eacodigo) {
		try {
			Estasect estasect = new Estasect();
			estasect.setEacodigo(eacodigo);
			estasect = this.estasectService.find(estasect);
			if (estasect == null) {
				throw new Exception(eacodigo.toString());
			}
			return estasect;
		} catch (Exception e) {
			throw new ResourceNotFoundException(eacodigo.toString());
		}
	}

	/**
	 * Method 'getAll'.
	 * 
	 * @param eacodigo
	 *            String
	 * @param eacoes
	 *            String
	 * @param eacoav
	 *            String
	 * @param eacose
	 *            String
	 * @param eainprse
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody
	Object getAll(
			@RequestParam(value = "eacodigo", required = false) String eacodigo,
			@RequestParam(value = "eacoes", required = false) String eacoes,
			@RequestParam(value = "eacoav", required = false) String eacoav,
			@RequestParam(value = "eacose", required = false) String eacose,
			@RequestParam(value = "eainprse", required = false) String eainprse,
			HttpServletRequest request) {
		try {
			Estasect filterEstasect = new Estasect(eacodigo, eacoes, eacoav,
					eacose, eainprse);
			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null
					&& request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));
				List<Estasect> estasects = this.estasectService.findAll(
						filterEstasect, pagination);

				if (estasects == null) {
					throw new Exception("No data Found.");
				}

				Long total = getAllCount(filterEstasect, request);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(estasects);
				return data;
			} else {
				List<Estasect> estasects = this.estasectService.findAll(
						filterEstasect, pagination);
				if (estasects == null) {
					throw new Exception("No data Found.");
				}
				return estasects;
			}
		} catch (Exception e) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	/**
	 * Method 'getAllCount'.
	 * 
	 * @param filterEstasect
	 *            Estasect
	 * @param request
	 *            HttpServletRequest
	 * @return Long
	 */
	@RequestMapping(value = "/count", method = RequestMethod.GET)
	public @ResponseBody
	Long getAllCount(
			@RequestParam(value = "estasect", required = false) Estasect filterEstasect,
			HttpServletRequest request) {
		try {
			return estasectService
					.findAllCount(filterEstasect != null ? filterEstasect
							: new Estasect());
		} catch (Exception e) {
			throw new ServiceUnavailableException(
					"Count Service is not responding.");
		}
	}

	/**
	 * Method 'edit'.
	 * 
	 * @param estasect
	 *            Estasect
	 * @param response
	 *            HttpServletResponse
	 * @return Estasect
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody
	Estasect edit(@RequestBody Estasect estasect, HttpServletResponse response) {
		try {
			Estasect estasectAux = this.estasectService.update(estasect);
			logger.info("Entity correctly inserted!");
			return estasectAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'add'.
	 * 
	 * @param estasect
	 *            Estasect
	 * @return Estasect
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody
	Estasect add(@RequestBody Estasect estasect) {
		try {
			Estasect estasectAux = this.estasectService.add(estasect);
			logger.info("Entity correctly inserted!");
			return estasectAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'remove'.
	 * 
	 * @param eacodigo
	 *            String
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/{eacodigo}", method = RequestMethod.DELETE)
	public void remove(@PathVariable String eacodigo,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		try {
			Estasect estasect = new Estasect();
			estasect.setEacodigo(eacodigo);
			this.estasectService.remove(estasect);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			logger.error("Unable to delete " + eacodigo);
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'removeAll'.
	 * 
	 * @param estasectIds
	 *            ArrayList
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	public void removeMultiple(
			@RequestBody ArrayList<ArrayList<String>> estasectIds,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		ArrayList<Estasect> estasectList = new ArrayList<Estasect>();
		try {
			for (ArrayList<String> estasectId : estasectIds) {
				Iterator<String> iterator = estasectId.iterator();
				Estasect estasect = new Estasect();// NOPMD 2012/05/09 (JC)
				estasect.setEacodigo(ObjectConversionManager.convert(
						iterator.next(), String.class));
				estasectList.add(estasect);
			}
			this.estasectService.removeMultiple(estasectList);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'handle'.
	 * 
	 * @param e
	 *            ControlException
	 * @return String
	 */
	@ExceptionHandler
	public @ResponseBody
	String handle(ControlException e) {
		logger.warn(e.getMessage());
		return e.getMessage();
	}

	/**
	 * Method 'getEstasectService'.
	 * 
	 * @return EstasectService
	 */
	protected EstasectService getEstasectService() {
		return this.estasectService;
	}

	/**
	 * Method 'setEstasectService'.
	 * 
	 * @param estasectService
	 *            EstasectService
	 * @return
	 */
	public void setEstasectService(EstasectService estasectService) {
		this.estasectService = estasectService;
	}

	/**
	 * Method 'getAppConfiguration'.
	 * 
	 * @return appConfiguration
	 */
	public Properties getAppConfiguration() {
		return appConfiguration;
	}

	/**
	 * Method 'setAppConfiguration'.
	 * 
	 * @param appConfiguration
	 *            Properties
	 * @return
	 */
	public void setAppConfiguration(Properties appConfiguration) {
		this.appConfiguration = appConfiguration;
	}
}
