package com.ejie.y38a.control;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.x38.control.exception.ControlException;
import com.ejie.x38.control.exception.MethodFailureException;
import com.ejie.x38.control.exception.ResourceNotFoundException;
import com.ejie.x38.control.exception.ServiceUnavailableException;
import com.ejie.x38.dto.JQGridJSONModel;
import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.ObjectConversionManager;
import com.ejie.y38a.model.Localida;
import com.ejie.y38a.service.LocalidaService;

/**
 * * LocalidaController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/localida")
public class LocalidaController {

	private static final Logger logger = LoggerFactory
			.getLogger(LocalidaController.class);

	@Autowired
	private LocalidaService localidaService;

	@Autowired
	private Properties appConfiguration;

	/**
	 * Method 'getCreateForm'.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "maint", method = RequestMethod.GET)
	public ModelAndView getCreateForm(Model model) {
		model.addAttribute("defaultLanguage",
				appConfiguration.get("y38aAppWar.default.language"));
		model.addAttribute("defaultLayout",
				appConfiguration.get("y38aAppWar.default.layout"));
		return new ModelAndView("localida", "model", model);
	}

	/**
	 * Method 'getById'.
	 * 
	 * @param locodigo
	 *            String
	 * @return String
	 */
	@RequestMapping(value = "/{locodigo}", method = RequestMethod.GET)
	public @ResponseBody
	Localida getById(@PathVariable String locodigo) {
		try {
			Localida localida = new Localida();
			localida.setLocodigo(locodigo);
			localida = this.localidaService.find(localida);
			if (localida == null) {
				throw new Exception(locodigo.toString());
			}
			return localida;
		} catch (Exception e) {
			throw new ResourceNotFoundException(locodigo.toString());
		}
	}

	/**
	 * Method 'getAll'.
	 * 
	 * @param locodigo
	 *            String
	 * @param codlocalid
	 *            String
	 * @param locopv
	 *            String
	 * @param locomu
	 *            String
	 * @param locopa
	 *            String
	 * @param lonombre
	 *            String
	 * @param lonrcopo
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody
	Object getAll(
			@RequestParam(value = "locodigo", required = false) String locodigo,
			@RequestParam(value = "codlocalid", required = false) String codlocalid,
			@RequestParam(value = "locopv", required = false) String locopv,
			@RequestParam(value = "locomu", required = false) String locomu,
			@RequestParam(value = "locopa", required = false) String locopa,
			@RequestParam(value = "lonombre", required = false) String lonombre,
			@RequestParam(value = "lonrcopo", required = false) String lonrcopo,
			HttpServletRequest request) {
		try {
			Localida filterLocalida = new Localida(locodigo, codlocalid,
					locopv, locomu, locopa, lonombre, lonrcopo);
			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null
					&& request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));
				List<Localida> localidas = this.localidaService.findAll(
						filterLocalida, pagination);

				if (localidas == null) {
					throw new Exception("No data Found.");
				}

				Long total = getAllCount(filterLocalida, request);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(localidas);
				return data;
			} else {
				List<Localida> localidas = this.localidaService.findAll(
						filterLocalida, pagination);
				if (localidas == null) {
					throw new Exception("No data Found.");
				}
				return localidas;
			}
		} catch (Exception e) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	/**
	 * Method 'getAllCount'.
	 * 
	 * @param filterLocalida
	 *            Localida
	 * @param request
	 *            HttpServletRequest
	 * @return Long
	 */
	@RequestMapping(value = "/count", method = RequestMethod.GET)
	public @ResponseBody
	Long getAllCount(
			@RequestParam(value = "localida", required = false) Localida filterLocalida,
			HttpServletRequest request) {
		try {
			return localidaService
					.findAllCount(filterLocalida != null ? filterLocalida
							: new Localida());
		} catch (Exception e) {
			throw new ServiceUnavailableException(
					"Count Service is not responding.");
		}
	}

	/**
	 * Method 'edit'.
	 * 
	 * @param localida
	 *            Localida
	 * @param response
	 *            HttpServletResponse
	 * @return Localida
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody
	Localida edit(@RequestBody Localida localida, HttpServletResponse response) {
		try {
			Localida localidaAux = this.localidaService.update(localida);
			logger.info("Entity correctly inserted!");
			return localidaAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'add'.
	 * 
	 * @param localida
	 *            Localida
	 * @return Localida
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody
	Localida add(@RequestBody Localida localida) {
		try {
			Localida localidaAux = this.localidaService.add(localida);
			logger.info("Entity correctly inserted!");
			return localidaAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'remove'.
	 * 
	 * @param locodigo
	 *            String
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/{locodigo}", method = RequestMethod.DELETE)
	public void remove(@PathVariable String locodigo,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		try {
			Localida localida = new Localida();
			localida.setLocodigo(locodigo);
			this.localidaService.remove(localida);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			logger.error("Unable to delete " + locodigo);
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'removeAll'.
	 * 
	 * @param localidaIds
	 *            ArrayList
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	public void removeMultiple(
			@RequestBody ArrayList<ArrayList<String>> localidaIds,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		ArrayList<Localida> localidaList = new ArrayList<Localida>();
		try {
			for (ArrayList<String> localidaId : localidaIds) {
				Iterator<String> iterator = localidaId.iterator();
				Localida localida = new Localida();// NOPMD
				localida.setLocodigo(ObjectConversionManager.convert(
						iterator.next(), String.class));
				localidaList.add(localida);
			}
			this.localidaService.removeMultiple(localidaList);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'handle'.
	 * 
	 * @param e
	 *            ControlException
	 * @return String
	 */
	@ExceptionHandler
	public @ResponseBody
	String handle(ControlException e) {
		logger.warn(e.getMessage());
		return e.getMessage();
	}

	/**
	 * Method 'getLocalidaService'.
	 * 
	 * @return LocalidaService
	 */
	protected LocalidaService getLocalidaService() {
		return this.localidaService;
	}

	/**
	 * Method 'setLocalidaService'.
	 * 
	 * @param localidaService
	 *            LocalidaService
	 * @return
	 */
	public void setLocalidaService(LocalidaService localidaService) {
		this.localidaService = localidaService;
	}

	/**
	 * Method 'getAppConfiguration'.
	 * 
	 * @return appConfiguration
	 */
	public Properties getAppConfiguration() {
		return appConfiguration;
	}

	/**
	 * Method 'setAppConfiguration'.
	 * 
	 * @param appConfiguration
	 *            Properties
	 * @return
	 */
	public void setAppConfiguration(Properties appConfiguration) {
		this.appConfiguration = appConfiguration;
	}
}
