package com.ejie.y38a.control;

import com.ejie.x38.control.exception.ControlException;
import com.ejie.x38.control.exception.MethodFailureException;
import com.ejie.x38.control.exception.ResourceNotFoundException;
import com.ejie.x38.control.exception.ServiceUnavailableException;
import com.ejie.x38.dto.JQGridJSONModel;
import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.ObjectConversionManager;
import com.ejie.y38a.service.MunicipiService;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.y38a.model.Municipi;

/**
 * * MunicipiController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/municipi")
public class MunicipiController {

	private static final Logger logger = LoggerFactory
			.getLogger(MunicipiController.class);

	@Autowired
	private MunicipiService municipiService;

	@Autowired
	private Properties appConfiguration;

	/**
	 * Method 'getCreateForm'.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "maint", method = RequestMethod.GET)
	public ModelAndView getCreateForm(Model model) {
		model.addAttribute("defaultLanguage",
				appConfiguration.get("y38aAppWar.default.language"));
		model.addAttribute("defaultLayout",
				appConfiguration.get("y38aAppWar.default.layout"));
		return new ModelAndView("municipi", "model", model);
	}

	/**
	 * Method 'getById'.
	 * 
	 * @param mucodigo
	 *            String
	 * @return String
	 */
	@RequestMapping(value = "/{mucodigo}", method = RequestMethod.GET)
	public @ResponseBody
	Municipi getById(@PathVariable String mucodigo) {
		try {
			Municipi municipi = new Municipi();
			municipi.setMucodigo(mucodigo);
			municipi = this.municipiService.find(municipi);
			if (municipi == null) {
				throw new Exception(mucodigo.toString());
			}
			return municipi;
		} catch (Exception e) {
			throw new ResourceNotFoundException(mucodigo.toString());
		}
	}

	/**
	 * Method 'getAll'.
	 * 
	 * @param mucodigo
	 *            String
	 * @param munombre
	 *            String
	 * @param mucomu
	 *            String
	 * @param mucopv
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody
	Object getAll(
			@RequestParam(value = "mucodigo", required = false) String mucodigo,
			@RequestParam(value = "munombre", required = false) String munombre,
			@RequestParam(value = "mucomu", required = false) String mucomu,
			@RequestParam(value = "mucopv", required = false) String mucopv,
			HttpServletRequest request) {
		try {
			Municipi filterMunicipi = new Municipi(mucodigo, munombre, mucomu,
					mucopv);
			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null
					&& request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));
				List<Municipi> municipis = this.municipiService.findAll(
						filterMunicipi, pagination);

				if (municipis == null) {
					throw new Exception("No data Found.");
				}

				Long total = getAllCount(filterMunicipi, request);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(municipis);
				return data;
			} else {
				List<Municipi> municipis = this.municipiService.findAll(
						filterMunicipi, pagination);
				if (municipis == null) {
					throw new Exception("No data Found.");
				}
				return municipis;
			}
		} catch (Exception e) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	/**
	 * Method 'getAllMunicipios'.
	 * 
	 * @param mucodigo
	 *            String
	 * @param munombre
	 *            String
	 * @param mucomu
	 *            String
	 * @param mucopv
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(value = "/list", method = RequestMethod.GET)
	public @ResponseBody
	Object getAllMunicipios(
			@RequestParam(value = "mucodigo", required = false) String mucodigo,
			@RequestParam(value = "munombre", required = false) String munombre,
			@RequestParam(value = "mucomu", required = false) String mucomu,
			@RequestParam(value = "mucopv", required = false) String mucopv,
			HttpServletRequest request) {
		try {
			Municipi filterMunicipi = new Municipi(mucodigo, munombre, mucomu,
					mucopv);
			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null
					&& request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));
				List<Municipi> municipis = this.municipiService.findAll(
						filterMunicipi, pagination);

				if (municipis == null) {
					throw new Exception("No data Found.");
				}

				Long total = getAllCount(filterMunicipi, request);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(municipis);
				return data;
			} else {
				List<Municipi> municipis = this.municipiService.findAll(
						filterMunicipi, pagination);
				if (municipis == null) {
					throw new Exception("No data Found.");
				}
				return municipis;
			}
		} catch (Exception e) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	/**
	 * Method 'getAllCount'.
	 * 
	 * @param filterMunicipi
	 *            Municipi
	 * @param request
	 *            HttpServletRequest
	 * @return Long
	 */
	@RequestMapping(value = "/count", method = RequestMethod.GET)
	public @ResponseBody
	Long getAllCount(
			@RequestParam(value = "municipi", required = false) Municipi filterMunicipi,
			HttpServletRequest request) {
		try {
			return municipiService
					.findAllCount(filterMunicipi != null ? filterMunicipi
							: new Municipi());
		} catch (Exception e) {
			throw new ServiceUnavailableException(
					"Count Service is not responding.");
		}
	}

	/**
	 * Method 'edit'.
	 * 
	 * @param municipi
	 *            Municipi
	 * @param response
	 *            HttpServletResponse
	 * @return Municipi
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody
	Municipi edit(@RequestBody Municipi municipi, HttpServletResponse response) {
		try {
			Municipi municipiAux = this.municipiService.update(municipi);
			logger.info("Entity correctly inserted!");
			return municipiAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'add'.
	 * 
	 * @param municipi
	 *            Municipi
	 * @return Municipi
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody
	Municipi add(@RequestBody Municipi municipi) {
		try {
			Municipi municipiAux = this.municipiService.add(municipi);
			logger.info("Entity correctly inserted!");
			return municipiAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'remove'.
	 * 
	 * @param mucodigo
	 *            String
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/{mucodigo}", method = RequestMethod.DELETE)
	public void remove(@PathVariable String mucodigo,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		try {
			Municipi municipi = new Municipi();
			municipi.setMucodigo(mucodigo);
			this.municipiService.remove(municipi);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			logger.error("Unable to delete " + mucodigo);
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'removeAll'.
	 * 
	 * @param municipiIds
	 *            ArrayList
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	public void removeMultiple(
			@RequestBody ArrayList<ArrayList<String>> municipiIds,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		ArrayList<Municipi> municipiList = new ArrayList<Municipi>();
		try {
			for (ArrayList<String> municipiId : municipiIds) {
				Iterator<String> iterator = municipiId.iterator();
				Municipi municipi = new Municipi();// NOPMD 2012/05/09 (JC)
				municipi.setMucodigo(ObjectConversionManager.convert(
						iterator.next(), String.class));
				municipiList.add(municipi);
			}
			this.municipiService.removeMultiple(municipiList);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'handle'.
	 * 
	 * @param e
	 *            ControlException
	 * @return String
	 */
	@ExceptionHandler
	public @ResponseBody
	String handle(ControlException e) {
		logger.warn(e.getMessage());
		return e.getMessage();
	}

	/**
	 * Method 'getMunicipiService'.
	 * 
	 * @return MunicipiService
	 */
	protected MunicipiService getMunicipiService() {
		return this.municipiService;
	}

	/**
	 * Method 'setMunicipiService'.
	 * 
	 * @param municipiService
	 *            MunicipiService
	 * @return
	 */
	public void setMunicipiService(MunicipiService municipiService) {
		this.municipiService = municipiService;
	}

	/**
	 * Method 'getAppConfiguration'.
	 * 
	 * @return appConfiguration
	 */
	public Properties getAppConfiguration() {
		return appConfiguration;
	}

	/**
	 * Method 'setAppConfiguration'.
	 * 
	 * @param appConfiguration
	 *            Properties
	 * @return
	 */
	public void setAppConfiguration(Properties appConfiguration) {
		this.appConfiguration = appConfiguration;
	}
}
