package com.ejie.y38a.control;

import com.ejie.x38.control.exception.ControlException;
import com.ejie.x38.control.exception.MethodFailureException;
import com.ejie.x38.control.exception.ResourceNotFoundException;
import com.ejie.x38.control.exception.ServiceUnavailableException;
import com.ejie.x38.dto.JQGridJSONModel;
import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.ObjectConversionManager;
import com.ejie.y38a.service.PaisestoService;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.y38a.model.Paisesto;

/**
 * * PaisestoController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/paisesto")
public class PaisestoController {

	private static final Logger logger = LoggerFactory
			.getLogger(PaisestoController.class);

	@Autowired
	private PaisestoService paisestoService;

	@Autowired
	private Properties appConfiguration;

	/**
	 * Method 'getCreateForm'.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "maint", method = RequestMethod.GET)
	public ModelAndView getCreateForm(Model model) {
		model.addAttribute("defaultLanguage",
				appConfiguration.get("y38aAppWar.default.language"));
		model.addAttribute("defaultLayout",
				appConfiguration.get("y38aAppWar.default.layout"));
		return new ModelAndView("paisesto", "model", model);
	}

	/**
	 * Method 'getById'.
	 * 
	 * @param pacodigo
	 *            String
	 * @return String
	 */
	@RequestMapping(value = "/{pacodigo}", method = RequestMethod.GET)
	public @ResponseBody
	Paisesto getById(@PathVariable String pacodigo) {
		try {
			Paisesto paisesto = new Paisesto();
			paisesto.setPacodigo(pacodigo);
			paisesto = this.paisestoService.find(paisesto);
			if (paisesto == null) {
				throw new Exception(pacodigo.toString());
			}
			return paisesto;
		} catch (Exception e) {
			throw new ResourceNotFoundException(pacodigo.toString());
		}
	}

	/**
	 * Method 'getAll'.
	 * 
	 * @param pacodigo
	 *            String
	 * @param pacoal2
	 *            String
	 * @param pacoal3
	 *            String
	 * @param panombre
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody
	Object getAll(
			@RequestParam(value = "pacodigo", required = false) String pacodigo,
			@RequestParam(value = "pacoal2", required = false) String pacoal2,
			@RequestParam(value = "pacoal3", required = false) String pacoal3,
			@RequestParam(value = "panombre", required = false) String panombre,
			HttpServletRequest request) {
		try {
			Paisesto filterPaisesto = new Paisesto(pacodigo, pacoal2, pacoal3,
					panombre);
			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null
					&& request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));
				List<Paisesto> paisestos = this.paisestoService.findAll(
						filterPaisesto, pagination);

				if (paisestos == null) {
					throw new Exception("No data Found.");
				}

				Long total = getAllCount(filterPaisesto, request);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(paisestos);
				return data;
			} else {
				List<Paisesto> paisestos = this.paisestoService.findAll(
						filterPaisesto, pagination);
				if (paisestos == null) {
					throw new Exception("No data Found.");
				}
				return paisestos;
			}
		} catch (Exception e) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	/**
	 * Method 'getAllCount'.
	 * 
	 * @param filterPaisesto
	 *            Paisesto
	 * @param request
	 *            HttpServletRequest
	 * @return Long
	 */
	@RequestMapping(value = "/count", method = RequestMethod.GET)
	public @ResponseBody
	Long getAllCount(
			@RequestParam(value = "paisesto", required = false) Paisesto filterPaisesto,
			HttpServletRequest request) {
		try {
			return paisestoService
					.findAllCount(filterPaisesto != null ? filterPaisesto
							: new Paisesto());
		} catch (Exception e) {
			throw new ServiceUnavailableException(
					"Count Service is not responding.");
		}
	}

	/**
	 * Method 'edit'.
	 * 
	 * @param paisesto
	 *            Paisesto
	 * @param response
	 *            HttpServletResponse
	 * @return Paisesto
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody
	Paisesto edit(@RequestBody Paisesto paisesto, HttpServletResponse response) {
		try {
			Paisesto paisestoAux = this.paisestoService.update(paisesto);
			logger.info("Entity correctly inserted!");
			return paisestoAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'add'.
	 * 
	 * @param paisesto
	 *            Paisesto
	 * @return Paisesto
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody
	Paisesto add(@RequestBody Paisesto paisesto) {
		try {
			Paisesto paisestoAux = this.paisestoService.add(paisesto);
			logger.info("Entity correctly inserted!");
			return paisestoAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'remove'.
	 * 
	 * @param pacodigo
	 *            String
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/{pacodigo}", method = RequestMethod.DELETE)
	public void remove(@PathVariable String pacodigo,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		try {
			Paisesto paisesto = new Paisesto();
			paisesto.setPacodigo(pacodigo);
			this.paisestoService.remove(paisesto);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			logger.error("Unable to delete " + pacodigo);
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'removeAll'.
	 * 
	 * @param paisestoIds
	 *            ArrayList
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	public void removeMultiple(
			@RequestBody ArrayList<ArrayList<String>> paisestoIds,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		ArrayList<Paisesto> paisestoList = new ArrayList<Paisesto>();
		try {
			for (ArrayList<String> paisestoId : paisestoIds) {
				Iterator<String> iterator = paisestoId.iterator();
				Paisesto paisesto = new Paisesto();// NOPMD 2012/05/09 (JC)
				paisesto.setPacodigo(ObjectConversionManager.convert(
						iterator.next(), String.class));
				paisestoList.add(paisesto);
			}
			this.paisestoService.removeMultiple(paisestoList);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'handle'.
	 * 
	 * @param e
	 *            ControlException
	 * @return String
	 */
	@ExceptionHandler
	public @ResponseBody
	String handle(ControlException e) {
		logger.warn(e.getMessage());
		return e.getMessage();
	}

	/**
	 * Method 'getPaisestoService'.
	 * 
	 * @return PaisestoService
	 */
	protected PaisestoService getPaisestoService() {
		return this.paisestoService;
	}

	/**
	 * Method 'setPaisestoService'.
	 * 
	 * @param paisestoService
	 *            PaisestoService
	 * @return
	 */
	public void setPaisestoService(PaisestoService paisestoService) {
		this.paisestoService = paisestoService;
	}

	/**
	 * Method 'getAppConfiguration'.
	 * 
	 * @return appConfiguration
	 */
	public Properties getAppConfiguration() {
		return appConfiguration;
	}

	/**
	 * Method 'setAppConfiguration'.
	 * 
	 * @param appConfiguration
	 *            Properties
	 * @return
	 */
	public void setAppConfiguration(Properties appConfiguration) {
		this.appConfiguration = appConfiguration;
	}
}
