package com.ejie.y38a.control;

import com.ejie.x38.control.exception.ControlException;
import com.ejie.x38.control.exception.MethodFailureException;
import com.ejie.x38.control.exception.ResourceNotFoundException;
import com.ejie.x38.control.exception.ServiceUnavailableException;
import com.ejie.x38.dto.JQGridJSONModel;
import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.ObjectConversionManager;
import com.ejie.y38a.service.ProvinciService;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.y38a.model.Provinci;

/**
 * * ProvinciController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/provinci")
public class ProvinciController {

	private static final Logger logger = LoggerFactory
			.getLogger(ProvinciController.class);

	@Autowired
	private ProvinciService provinciService;

	@Autowired
	private Properties appConfiguration;

	/**
	 * Method 'getCreateForm'.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "maint", method = RequestMethod.GET)
	public ModelAndView getCreateForm(Model model) {
		model.addAttribute("defaultLanguage",
				appConfiguration.get("y38aAppWar.default.language"));
		model.addAttribute("defaultLayout",
				appConfiguration.get("y38aAppWar.default.layout"));
		return new ModelAndView("provinci", "model", model);
	}

	/**
	 * Method 'getById'.
	 * 
	 * @param pvcodigo
	 *            String
	 * @return String
	 */
	@RequestMapping(value = "/{pvcodigo}", method = RequestMethod.GET)
	public @ResponseBody
	Provinci getById(@PathVariable String pvcodigo) {
		try {
			Provinci provinci = new Provinci();
			provinci.setPvcodigo(pvcodigo);
			provinci = this.provinciService.find(provinci);
			if (provinci == null) {
				throw new Exception(pvcodigo.toString());
			}
			return provinci;
		} catch (Exception e) {
			throw new ResourceNotFoundException(pvcodigo.toString());
		}
	}

	/**
	 * Method 'getAll'.
	 * 
	 * @param pvcodigo
	 *            String
	 * @param pvnombre
	 *            String
	 * @param pvcoca
	 *            String
	 * @param pvcoma
	 *            String
	 * @param pvnrprte
	 *            String
	 * @param pvnoca
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody
	Object getAll(
			@RequestParam(value = "pvcodigo", required = false) String pvcodigo,
			@RequestParam(value = "pvnombre", required = false) String pvnombre,
			@RequestParam(value = "pvcoca", required = false) String pvcoca,
			@RequestParam(value = "pvcoma", required = false) String pvcoma,
			@RequestParam(value = "pvnrprte", required = false) String pvnrprte,
			@RequestParam(value = "pvnoca", required = false) String pvnoca,
			HttpServletRequest request) {
		try {
			Provinci filterProvinci = new Provinci(pvcodigo, pvnombre, pvcoca,
					pvcoma, pvnrprte, pvnoca);
			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null
					&& request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));
				List<Provinci> provincis = this.provinciService.findAll(
						filterProvinci, pagination);

				if (provincis == null) {
					throw new Exception("No data Found.");
				}

				Long total = getAllCount(filterProvinci, request);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(provincis);
				return data;
			} else {
				List<Provinci> provincis = this.provinciService.findAll(
						filterProvinci, pagination);
				if (provincis == null) {
					throw new Exception("No data Found.");
				}
				return provincis;
			}
		} catch (Exception e) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	/**
	 * Method 'getAllCount'.
	 * 
	 * @param filterProvinci
	 *            Provinci
	 * @param request
	 *            HttpServletRequest
	 * @return Long
	 */
	@RequestMapping(value = "/count", method = RequestMethod.GET)
	public @ResponseBody
	Long getAllCount(
			@RequestParam(value = "provinci", required = false) Provinci filterProvinci,
			HttpServletRequest request) {
		try {
			return provinciService
					.findAllCount(filterProvinci != null ? filterProvinci
							: new Provinci());
		} catch (Exception e) {
			throw new ServiceUnavailableException(
					"Count Service is not responding.");
		}
	}

	/**
	 * Method 'edit'.
	 * 
	 * @param provinci
	 *            Provinci
	 * @param response
	 *            HttpServletResponse
	 * @return Provinci
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody
	Provinci edit(@RequestBody Provinci provinci, HttpServletResponse response) {
		try {
			Provinci provinciAux = this.provinciService.update(provinci);
			logger.info("Entity correctly inserted!");
			return provinciAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'add'.
	 * 
	 * @param provinci
	 *            Provinci
	 * @return Provinci
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody
	Provinci add(@RequestBody Provinci provinci) {
		try {
			Provinci provinciAux = this.provinciService.add(provinci);
			logger.info("Entity correctly inserted!");
			return provinciAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'remove'.
	 * 
	 * @param pvcodigo
	 *            String
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/{pvcodigo}", method = RequestMethod.DELETE)
	public void remove(@PathVariable String pvcodigo,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		try {
			Provinci provinci = new Provinci();
			provinci.setPvcodigo(pvcodigo);
			this.provinciService.remove(provinci);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			logger.error("Unable to delete " + pvcodigo);
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'removeAll'.
	 * 
	 * @param provinciIds
	 *            ArrayList
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	public void removeMultiple(
			@RequestBody ArrayList<ArrayList<String>> provinciIds,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		ArrayList<Provinci> provinciList = new ArrayList<Provinci>();
		try {
			for (ArrayList<String> provinciId : provinciIds) {
				Iterator<String> iterator = provinciId.iterator();
				Provinci provinci = new Provinci();// NOPMD 2012/05/09 (JC)
				provinci.setPvcodigo(ObjectConversionManager.convert(
						iterator.next(), String.class));
				provinciList.add(provinci);
			}
			this.provinciService.removeMultiple(provinciList);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'handle'.
	 * 
	 * @param e
	 *            ControlException
	 * @return String
	 */
	@ExceptionHandler
	public @ResponseBody
	String handle(ControlException e) {
		logger.warn(e.getMessage());
		return e.getMessage();
	}

	/**
	 * Method 'getProvinciService'.
	 * 
	 * @return ProvinciService
	 */
	protected ProvinciService getProvinciService() {
		return this.provinciService;
	}

	/**
	 * Method 'setProvinciService'.
	 * 
	 * @param provinciService
	 *            ProvinciService
	 * @return
	 */
	public void setProvinciService(ProvinciService provinciService) {
		this.provinciService = provinciService;
	}

	/**
	 * Method 'getAppConfiguration'.
	 * 
	 * @return appConfiguration
	 */
	public Properties getAppConfiguration() {
		return appConfiguration;
	}

	/**
	 * Method 'setAppConfiguration'.
	 * 
	 * @param appConfiguration
	 *            Properties
	 * @return
	 */
	public void setAppConfiguration(Properties appConfiguration) {
		this.appConfiguration = appConfiguration;
	}
}
