package com.ejie.y38a.control;

import com.ejie.x38.control.exception.ControlException;
import com.ejie.x38.control.exception.MethodFailureException;
import com.ejie.x38.control.exception.ResourceNotFoundException;
import com.ejie.x38.control.exception.ServiceUnavailableException;
import com.ejie.x38.dto.JQGridJSONModel;
import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.ObjectConversionManager;
import com.ejie.y38a.service.SecagrupService;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.y38a.model.Secagrup;

/**
 * * SecagrupController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/secagrup")
public class SecagrupController {

	private static final Logger logger = LoggerFactory
			.getLogger(SecagrupController.class);

	@Autowired
	private SecagrupService secagrupService;

	@Autowired
	private Properties appConfiguration;

	/**
	 * Method 'getCreateForm'.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "maint", method = RequestMethod.GET)
	public ModelAndView getCreateForm(Model model) {
		model.addAttribute("defaultLanguage",
				appConfiguration.get("y38aAppWar.default.language"));
		model.addAttribute("defaultLayout",
				appConfiguration.get("y38aAppWar.default.layout"));
		return new ModelAndView("secagrup", "model", model);
	}

	/**
	 * Method 'getById'.
	 * 
	 * @param l0codigo
	 *            String
	 * @return String
	 */
	@RequestMapping(value = "/{l0codigo}", method = RequestMethod.GET)
	public @ResponseBody
	Secagrup getById(@PathVariable String l0codigo) {
		try {
			Secagrup secagrup = new Secagrup();
			secagrup.setL0codigo(l0codigo);
			secagrup = this.secagrupService.find(secagrup);
			if (secagrup == null) {
				throw new Exception(l0codigo.toString());
			}
			return secagrup;
		} catch (Exception e) {
			throw new ResourceNotFoundException(l0codigo.toString());
		}
	}

	/**
	 * Method 'getAll'.
	 * 
	 * @param l0codigo
	 *            String
	 * @param l0nombre
	 *            String
	 * @param l0nombree
	 *            String
	 * @param l0nombrei
	 *            String
	 * @param l0nombref
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody
	Object getAll(
			@RequestParam(value = "l0codigo", required = false) String l0codigo,
			@RequestParam(value = "l0nombre", required = false) String l0nombre,
			@RequestParam(value = "l0nombree", required = false) String l0nombree,
			@RequestParam(value = "l0nombrei", required = false) String l0nombrei,
			@RequestParam(value = "l0nombref", required = false) String l0nombref,
			HttpServletRequest request) {
		try {
			Secagrup filterSecagrup = new Secagrup(l0codigo, l0nombre,
					l0nombree, l0nombrei, l0nombref);
			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null
					&& request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));
				List<Secagrup> secagrups = this.secagrupService.findAll(
						filterSecagrup, pagination);

				if (secagrups == null) {
					throw new Exception("No data Found.");
				}

				Long total = getAllCount(filterSecagrup, request);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(secagrups);
				return data;
			} else {
				List<Secagrup> secagrups = this.secagrupService.findAll(
						filterSecagrup, pagination);
				if (secagrups == null) {
					throw new Exception("No data Found.");
				}
				return secagrups;
			}
		} catch (Exception e) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	/**
	 * Method 'getAll'.
	 * 
	 * @param l0codigo
	 *            String
	 * @param l0nombre
	 *            String
	 * @param l0nombree
	 *            String
	 * @param l0nombrei
	 *            String
	 * @param l0nombref
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(value = "/list", method = RequestMethod.GET)
	public @ResponseBody
	Object getAllSectoresAgrupados(
			@RequestParam(value = "l0codigo", required = false) String l0codigo_,
			@RequestParam(value = "l0nombre", required = false) String l0nombre_,
			@RequestParam(value = "l0nombree", required = false) String l0nombree,
			@RequestParam(value = "l0nombrei", required = false) String l0nombrei,
			@RequestParam(value = "l0nombref", required = false) String l0nombref,
			HttpServletRequest request) {
		try {

			// formateador para realizar las busquedas en sectores
			String l0codigo = ("".equals(l0codigo_)) ? null : l0codigo_;
			String l0nombre = ("".equals(l0nombre_)) ? null : l0nombre_;

			Secagrup filterSecagrup = new Secagrup(l0codigo, l0nombre,
					l0nombree, l0nombrei, l0nombref);
			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null
					&& request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));
				List<Secagrup> secagrups = this.secagrupService.findAll(
						filterSecagrup, pagination);

				if (secagrups == null) {
					throw new Exception("No data Found.");
				}

				Long total = getAllCount(filterSecagrup, request);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(secagrups);
				return data;
			} else {
				List<Secagrup> secagrups = this.secagrupService.findAll(
						filterSecagrup, pagination);
				if (secagrups == null) {
					throw new Exception("No data Found.");
				}
				return secagrups;
			}
		} catch (Exception e) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	/**
	 * Method 'getAllCount'.
	 * 
	 * @param filterSecagrup
	 *            Secagrup
	 * @param request
	 *            HttpServletRequest
	 * @return Long
	 */
	@RequestMapping(value = "/count", method = RequestMethod.GET)
	public @ResponseBody
	Long getAllCount(
			@RequestParam(value = "secagrup", required = false) Secagrup filterSecagrup,
			HttpServletRequest request) {
		try {
			return secagrupService
					.findAllCount(filterSecagrup != null ? filterSecagrup
							: new Secagrup());
		} catch (Exception e) {
			throw new ServiceUnavailableException(
					"Count Service is not responding.");
		}
	}

	/**
	 * Method 'edit'.
	 * 
	 * @param secagrup
	 *            Secagrup
	 * @param response
	 *            HttpServletResponse
	 * @return Secagrup
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody
	Secagrup edit(@RequestBody Secagrup secagrup, HttpServletResponse response) {
		try {
			Secagrup secagrupAux = this.secagrupService.update(secagrup);
			logger.info("Entity correctly inserted!");
			return secagrupAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'add'.
	 * 
	 * @param secagrup
	 *            Secagrup
	 * @return Secagrup
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody
	Secagrup add(@RequestBody Secagrup secagrup) {
		try {
			Secagrup secagrupAux = this.secagrupService.add(secagrup);
			logger.info("Entity correctly inserted!");
			return secagrupAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'remove'.
	 * 
	 * @param l0codigo
	 *            String
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/{l0codigo}", method = RequestMethod.DELETE)
	public void remove(@PathVariable String l0codigo,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		try {
			Secagrup secagrup = new Secagrup();
			secagrup.setL0codigo(l0codigo);
			this.secagrupService.remove(secagrup);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			logger.error("Unable to delete " + l0codigo);
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'removeAll'.
	 * 
	 * @param secagrupIds
	 *            ArrayList
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	public void removeMultiple(
			@RequestBody ArrayList<ArrayList<String>> secagrupIds,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		ArrayList<Secagrup> secagrupList = new ArrayList<Secagrup>();
		try {
			for (ArrayList<String> secagrupId : secagrupIds) {
				Iterator<String> iterator = secagrupId.iterator();
				Secagrup secagrup = new Secagrup();// NOPMD 2012/05/09 (JC)
				secagrup.setL0codigo(ObjectConversionManager.convert(
						iterator.next(), String.class));
				secagrupList.add(secagrup);
			}
			this.secagrupService.removeMultiple(secagrupList);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'handle'.
	 * 
	 * @param e
	 *            ControlException
	 * @return String
	 */
	@ExceptionHandler
	public @ResponseBody
	String handle(ControlException e) {
		logger.warn(e.getMessage());
		return e.getMessage();
	}

	/**
	 * Method 'getSecagrupService'.
	 * 
	 * @return SecagrupService
	 */
	protected SecagrupService getSecagrupService() {
		return this.secagrupService;
	}

	/**
	 * Method 'setSecagrupService'.
	 * 
	 * @param secagrupService
	 *            SecagrupService
	 * @return
	 */
	public void setSecagrupService(SecagrupService secagrupService) {
		this.secagrupService = secagrupService;
	}

	/**
	 * Method 'getAppConfiguration'.
	 * 
	 * @return appConfiguration
	 */
	public Properties getAppConfiguration() {
		return appConfiguration;
	}

	/**
	 * Method 'setAppConfiguration'.
	 * 
	 * @param appConfiguration
	 *            Properties
	 * @return
	 */
	public void setAppConfiguration(Properties appConfiguration) {
		this.appConfiguration = appConfiguration;
	}
}
