package com.ejie.y38a.control;

import com.ejie.x38.control.exception.ControlException;
import com.ejie.x38.control.exception.MethodFailureException;
import com.ejie.x38.control.exception.ResourceNotFoundException;
import com.ejie.x38.control.exception.ServiceUnavailableException;
import com.ejie.x38.dto.JQGridJSONModel;
import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.ObjectConversionManager;
import com.ejie.y38a.model.Secagrup;
import com.ejie.y38a.service.SectoresService;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.y38a.model.Sectores;

/**
 * * SectoresController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/sectores")
public class SectoresController {

	private static final Logger logger = LoggerFactory
			.getLogger(SectoresController.class);

	@Autowired
	private SectoresService sectoresService;

	@Autowired
	private Properties appConfiguration;

	/**
	 * Method 'getCreateForm'.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "maint", method = RequestMethod.GET)
	public ModelAndView getCreateForm(Model model) {
		model.addAttribute("defaultLanguage",
				appConfiguration.get("y38aAppWar.default.language"));
		model.addAttribute("defaultLayout",
				appConfiguration.get("y38aAppWar.default.layout"));
		return new ModelAndView("sectores", "model", model);
	}

	/**
	 * Method 'getCreateForm'.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "agrupados", method = RequestMethod.GET)
	public ModelAndView getCreateFormSectoresAgrupados(Model model) {
		model.addAttribute("defaultLanguage",
				appConfiguration.get("y38aAppWar.default.language"));
		model.addAttribute("defaultLayout",
				appConfiguration.get("y38aAppWar.default.layout"));
		return new ModelAndView("sectoresAgrupados", "model", model);
	}

	/**
	 * Method 'getById'.
	 * 
	 * @param secodigo
	 *            String
	 * @return String
	 */
	@RequestMapping(value = "/{secodigo}", method = RequestMethod.GET)
	public @ResponseBody
	Sectores getById(@PathVariable String secodigo) {
		try {
			Sectores sectores = new Sectores();
			sectores.setSecodigo(secodigo);
			sectores = this.sectoresService.find(sectores);
			if (sectores == null) {
				throw new Exception(secodigo.toString());
			}
			return sectores;
		} catch (Exception e) {
			throw new ResourceNotFoundException(secodigo.toString());
		}
	}

	/**
	 * Method 'getAll'.
	 * 
	 * @param secodigo
	 *            String
	 * @param secagrupL0codigo
	 *            String
	 * @param senombre
	 *            String
	 * @param senoco
	 *            String
	 * @param sedescri
	 *            String
	 * @param secose
	 *            String
	 * @param senoco2
	 *            String
	 * @param seinsel1
	 *            String
	 * @param senombree
	 *            String
	 * @param senombrei
	 *            String
	 * @param senombref
	 *            String
	 * @param senocoe
	 *            String
	 * @param senocoi
	 *            String
	 * @param senocof
	 *            String
	 * @param sedescrie
	 *            String
	 * @param sedescrii
	 *            String
	 * @param sedescrif
	 *            String
	 * @param senombrea
	 *            String
	 * @param sedescria
	 *            String
	 * @param senocoa
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody
	Object getAll(
			@RequestParam(value = "secodigo", required = false) String secodigo,
			@RequestParam(value = "secagrupL0codigo", required = false) String secagrupL0codigo,
			@RequestParam(value = "senombre", required = false) String senombre,
			@RequestParam(value = "senoco", required = false) String senoco,
			@RequestParam(value = "sedescri", required = false) String sedescri,
			@RequestParam(value = "secose", required = false) String secose,
			@RequestParam(value = "senoco2", required = false) String senoco2,
			@RequestParam(value = "seinsel1", required = false) String seinsel1,
			@RequestParam(value = "senombree", required = false) String senombree,
			@RequestParam(value = "senombrei", required = false) String senombrei,
			@RequestParam(value = "senombref", required = false) String senombref,
			@RequestParam(value = "senocoe", required = false) String senocoe,
			@RequestParam(value = "senocoi", required = false) String senocoi,
			@RequestParam(value = "senocof", required = false) String senocof,
			@RequestParam(value = "sedescrie", required = false) String sedescrie,
			@RequestParam(value = "sedescrii", required = false) String sedescrii,
			@RequestParam(value = "sedescrif", required = false) String sedescrif,
			@RequestParam(value = "senombrea", required = false) String senombrea,
			@RequestParam(value = "sedescria", required = false) String sedescria,
			@RequestParam(value = "senocoa", required = false) String senocoa,
			HttpServletRequest request) {
		try {
			Sectores filterSectores = new Sectores(secodigo, senombre, senoco,
					sedescri, secose, senoco2, seinsel1, senombree, senombrei,
					senombref, senocoe, senocoi, senocof, sedescrie, sedescrii,
					sedescrif, senombrea, sedescria, senocoa, new Secagrup(
							secagrupL0codigo, null, null, null, null, null,
							null), new Secagrup(secagrupL0codigo, null, null,
							null, null, null, null));
			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null
					&& request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));
				List<Sectores> sectoress = this.sectoresService.findAll(
						filterSectores, pagination);

				if (sectoress == null) {
					throw new Exception("No data Found.");
				}

				Long total = getAllCount(filterSectores, request);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(sectoress);
				return data;
			} else {
				List<Sectores> sectoress = this.sectoresService.findAll(
						filterSectores, pagination);
				if (sectoress == null) {
					throw new Exception("No data Found.");
				}
				return sectoress;
			}
		} catch (Exception e) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	// Metodo para mostrar los datos en la tabla

	/**
	 * Method 'getAll'.
	 * 
	 * @param secodigo_
	 *            String
	 * @param secagrupL0codigo
	 *            String
	 * @param senombre_
	 *            String
	 * @param senoco
	 *            String
	 * @param sedescri
	 *            String
	 * @param secose
	 *            String
	 * @param senoco2
	 *            String
	 * @param seinsel1_
	 *            String
	 * @param senombree
	 *            String
	 * @param senombrei
	 *            String
	 * @param senombref
	 *            String
	 * @param senocoe
	 *            String
	 * @param senocoi
	 *            String
	 * @param senocof
	 *            String
	 * @param sedescrie
	 *            String
	 * @param sedescrii
	 *            String
	 * @param sedescrif
	 *            String
	 * @param senombrea
	 *            String
	 * @param sedescria
	 *            String
	 * @param senocoa
	 *            String
	 * @param request
	 *            HttpServletRequest
	 * @return String
	 */
	@RequestMapping(value = "/list", method = RequestMethod.GET)
	public @ResponseBody
	Object getAllSectores(
			@RequestParam(value = "secodigo", required = false) String secodigo_,
			@RequestParam(value = "secagrupL0codigo", required = false) String secagrupL0codigo,
			@RequestParam(value = "senombre", required = false) String senombre_,
			@RequestParam(value = "senoco", required = false) String senoco,
			@RequestParam(value = "sedescri", required = false) String sedescri,
			@RequestParam(value = "secose", required = false) String secose,
			@RequestParam(value = "senoco2", required = false) String senoco2,
			@RequestParam(value = "seinsel1", required = false) String seinsel1_,
			@RequestParam(value = "senombree", required = false) String senombree,
			@RequestParam(value = "senombrei", required = false) String senombrei,
			@RequestParam(value = "senombref", required = false) String senombref,
			@RequestParam(value = "senocoe", required = false) String senocoe,
			@RequestParam(value = "senocoi", required = false) String senocoi,
			@RequestParam(value = "senocof", required = false) String senocof,
			@RequestParam(value = "sedescrie", required = false) String sedescrie,
			@RequestParam(value = "sedescrii", required = false) String sedescrii,
			@RequestParam(value = "sedescrif", required = false) String sedescrif,
			@RequestParam(value = "senombrea", required = false) String senombrea,
			@RequestParam(value = "sedescria", required = false) String sedescria,
			@RequestParam(value = "senocoa", required = false) String senocoa,
			HttpServletRequest request) {
		try {

			// formateador para realizar las busquedas en sectores
			String secodigo = ("".equals(secodigo_)) ? null : secodigo_;
			String senombre = ("".equals(senombre_)) ? null : senombre_;
			String seinsel1 = ("".equals(seinsel1_)) ? null : seinsel1_;

			Sectores filterSectores = new Sectores(secodigo, senombre, senoco,
					sedescri, secose, senoco2, seinsel1, senombree, senombrei,
					senombref, senocoe, senocoi, senocof, sedescrie, sedescrii,
					sedescrif, senombrea, sedescria, senocoa, new Secagrup(
							secagrupL0codigo, null, null, null, null, null,
							null), new Secagrup(secagrupL0codigo, null, null,
							null, null, null, null));
			Pagination pagination = null;
			if (request.getHeader("JQGridModel") != null
					&& request.getHeader("JQGridModel").equals("true")) {
				pagination = new Pagination();
				pagination.setPage(Long.valueOf(request.getParameter("page")));
				pagination.setRows(Long.valueOf(request.getParameter("rows")));
				pagination.setSort(request.getParameter("sidx"));
				pagination.setAscDsc(request.getParameter("sord"));
				List<Sectores> sectoress = this.sectoresService.findAll(
						filterSectores, pagination);

				if (sectoress == null) {
					throw new Exception("No data Found.");
				}

				Long total = getAllCount(filterSectores, request);
				JQGridJSONModel data = new JQGridJSONModel();
				data.setPage(request.getParameter("page"));
				data.setRecords(total.intValue());
				data.setTotal(total, pagination.getRows());
				data.setRows(sectoress);
				return data;
			} else {
				List<Sectores> sectoress = this.sectoresService.findAll(
						filterSectores, pagination);
				if (sectoress == null) {
					throw new Exception("No data Found.");
				}
				return sectoress;
			}
		} catch (Exception e) {
			throw new ResourceNotFoundException("No data Found.");
		}
	}

	/**
	 * Method 'getAllCount'.
	 * 
	 * @param filterSectores
	 *            Sectores
	 * @param request
	 *            HttpServletRequest
	 * @return Long
	 */
	@RequestMapping(value = "/count", method = RequestMethod.GET)
	public @ResponseBody
	Long getAllCount(
			@RequestParam(value = "sectores", required = false) Sectores filterSectores,
			HttpServletRequest request) {
		try {
			return sectoresService
					.findAllCount(filterSectores != null ? filterSectores
							: new Sectores());
		} catch (Exception e) {
			throw new ServiceUnavailableException(
					"Count Service is not responding.");
		}
	}

	/**
	 * Method 'edit'.
	 * 
	 * @param sectores
	 *            Sectores
	 * @param response
	 *            HttpServletResponse
	 * @return Sectores
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody
	Sectores edit(@RequestBody Sectores sectores, HttpServletResponse response) {
		try {
			Sectores sectoresAux = this.sectoresService.update(sectores);
			logger.info("Entity correctly inserted!");
			return sectoresAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'add'.
	 * 
	 * @param sectores
	 *            Sectores
	 * @return Sectores
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody
	Sectores add(@RequestBody Sectores sectores) {
		try {
			Sectores sectoresAux = this.sectoresService.add(sectores);
			logger.info("Entity correctly inserted!");
			return sectoresAux;
		} catch (Exception e) {
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'remove'.
	 * 
	 * @param secodigo
	 *            String
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/{secodigo}", method = RequestMethod.DELETE)
	public void remove(@PathVariable String secodigo,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		try {
			Sectores sectores = new Sectores();
			sectores.setSecodigo(secodigo);
			this.sectoresService.remove(sectores);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			logger.error("Unable to delete " + secodigo);
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'removeAll'.
	 * 
	 * @param sectoresIds
	 *            ArrayList
	 * @param response
	 *            HttpServletResponse
	 * @return
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	public void removeMultiple(
			@RequestBody ArrayList<ArrayList<String>> sectoresIds,
			HttpServletResponse response) {
		response.setContentType("text/javascript;charset=utf-8");
		response.setHeader("Pragma", "cache");
		response.setHeader("Expires", "0");
		response.setHeader("Cache-Control", "private");
		ArrayList<Sectores> sectoresList = new ArrayList<Sectores>();
		try {
			for (ArrayList<String> sectoresId : sectoresIds) {
				Iterator<String> iterator = sectoresId.iterator();
				Sectores sectores = new Sectores();// NOPMD 2012/05/09 (JC)
				sectores.setSecodigo(ObjectConversionManager.convert(
						iterator.next(), String.class));
				sectoresList.add(sectores);
			}
			this.sectoresService.removeMultiple(sectoresList);
			response.setStatus(HttpServletResponse.SC_OK);
		} catch (Exception e) {
			response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
			throw new MethodFailureException("Method failed");
		}
	}

	/**
	 * Method 'handle'.
	 * 
	 * @param e
	 *            ControlException
	 * @return String
	 */
	@ExceptionHandler
	public @ResponseBody
	String handle(ControlException e) {
		logger.warn(e.getMessage());
		return e.getMessage();
	}

	/**
	 * Method 'getSectoresService'.
	 * 
	 * @return SectoresService
	 */
	protected SectoresService getSectoresService() {
		return this.sectoresService;
	}

	/**
	 * Method 'setSectoresService'.
	 * 
	 * @param sectoresService
	 *            SectoresService
	 * @return
	 */
	public void setSectoresService(SectoresService sectoresService) {
		this.sectoresService = sectoresService;
	}

	/**
	 * Method 'getAppConfiguration'.
	 * 
	 * @return appConfiguration
	 */
	public Properties getAppConfiguration() {
		return appConfiguration;
	}

	/**
	 * Method 'setAppConfiguration'.
	 * 
	 * @param appConfiguration
	 *            Properties
	 * @return
	 */
	public void setAppConfiguration(Properties appConfiguration) {
		this.appConfiguration = appConfiguration;
	}
}
