package com.ejie.y38a.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.PaginationManager;
import com.ejie.y38a.constantes.Y38aEstablecAdheConstantes;
import com.ejie.y38a.model.Establec;
import com.ejie.y38a.utils.Y38aUtils;

//import com.ejie.y38a.utils.Y38aUtils;

/**
 * * EstablecDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class EstablecDaoImpl implements EstablecDao {

	private static final Logger logger = LoggerFactory
			.getLogger(EstablecDaoImpl.class);

	private SimpleJdbcTemplate jdbcTemplate;
	private RowMapper<Establec> rwMap = new RowMapper<Establec>() {
		public Establec mapRow(ResultSet resultSet, int rowNum)
				throws SQLException {
			return new Establec(
					resultSet.getString("ESCODIGO"),
					resultSet.getString("ESNOMBRE"),
					resultSet.getString("ESNIF"),
					resultSet.getString("ESNOAN"),
					resultSet.getString("ESNOCO"),
					resultSet.getString("ESNODIR"),
					resultSet.getString("ESCOLO"),
					resultSet.getString("ESNRCOPO"),
					resultSet.getString("ESNRTEL"),
					resultSet.getString("ESNRFAX"),
					resultSet.getString("ESCOPA"),
					resultSet.getString("ESINCAPR"),
					resultSet.getString("ESINDEMP"),
					resultSet.getString("ESTECO"),
					resultSet.getString("ESINADAR"),
					resultSet.getDate("ESFEADAR"),
					resultSet.getString("ESCOEM"),
					resultSet.getString("ESINEMPR"),
					resultSet.getString("ESNRTEL2"),
					resultSet.getDate("ESFEBA"),
					resultSet.getString("ESNOAP1"),
					resultSet.getString("ESNOAP2"),
					resultSet.getString("ESNOLO"),
					resultSet.getString("ESCOMAPV"),
					resultSet.getString("ESCOCA"),
					resultSet.getString("ESNOPECO"),
					resultSet.getString("ESCOIDCO"),
					resultSet.getString("ESINRECO"),
					resultSet.getString("ESCOZS"),
					resultSet.getString("ESFEMOD"),
					resultSet.getString("ESINESCO"),
					resultSet.getString("ESNOMU"),
					resultSet.getString("ESNOREP"),
					resultSet.getString("ESNIFREP"),
					resultSet.getString("DTTEEMR"),
					resultSet.getString("ESCAREP"),
					resultSet.getString("ESTEURL"),
					resultSet.getString("ESCOOE"),
					resultSet.getString("ESNODECO"),
					resultSet.getString("ESINTIAR"),
					resultSet.getDate("ESFEPLAD"),
					resultSet.getString("ESINDEME"),
					null,
					null,
					null,
					// resultSet.getString("LOCALIDADID"),
					// resultSet.getString("MUNICIPIOID"),
					// resultSet.getString("PROVINCIAID"),
					resultSet.getDate("BAJA"),
					resultSet.getString("CODSECTOR"),
					null,
					// resultSet.getString("LOCALIZACION"),
					resultSet.getString("LIMITACIONES"),
					resultSet.getString("ESEXTRANJERO"), null,
					resultSet.getString("ESNORAPAISID"),
					resultSet.getString("ESNORAPAISNOMBRE"),
					resultSet.getString("ESNORAPROVINCIAID"),
					resultSet.getString("ESNOMBREPROVINCIA"),
					resultSet.getString("ESNORAMUNICIPIOID"),
					resultSet.getString("ESNOMBREMUNICIPIO"),
					resultSet.getString("ESNORALOCALIDADID"),
					resultSet.getString("ESNOMBRELOCALIDAD"),
					resultSet.getString("ESNORACALLEID"),
					resultSet.getString("ESNOMBRECALLE"),
					resultSet.getString("ESNORACPID"),
					resultSet.getString("ESNOMBRECP"),
					resultSet.getString("ESNORAPORTALID"),
					resultSet.getString("ESNOMBREPORTAL"),
					resultSet.getString("ESNOMBREPISO"),
					resultSet.getString("ESDIRECCION_NOCAPV"),
					resultSet.getString("AHNRDI"));
		}
	};

	/**
	 * Method use to set the datasource.
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new SimpleJdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the Establec table.
	 * 
	 * @param establec
	 *            Pagination
	 * @return Establec
	 */
	public Establec add(Establec establec) {

		String query = "INSERT INTO ESTABLEC( ESCODIGO,ESNOMBRE,ESNIF,ESNOAN,ESNOCO,ESNODIR,ESCOLO,ESNRCOPO,ESNRTEL,ESNRFAX,ESCOPA,ESINCAPR,ESINDEMP,ESTECO,ESINADAR,ESFEADAR,ESCOEM,ESINEMPR,ESNRTEL2,ESFEBA,ESNOAP1,ESNOAP2,ESNOLO,ESCOMAPV,ESCOCA,ESNOPECO,ESCOIDCO,ESINRECO,ESCOZS,ESFEMOD,ESINESCO,ESNOMU,ESNOREP,ESNIFREP,DTTEEMR,ESCAREP,ESTEURL,ESCOOE,ESNODECO,ESINTIAR,ESFEPLAD,ESINDEME)"
				+ "VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";

		this.jdbcTemplate.update(query, establec.getEscodigo(),
				establec.getEsnombre(), establec.getEsnif(),
				establec.getEsnoan(), establec.getEsnoco(),
				establec.getEsnodir(), establec.getEscolo(),
				establec.getEsnrcopo(), establec.getEsnrtel(),
				establec.getEsnrfax(), establec.getEscopa(),
				establec.getEsincapr(), establec.getEsindemp(),
				establec.getEsteco(), establec.getEsinadar(),
				establec.getEsfeadar(), establec.getEscoem(),
				establec.getEsinempr(), establec.getEsnrtel2(),
				establec.getEsfeba(), establec.getEsnoap1(),
				establec.getEsnoap2(), establec.getEsnolo(),
				establec.getEscomapv(), establec.getEscoca(),
				establec.getEsnopeco(), establec.getEscoidco(),
				establec.getEsinreco(), establec.getEscozs(),
				establec.getEsfemod(), establec.getEsinesco(),
				establec.getEsnomu(), establec.getEsnorep(),
				establec.getEsnifrep(), establec.getDtteemr(),
				establec.getEscarep(), establec.getEsteurl(),
				establec.getEscooe(), establec.getEsnodeco(),
				establec.getEsintiar(), establec.getEsfeplad(),
				establec.getEsindeme());
		return establec;
	}

	/**
	 * Updates a single row in the Establec table.
	 * 
	 * @param establec
	 *            Pagination
	 * @return Establec
	 */
	public Establec update(Establec establec) {
		String query = "UPDATE ESTABLEC SET ESNOMBRE=?,ESNIF=?,ESNOAN=?,ESNOCO=?,ESNODIR=?,ESCOLO=?,ESNRCOPO=?,ESNRTEL=?,ESNRFAX=?,ESCOPA=?,ESINCAPR=?,ESINDEMP=?,ESTECO=?,ESINADAR=?,ESFEADAR=?,ESCOEM=?,ESINEMPR=?,ESNRTEL2=?,ESFEBA=?,ESNOAP1=?,ESNOAP2=?,ESNOLO=?,ESCOMAPV=?,ESCOCA=?,ESNOPECO=?,ESCOIDCO=?,ESINRECO=?,ESCOZS=?,ESFEMOD=?,ESINESCO=?,ESNOMU=?,ESNOREP=?,ESNIFREP=?,DTTEEMR=?,ESCAREP=?,ESTEURL=?,ESCOOE=?,ESNODECO=?,ESINTIAR=?,ESFEPLAD=?,ESINDEME=? WHERE ESCODIGO=?";
		this.jdbcTemplate.update(query, establec.getEsnombre(),
				establec.getEsnif(), establec.getEsnoan(),
				establec.getEsnoco(), establec.getEsnodir(),
				establec.getEscolo(), establec.getEsnrcopo(),
				establec.getEsnrtel(), establec.getEsnrfax(),
				establec.getEscopa(), establec.getEsincapr(),
				establec.getEsindemp(), establec.getEsteco(),
				establec.getEsinadar(), establec.getEsfeadar(),
				establec.getEscoem(), establec.getEsinempr(),
				establec.getEsnrtel2(), establec.getEsfeba(),
				establec.getEsnoap1(), establec.getEsnoap2(),
				establec.getEsnolo(), establec.getEscomapv(),
				establec.getEscoca(), establec.getEsnopeco(),
				establec.getEscoidco(), establec.getEsinreco(),
				establec.getEscozs(), establec.getEsfemod(),
				establec.getEsinesco(), establec.getEsnomu(),
				establec.getEsnorep(), establec.getEsnifrep(),
				establec.getDtteemr(), establec.getEscarep(),
				establec.getEsteurl(), establec.getEscooe(),
				establec.getEsnodeco(), establec.getEsintiar(),
				establec.getEsfeplad(), establec.getEsindeme(),
				establec.getEscodigo());
		return establec;
	}

	/**
	 * Finds a single row in the Establec table.
	 * 
	 * @param establec
	 *            Pagination
	 * @return Establec
	 */
	@Transactional(readOnly = true)
	public Establec findEstablecimiento(Establec establec) {
		String query = "SELECT  AH.AHFEBA BAJA, s.secodigo CODSECTOR,"
				+ "E.ESCODIGO ESCODIGO,E.ESNOMBRE ESNOMBRE,E.ESNIF ESNIF,E.ESNOAN ESNOAN,"
				+ "E.ESNOCO ESNOCO,E.ESNODIR ESNODIR,E.ESCOLO ESCOLO,E.ESNRCOPO ESNRCOPO,E.ESNRTEL ESNRTEL,"
				+ "E.ESNRFAX ESNRFAX,E.ESCOPA ESCOPA,E.ESINCAPR ESINCAPR,E.ESINDEMP ESINDEMP,E.ESTECO ESTECO,"
				+ "E.ESINADAR ESINADAR,E.ESFEADAR ESFEADAR,E.ESCOEM ESCOEM,E.ESINEMPR ESINEMPR,"
				+ "E.ESNRTEL2 ESNRTEL2,E.ESFEBA ESFEBA,E.ESNOAP1 ESNOAP1,E.ESNOAP2 ESNOAP2,"
				+ "E.ESNOLO ESNOLO,E.ESCOMAPV ESCOMAPV,E.ESCOCA ESCOCA,E.ESNOPECO ESNOPECO,E.ESCOIDCO ESCOIDCO,"
				+ "E.ESINRECO ESINRECO,E.ESCOZS ESCOZS,E.ESFEMOD ESFEMOD,E.ESINESCO ESINESCO,E.ESNOMU ESNOMU,"
				+ "E.ESNOREP ESNOREP,E.ESNIFREP ESNIFREP,E.DTTEEMR DTTEEMR,E.ESCAREP ESCAREP,E.ESTEURL ESTEURL,"
				+ "E.ESCOOE ESCOOE,E.ESNODECO ESNODECO,E.ESINTIAR ESINTIAR,E.ESFEPLAD ESFEPLAD,E.ESINDEME ESINDEME,"
				+ "E.ESINDEME LIMITACIONES, E.ESEXTRANJERO ESEXTRANJERO, E.ESNORA_PAIS_ID ESNORAPAISID, E.ESNORA_PAIS_NOMBRE ESNORAPAISNOMBRE, "
				+ "E.ESNORA_PROVINCIA_ID ESNORAPROVINCIAID, E.ESNOMBRE_PROVINCIA ESNOMBREPROVINCIA, "
				+ "E.ESNORA_MUNICIPIO_ID ESNORAMUNICIPIOID, E.ESNOMBRE_MUNICIPIO ESNOMBREMUNICIPIO, "
				+ "E.ESNORA_LOCALIDAD_ID ESNORALOCALIDADID, E.ESNOMBRE_LOCALIDAD ESNOMBRELOCALIDAD, "
				+ "E.ESNORA_CALLE_ID ESNORACALLEID, E.ESNOMBRE_CALLE ESNOMBRECALLE, "
				+ "E.ESNORA_CP_ID ESNORACPID, E.ESNOMBRE_CP ESNOMBRECP, E.ESNORA_PORTAL_ID ESNORAPORTALID, E.ESNOMBRE_PORTAL ESNOMBREPORTAL, "
				+ "E.ESNOMBRE_PISO ESNOMBREPISO, E.ESDIRECCION_NOCAPV ESDIRECCION_NOCAPV, AH.AHNRDI AHNRDI "
				+ "FROM ESTABLEC E, ADHEESTA AH, ESTASECT ES, SECTORES S  "
				+ "WHERE AH.AHCOES = E.ESCODIGO "
				+ "AND E.ESCODIGO = ES.EACOES (+) "
				+ "AND ES.EACOSE = S.SECODIGO (+) " + "AND E.ESCODIGO = ?  ";
		return (Establec) this.jdbcTemplate.queryForObject(query, rwMap,
				establec.getEscodigo());
	}

	/**
	 * Finds a single row in the Establec table.
	 * 
	 * @param establec
	 *            Pagination
	 * @return Establec
	 */
	@Transactional(readOnly = true)
	public Establec find(Establec establec) {
		String query = "SELECT t1.ESCODIGO ESCODIGO, t1.ESNOMBRE ESNOMBRE, t1.ESNIF ESNIF, t1.ESNOAN ESNOAN, t1.ESNOCO ESNOCO, t1.ESNODIR ESNODIR, t1.ESCOLO ESCOLO, t1.ESNRCOPO ESNRCOPO, t1.ESNRTEL ESNRTEL, t1.ESNRFAX ESNRFAX, t1.ESCOPA ESCOPA, t1.ESINCAPR ESINCAPR, t1.ESINDEMP ESINDEMP, t1.ESTECO ESTECO, t1.ESINADAR ESINADAR, t1.ESFEADAR ESFEADAR, t1.ESCOEM ESCOEM, t1.ESINEMPR ESINEMPR, t1.ESNRTEL2 ESNRTEL2, t1.ESFEBA ESFEBA, t1.ESNOAP1 ESNOAP1, t1.ESNOAP2 ESNOAP2, t1.ESNOLO ESNOLO, t1.ESCOMAPV ESCOMAPV, t1.ESCOCA ESCOCA, t1.ESNOPECO ESNOPECO, t1.ESCOIDCO ESCOIDCO, t1.ESINRECO ESINRECO, t1.ESCOZS ESCOZS, t1.ESFEMOD ESFEMOD, t1.ESINESCO ESINESCO, t1.ESNOMU ESNOMU, t1.ESNOREP ESNOREP, t1.ESNIFREP ESNIFREP, t1.DTTEEMR DTTEEMR, t1.ESCAREP ESCAREP, t1.ESTEURL ESTEURL, t1.ESCOOE ESCOOE, t1.ESNODECO ESNODECO, t1.ESINTIAR ESINTIAR, t1.ESFEPLAD ESFEPLAD, t1.ESINDEME ESINDEME "
				+ "FROM ESTABLEC t1  " + "WHERE t1.ESCODIGO = ?    ";
		return (Establec) this.jdbcTemplate.queryForObject(query, rwMap,
				establec.getEscodigo());
	}

	/**
	 * Removes a single row in the Establec table.
	 * 
	 * @param establec
	 *            Pagination
	 * @return
	 */
	public void remove(Establec establec) {
		String query = "DELETE  FROM ESTABLEC WHERE ESCODIGO=?";
		this.jdbcTemplate.update(query, establec.getEscodigo());
	}

	/**
	 * Finds a List of rows in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Establec> findAll(Establec establec, Pagination pagination) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.ESCODIGO ESCODIGO,t1.ESNOMBRE ESNOMBRE,t1.ESNIF ESNIF,t1.ESNOAN ESNOAN,t1.ESNOCO ESNOCO,t1.ESNODIR ESNODIR,t1.ESCOLO ESCOLO,t1.ESNRCOPO ESNRCOPO,t1.ESNRTEL ESNRTEL,t1.ESNRFAX ESNRFAX,t1.ESCOPA ESCOPA,t1.ESINCAPR ESINCAPR,t1.ESINDEMP ESINDEMP,t1.ESTECO ESTECO,t1.ESINADAR ESINADAR,t1.ESFEADAR ESFEADAR,t1.ESCOEM ESCOEM,t1.ESINEMPR ESINEMPR,t1.ESNRTEL2 ESNRTEL2,t1.ESFEBA ESFEBA,t1.ESNOAP1 ESNOAP1,t1.ESNOAP2 ESNOAP2,t1.ESNOLO ESNOLO,t1.ESCOMAPV ESCOMAPV,t1.ESCOCA ESCOCA,t1.ESNOPECO ESNOPECO,t1.ESCOIDCO ESCOIDCO,t1.ESINRECO ESINRECO,t1.ESCOZS ESCOZS,t1.ESFEMOD ESFEMOD,t1.ESINESCO ESINESCO,t1.ESNOMU ESNOMU,t1.ESNOREP ESNOREP,t1.ESNIFREP ESNIFREP,t1.DTTEEMR DTTEEMR,t1.ESCAREP ESCAREP,t1.ESTEURL ESTEURL,t1.ESCOOE ESCOOE,t1.ESNODECO ESNODECO,t1.ESINTIAR ESINTIAR,t1.ESFEPLAD ESFEPLAD,t1.ESINDEME ESINDEME "
						+ "FROM ESTABLEC t1 ");

		if (establec != null && establec.getEscodigo() != null) {
			where.append(" AND t1.ESCODIGO = ?");
			params.add(establec.getEscodigo());
		}
		if (establec != null && establec.getEsnombre() != null) {
			where.append(" AND t1.ESNOMBRE = ?");
			params.add(establec.getEsnombre());
		}
		if (establec != null && establec.getEsnif() != null) {
			where.append(" AND t1.ESNIF = ?");
			params.add(establec.getEsnif());
		}
		if (establec != null && establec.getEsnoan() != null) {
			where.append(" AND t1.ESNOAN = ?");
			params.add(establec.getEsnoan());
		}
		if (establec != null && establec.getEsnoco() != null) {
			where.append(" AND t1.ESNOCO = ?");
			params.add(establec.getEsnoco());
		}
		if (establec != null && establec.getEsnodir() != null) {
			where.append(" AND t1.ESNODIR = ?");
			params.add(establec.getEsnodir());
		}
		if (establec != null && establec.getEscolo() != null) {
			where.append(" AND t1.ESCOLO = ?");
			params.add(establec.getEscolo());
		}
		if (establec != null && establec.getEsnrcopo() != null) {
			where.append(" AND t1.ESNRCOPO = ?");
			params.add(establec.getEsnrcopo());
		}
		if (establec != null && establec.getEsnrtel() != null) {
			where.append(" AND t1.ESNRTEL = ?");
			params.add(establec.getEsnrtel());
		}
		if (establec != null && establec.getEsnrfax() != null) {
			where.append(" AND t1.ESNRFAX = ?");
			params.add(establec.getEsnrfax());
		}
		if (establec != null && establec.getEscopa() != null) {
			where.append(" AND t1.ESCOPA = ?");
			params.add(establec.getEscopa());
		}
		if (establec != null && establec.getEsincapr() != null) {
			where.append(" AND t1.ESINCAPR = ?");
			params.add(establec.getEsincapr());
		}
		if (establec != null && establec.getEsindemp() != null) {
			where.append(" AND t1.ESINDEMP = ?");
			params.add(establec.getEsindemp());
		}
		if (establec != null && establec.getEsteco() != null) {
			where.append(" AND t1.ESTECO = ?");
			params.add(establec.getEsteco());
		}
		if (establec != null && establec.getEsinadar() != null) {
			where.append(" AND t1.ESINADAR = ?");
			params.add(establec.getEsinadar());
		}
		if (establec != null && establec.getEsfeadar() != null) {
			where.append(" AND t1.ESFEADAR = ?");
			params.add(establec.getEsfeadar());
		}
		if (establec != null && establec.getEscoem() != null) {
			where.append(" AND t1.ESCOEM = ?");
			params.add(establec.getEscoem());
		}
		if (establec != null && establec.getEsinempr() != null) {
			where.append(" AND t1.ESINEMPR = ?");
			params.add(establec.getEsinempr());
		}
		if (establec != null && establec.getEsnrtel2() != null) {
			where.append(" AND t1.ESNRTEL2 = ?");
			params.add(establec.getEsnrtel2());
		}
		if (establec != null && establec.getEsfeba() != null) {
			where.append(" AND t1.ESFEBA = ?");
			params.add(establec.getEsfeba());
		}
		if (establec != null && establec.getEsnoap1() != null) {
			where.append(" AND t1.ESNOAP1 = ?");
			params.add(establec.getEsnoap1());
		}
		if (establec != null && establec.getEsnoap2() != null) {
			where.append(" AND t1.ESNOAP2 = ?");
			params.add(establec.getEsnoap2());
		}
		if (establec != null && establec.getEsnolo() != null) {
			where.append(" AND t1.ESNOLO = ?");
			params.add(establec.getEsnolo());
		}
		if (establec != null && establec.getEscomapv() != null) {
			where.append(" AND t1.ESCOMAPV = ?");
			params.add(establec.getEscomapv());
		}
		if (establec != null && establec.getEscoca() != null) {
			where.append(" AND t1.ESCOCA = ?");
			params.add(establec.getEscoca());
		}
		if (establec != null && establec.getEsnopeco() != null) {
			where.append(" AND t1.ESNOPECO = ?");
			params.add(establec.getEsnopeco());
		}
		if (establec != null && establec.getEscoidco() != null) {
			where.append(" AND t1.ESCOIDCO = ?");
			params.add(establec.getEscoidco());
		}
		if (establec != null && establec.getEsinreco() != null) {
			where.append(" AND t1.ESINRECO = ?");
			params.add(establec.getEsinreco());
		}
		if (establec != null && establec.getEscozs() != null) {
			where.append(" AND t1.ESCOZS = ?");
			params.add(establec.getEscozs());
		}
		if (establec != null && establec.getEsfemod() != null) {
			where.append(" AND t1.ESFEMOD = ?");
			params.add(establec.getEsfemod());
		}
		if (establec != null && establec.getEsinesco() != null) {
			where.append(" AND t1.ESINESCO = ?");
			params.add(establec.getEsinesco());
		}
		if (establec != null && establec.getEsnomu() != null) {
			where.append(" AND t1.ESNOMU = ?");
			params.add(establec.getEsnomu());
		}
		if (establec != null && establec.getEsnorep() != null) {
			where.append(" AND t1.ESNOREP = ?");
			params.add(establec.getEsnorep());
		}
		if (establec != null && establec.getEsnifrep() != null) {
			where.append(" AND t1.ESNIFREP = ?");
			params.add(establec.getEsnifrep());
		}
		if (establec != null && establec.getDtteemr() != null) {
			where.append(" AND t1.DTTEEMR = ?");
			params.add(establec.getDtteemr());
		}
		if (establec != null && establec.getEscarep() != null) {
			where.append(" AND t1.ESCAREP = ?");
			params.add(establec.getEscarep());
		}
		if (establec != null && establec.getEsteurl() != null) {
			where.append(" AND t1.ESTEURL = ?");
			params.add(establec.getEsteurl());
		}
		if (establec != null && establec.getEscooe() != null) {
			where.append(" AND t1.ESCOOE = ?");
			params.add(establec.getEscooe());
		}
		if (establec != null && establec.getEsnodeco() != null) {
			where.append(" AND t1.ESNODECO = ?");
			params.add(establec.getEsnodeco());
		}
		if (establec != null && establec.getEsintiar() != null) {
			where.append(" AND t1.ESINTIAR = ?");
			params.add(establec.getEsintiar());
		}
		if (establec != null && establec.getEsfeplad() != null) {
			where.append(" AND t1.ESFEPLAD = ?");
			params.add(establec.getEsfeplad());
		}
		if (establec != null && establec.getEsindeme() != null) {
			where.append(" AND t1.ESINDEME = ?");
			params.add(establec.getEsindeme());
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Establec>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Counts rows in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Establec establec) {

		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1  ");

		StringBuffer query = new StringBuffer(
				"SELECT COUNT(1) FROM  ESTABLEC t1  ");
		if (establec != null && establec.getEscodigo() != null) {
			where.append(" AND t1.ESCODIGO = ?");
			params.add(establec.getEscodigo());
		}
		if (establec != null && establec.getEsnombre() != null) {
			where.append(" AND t1.ESNOMBRE = ?");
			params.add(establec.getEsnombre());
		}
		if (establec != null && establec.getEsnif() != null) {
			where.append(" AND t1.ESNIF = ?");
			params.add(establec.getEsnif());
		}
		if (establec != null && establec.getEsnoan() != null) {
			where.append(" AND t1.ESNOAN = ?");
			params.add(establec.getEsnoan());
		}
		if (establec != null && establec.getEsnoco() != null) {
			where.append(" AND t1.ESNOCO = ?");
			params.add(establec.getEsnoco());
		}
		if (establec != null && establec.getEsnodir() != null) {
			where.append(" AND t1.ESNODIR = ?");
			params.add(establec.getEsnodir());
		}
		if (establec != null && establec.getEscolo() != null) {
			where.append(" AND t1.ESCOLO = ?");
			params.add(establec.getEscolo());
		}
		if (establec != null && establec.getEsnrcopo() != null) {
			where.append(" AND t1.ESNRCOPO = ?");
			params.add(establec.getEsnrcopo());
		}
		if (establec != null && establec.getEsnrtel() != null) {
			where.append(" AND t1.ESNRTEL = ?");
			params.add(establec.getEsnrtel());
		}
		if (establec != null && establec.getEsnrfax() != null) {
			where.append(" AND t1.ESNRFAX = ?");
			params.add(establec.getEsnrfax());
		}
		if (establec != null && establec.getEscopa() != null) {
			where.append(" AND t1.ESCOPA = ?");
			params.add(establec.getEscopa());
		}
		if (establec != null && establec.getEsincapr() != null) {
			where.append(" AND t1.ESINCAPR = ?");
			params.add(establec.getEsincapr());
		}
		if (establec != null && establec.getEsindemp() != null) {
			where.append(" AND t1.ESINDEMP = ?");
			params.add(establec.getEsindemp());
		}
		if (establec != null && establec.getEsteco() != null) {
			where.append(" AND t1.ESTECO = ?");
			params.add(establec.getEsteco());
		}
		if (establec != null && establec.getEsinadar() != null) {
			where.append(" AND t1.ESINADAR = ?");
			params.add(establec.getEsinadar());
		}
		if (establec != null && establec.getEsfeadar() != null) {
			where.append(" AND t1.ESFEADAR = ?");
			params.add(establec.getEsfeadar());
		}
		if (establec != null && establec.getEscoem() != null) {
			where.append(" AND t1.ESCOEM = ?");
			params.add(establec.getEscoem());
		}
		if (establec != null && establec.getEsinempr() != null) {
			where.append(" AND t1.ESINEMPR = ?");
			params.add(establec.getEsinempr());
		}
		if (establec != null && establec.getEsnrtel2() != null) {
			where.append(" AND t1.ESNRTEL2 = ?");
			params.add(establec.getEsnrtel2());
		}
		if (establec != null && establec.getEsfeba() != null) {
			where.append(" AND t1.ESFEBA = ?");
			params.add(establec.getEsfeba());
		}
		if (establec != null && establec.getEsnoap1() != null) {
			where.append(" AND t1.ESNOAP1 = ?");
			params.add(establec.getEsnoap1());
		}
		if (establec != null && establec.getEsnoap2() != null) {
			where.append(" AND t1.ESNOAP2 = ?");
			params.add(establec.getEsnoap2());
		}
		if (establec != null && establec.getEsnolo() != null) {
			where.append(" AND t1.ESNOLO = ?");
			params.add(establec.getEsnolo());
		}
		if (establec != null && establec.getEscomapv() != null) {
			where.append(" AND t1.ESCOMAPV = ?");
			params.add(establec.getEscomapv());
		}
		if (establec != null && establec.getEscoca() != null) {
			where.append(" AND t1.ESCOCA = ?");
			params.add(establec.getEscoca());
		}
		if (establec != null && establec.getEsnopeco() != null) {
			where.append(" AND t1.ESNOPECO = ?");
			params.add(establec.getEsnopeco());
		}
		if (establec != null && establec.getEscoidco() != null) {
			where.append(" AND t1.ESCOIDCO = ?");
			params.add(establec.getEscoidco());
		}
		if (establec != null && establec.getEsinreco() != null) {
			where.append(" AND t1.ESINRECO = ?");
			params.add(establec.getEsinreco());
		}
		if (establec != null && establec.getEscozs() != null) {
			where.append(" AND t1.ESCOZS = ?");
			params.add(establec.getEscozs());
		}
		if (establec != null && establec.getEsfemod() != null) {
			where.append(" AND t1.ESFEMOD = ?");
			params.add(establec.getEsfemod());
		}
		if (establec != null && establec.getEsinesco() != null) {
			where.append(" AND t1.ESINESCO = ?");
			params.add(establec.getEsinesco());
		}
		if (establec != null && establec.getEsnomu() != null) {
			where.append(" AND t1.ESNOMU = ?");
			params.add(establec.getEsnomu());
		}
		if (establec != null && establec.getEsnorep() != null) {
			where.append(" AND t1.ESNOREP = ?");
			params.add(establec.getEsnorep());
		}
		if (establec != null && establec.getEsnifrep() != null) {
			where.append(" AND t1.ESNIFREP = ?");
			params.add(establec.getEsnifrep());
		}
		if (establec != null && establec.getDtteemr() != null) {
			where.append(" AND t1.DTTEEMR = ?");
			params.add(establec.getDtteemr());
		}
		if (establec != null && establec.getEscarep() != null) {
			where.append(" AND t1.ESCAREP = ?");
			params.add(establec.getEscarep());
		}
		if (establec != null && establec.getEsteurl() != null) {
			where.append(" AND t1.ESTEURL = ?");
			params.add(establec.getEsteurl());
		}
		if (establec != null && establec.getEscooe() != null) {
			where.append(" AND t1.ESCOOE = ?");
			params.add(establec.getEscooe());
		}
		if (establec != null && establec.getEsnodeco() != null) {
			where.append(" AND t1.ESNODECO = ?");
			params.add(establec.getEsnodeco());
		}
		if (establec != null && establec.getEsintiar() != null) {
			where.append(" AND t1.ESINTIAR = ?");
			params.add(establec.getEsintiar());
		}
		if (establec != null && establec.getEsfeplad() != null) {
			where.append(" AND t1.ESFEPLAD = ?");
			params.add(establec.getEsfeplad());
		}
		if (establec != null && establec.getEsindeme() != null) {
			where.append(" AND t1.ESINDEME = ?");
			params.add(establec.getEsindeme());
		}
		query.append(where);
		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());
	}

	/**
	 * Finds rows in the Establec table using like.
	 * 
	 * @param establec
	 *            Establec
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Establec> findAllLike(Establec establec, Pagination pagination,
			Boolean startsWith) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.ESCODIGO ESCODIGO,t1.ESNOMBRE ESNOMBRE,t1.ESNIF ESNIF,t1.ESNOAN ESNOAN,t1.ESNOCO ESNOCO,t1.ESNODIR ESNODIR,t1.ESCOLO ESCOLO,t1.ESNRCOPO ESNRCOPO,t1.ESNRTEL ESNRTEL,t1.ESNRFAX ESNRFAX,t1.ESCOPA ESCOPA,t1.ESINCAPR ESINCAPR,t1.ESINDEMP ESINDEMP,t1.ESTECO ESTECO,t1.ESINADAR ESINADAR,t1.ESFEADAR ESFEADAR,t1.ESCOEM ESCOEM,t1.ESINEMPR ESINEMPR,t1.ESNRTEL2 ESNRTEL2,t1.ESFEBA ESFEBA,t1.ESNOAP1 ESNOAP1,t1.ESNOAP2 ESNOAP2,t1.ESNOLO ESNOLO,t1.ESCOMAPV ESCOMAPV,t1.ESCOCA ESCOCA,t1.ESNOPECO ESNOPECO,t1.ESCOIDCO ESCOIDCO,t1.ESINRECO ESINRECO,t1.ESCOZS ESCOZS,t1.ESFEMOD ESFEMOD,t1.ESINESCO ESINESCO,t1.ESNOMU ESNOMU,t1.ESNOREP ESNOREP,t1.ESNIFREP ESNIFREP,t1.DTTEEMR DTTEEMR,t1.ESCAREP ESCAREP,t1.ESTEURL ESTEURL,t1.ESCOOE ESCOOE,t1.ESNODECO ESNODECO,t1.ESINTIAR ESINTIAR,t1.ESFEPLAD ESFEPLAD,t1.ESINDEME ESINDEME "
						+ "FROM ESTABLEC t1 ");

		if (establec != null && establec.getEscodigo() != null) {
			where.append(" AND UPPER(t1.ESCODIGO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEscodigo().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEscodigo().toUpperCase() + "%");
			}
			where.append(" AND t1.ESCODIGO IS NOT NULL");
		}
		if (establec != null && establec.getEsnombre() != null) {
			where.append(" AND UPPER(t1.ESNOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnombre().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnombre().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNOMBRE IS NOT NULL");
		}
		if (establec != null && establec.getEsnif() != null) {
			where.append(" AND UPPER(t1.ESNIF) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnif().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnif().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNIF IS NOT NULL");
		}
		if (establec != null && establec.getEsnoan() != null) {
			where.append(" AND UPPER(t1.ESNOAN) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnoan().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnoan().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNOAN IS NOT NULL");
		}
		if (establec != null && establec.getEsnoco() != null) {
			where.append(" AND UPPER(t1.ESNOCO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnoco().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnoco().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNOCO IS NOT NULL");
		}
		if (establec != null && establec.getEsnodir() != null) {
			where.append(" AND UPPER(t1.ESNODIR) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnodir().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnodir().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNODIR IS NOT NULL");
		}
		if (establec != null && establec.getEscolo() != null) {
			where.append(" AND UPPER(t1.ESCOLO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEscolo().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEscolo().toUpperCase() + "%");
			}
			where.append(" AND t1.ESCOLO IS NOT NULL");
		}
		if (establec != null && establec.getEsnrcopo() != null) {
			where.append(" AND UPPER(t1.ESNRCOPO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnrcopo().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnrcopo().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNRCOPO IS NOT NULL");
		}
		if (establec != null && establec.getEsnrtel() != null) {
			where.append(" AND UPPER(t1.ESNRTEL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnrtel().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnrtel().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNRTEL IS NOT NULL");
		}
		if (establec != null && establec.getEsnrfax() != null) {
			where.append(" AND UPPER(t1.ESNRFAX) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnrfax().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnrfax().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNRFAX IS NOT NULL");
		}
		if (establec != null && establec.getEscopa() != null) {
			where.append(" AND UPPER(t1.ESCOPA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEscopa().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEscopa().toUpperCase() + "%");
			}
			where.append(" AND t1.ESCOPA IS NOT NULL");
		}
		if (establec != null && establec.getEsincapr() != null) {
			where.append(" AND UPPER(t1.ESINCAPR) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsincapr().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsincapr().toUpperCase() + "%");
			}
			where.append(" AND t1.ESINCAPR IS NOT NULL");
		}
		if (establec != null && establec.getEsindemp() != null) {
			where.append(" AND UPPER(t1.ESINDEMP) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsindemp().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsindemp().toUpperCase() + "%");
			}
			where.append(" AND t1.ESINDEMP IS NOT NULL");
		}
		if (establec != null && establec.getEsteco() != null) {
			where.append(" AND UPPER(t1.ESTECO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsteco().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsteco().toUpperCase() + "%");
			}
			where.append(" AND t1.ESTECO IS NOT NULL");
		}
		if (establec != null && establec.getEsinadar() != null) {
			where.append(" AND UPPER(t1.ESINADAR) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsinadar().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsinadar().toUpperCase() + "%");
			}
			where.append(" AND t1.ESINADAR IS NOT NULL");
		}
		if (establec != null && establec.getEsfeadar() != null) {
			where.append(" AND t1.ESFEADAR like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsfeadar() + "%");
			} else {
				params.add("%" + establec.getEsfeadar() + "%");
			}
			where.append(" AND t1.ESFEADAR IS NOT NULL");
		}
		if (establec != null && establec.getEscoem() != null) {
			where.append(" AND UPPER(t1.ESCOEM) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEscoem().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEscoem().toUpperCase() + "%");
			}
			where.append(" AND t1.ESCOEM IS NOT NULL");
		}
		if (establec != null && establec.getEsinempr() != null) {
			where.append(" AND UPPER(t1.ESINEMPR) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsinempr().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsinempr().toUpperCase() + "%");
			}
			where.append(" AND t1.ESINEMPR IS NOT NULL");
		}
		if (establec != null && establec.getEsnrtel2() != null) {
			where.append(" AND UPPER(t1.ESNRTEL2) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnrtel2().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnrtel2().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNRTEL2 IS NOT NULL");
		}
		if (establec != null && establec.getEsfeba() != null) {
			where.append(" AND t1.ESFEBA like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsfeba() + "%");
			} else {
				params.add("%" + establec.getEsfeba() + "%");
			}
			where.append(" AND t1.ESFEBA IS NOT NULL");
		}
		if (establec != null && establec.getEsnoap1() != null) {
			where.append(" AND UPPER(t1.ESNOAP1) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnoap1().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnoap1().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNOAP1 IS NOT NULL");
		}
		if (establec != null && establec.getEsnoap2() != null) {
			where.append(" AND UPPER(t1.ESNOAP2) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnoap2().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnoap2().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNOAP2 IS NOT NULL");
		}
		if (establec != null && establec.getEsnolo() != null) {
			where.append(" AND UPPER(t1.ESNOLO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnolo().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnolo().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNOLO IS NOT NULL");
		}
		if (establec != null && establec.getEscomapv() != null) {
			where.append(" AND UPPER(t1.ESCOMAPV) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEscomapv().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEscomapv().toUpperCase() + "%");
			}
			where.append(" AND t1.ESCOMAPV IS NOT NULL");
		}
		if (establec != null && establec.getEscoca() != null) {
			where.append(" AND UPPER(t1.ESCOCA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEscoca().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEscoca().toUpperCase() + "%");
			}
			where.append(" AND t1.ESCOCA IS NOT NULL");
		}
		if (establec != null && establec.getEsnopeco() != null) {
			where.append(" AND UPPER(t1.ESNOPECO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnopeco().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnopeco().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNOPECO IS NOT NULL");
		}
		if (establec != null && establec.getEscoidco() != null) {
			where.append(" AND UPPER(t1.ESCOIDCO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEscoidco().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEscoidco().toUpperCase() + "%");
			}
			where.append(" AND t1.ESCOIDCO IS NOT NULL");
		}
		if (establec != null && establec.getEsinreco() != null) {
			where.append(" AND UPPER(t1.ESINRECO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsinreco().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsinreco().toUpperCase() + "%");
			}
			where.append(" AND t1.ESINRECO IS NOT NULL");
		}
		if (establec != null && establec.getEscozs() != null) {
			where.append(" AND UPPER(t1.ESCOZS) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEscozs().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEscozs().toUpperCase() + "%");
			}
			where.append(" AND t1.ESCOZS IS NOT NULL");
		}
		if (establec != null && establec.getEsfemod() != null) {
			where.append(" AND UPPER(t1.ESFEMOD) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsfemod().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsfemod().toUpperCase() + "%");
			}
			where.append(" AND t1.ESFEMOD IS NOT NULL");
		}
		if (establec != null && establec.getEsinesco() != null) {
			where.append(" AND UPPER(t1.ESINESCO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsinesco().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsinesco().toUpperCase() + "%");
			}
			where.append(" AND t1.ESINESCO IS NOT NULL");
		}
		if (establec != null && establec.getEsnomu() != null) {
			where.append(" AND UPPER(t1.ESNOMU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnomu().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnomu().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNOMU IS NOT NULL");
		}
		if (establec != null && establec.getEsnorep() != null) {
			where.append(" AND UPPER(t1.ESNOREP) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnorep().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnorep().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNOREP IS NOT NULL");
		}
		if (establec != null && establec.getEsnifrep() != null) {
			where.append(" AND UPPER(t1.ESNIFREP) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnifrep().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnifrep().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNIFREP IS NOT NULL");
		}
		if (establec != null && establec.getDtteemr() != null) {
			where.append(" AND UPPER(t1.DTTEEMR) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getDtteemr().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getDtteemr().toUpperCase() + "%");
			}
			where.append(" AND t1.DTTEEMR IS NOT NULL");
		}
		if (establec != null && establec.getEscarep() != null) {
			where.append(" AND UPPER(t1.ESCAREP) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEscarep().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEscarep().toUpperCase() + "%");
			}
			where.append(" AND t1.ESCAREP IS NOT NULL");
		}
		if (establec != null && establec.getEsteurl() != null) {
			where.append(" AND UPPER(t1.ESTEURL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsteurl().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsteurl().toUpperCase() + "%");
			}
			where.append(" AND t1.ESTEURL IS NOT NULL");
		}
		if (establec != null && establec.getEscooe() != null) {
			where.append(" AND UPPER(t1.ESCOOE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEscooe().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEscooe().toUpperCase() + "%");
			}
			where.append(" AND t1.ESCOOE IS NOT NULL");
		}
		if (establec != null && establec.getEsnodeco() != null) {
			where.append(" AND UPPER(t1.ESNODECO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnodeco().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnodeco().toUpperCase() + "%");
			}
			where.append(" AND t1.ESNODECO IS NOT NULL");
		}
		if (establec != null && establec.getEsintiar() != null) {
			where.append(" AND UPPER(t1.ESINTIAR) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsintiar().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsintiar().toUpperCase() + "%");
			}
			where.append(" AND t1.ESINTIAR IS NOT NULL");
		}
		if (establec != null && establec.getEsfeplad() != null) {
			where.append(" AND t1.ESFEPLAD like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsfeplad() + "%");
			} else {
				params.add("%" + establec.getEsfeplad() + "%");
			}
			where.append(" AND t1.ESFEPLAD IS NOT NULL");
		}
		if (establec != null && establec.getEsindeme() != null) {
			where.append(" AND UPPER(t1.ESINDEME) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsindeme().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsindeme().toUpperCase() + "%");
			}
			where.append(" AND t1.ESINDEME IS NOT NULL");
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Establec>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Establec table using like.
	 * 
	 * @param establec
	 *            Establec
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Establec> findAllLikeEstablec(Establec establec,
			Pagination pagination, Boolean startsWith) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		String transformacion = "";

		StringBuffer query = new StringBuffer(
				"SELECT DISTINCT '' CODSECTOR, AH.AHFEBA BAJA, "// s.secodigo
				// CODSECTOR, "
						+ "E.ESCODIGO ESCODIGO,E.ESNOMBRE ESNOMBRE,E.ESNIF ESNIF,E.ESNOAN ESNOAN, "
						+ "E.ESNOCO ESNOCO,E.ESNODIR ESNODIR,E.ESCOLO ESCOLO,E.ESNRCOPO ESNRCOPO,E.ESNRTEL ESNRTEL, "
						+ "E.ESNRFAX ESNRFAX,E.ESCOPA ESCOPA,E.ESINCAPR ESINCAPR,E.ESINDEMP ESINDEMP,E.ESTECO ESTECO, "
						+ "E.ESINADAR ESINADAR,E.ESFEADAR ESFEADAR,E.ESCOEM ESCOEM,E.ESINEMPR ESINEMPR, "
						+ "E.ESNRTEL2 ESNRTEL2,E.ESFEBA ESFEBA,E.ESNOAP1 ESNOAP1,E.ESNOAP2 ESNOAP2, "
						+ "E.ESNOLO ESNOLO,E.ESCOMAPV ESCOMAPV,E.ESCOCA ESCOCA,E.ESNOPECO ESNOPECO,E.ESCOIDCO ESCOIDCO, "
						+ "E.ESINRECO ESINRECO,E.ESCOZS ESCOZS,E.ESFEMOD ESFEMOD,E.ESINESCO ESINESCO,E.ESNOMU ESNOMU, "
						+ "E.ESNOREP ESNOREP,E.ESNIFREP ESNIFREP,E.DTTEEMR DTTEEMR,E.ESCAREP ESCAREP,E.ESTEURL ESTEURL, "
						+ "E.ESCOOE ESCOOE,E.ESNODECO ESNODECO,E.ESINTIAR ESINTIAR,E.ESFEPLAD ESFEPLAD,E.ESINDEME ESINDEME, "
						+ "E.ESINDEME LIMITACIONES, E.ESEXTRANJERO ESEXTRANJERO, E.ESNORA_PAIS_ID ESNORAPAISID, E.ESNORA_PAIS_NOMBRE ESNORAPAISNOMBRE, "
						+ "E.ESNORA_PROVINCIA_ID ESNORAPROVINCIAID, E.ESNOMBRE_PROVINCIA ESNOMBREPROVINCIA, "
						+ "E.ESNORA_MUNICIPIO_ID ESNORAMUNICIPIOID, E.ESNOMBRE_MUNICIPIO ESNOMBREMUNICIPIO, "
						+ "E.ESNORA_LOCALIDAD_ID ESNORALOCALIDADID, E.ESNOMBRE_LOCALIDAD ESNOMBRELOCALIDAD, "
						+ "E.ESNORA_CALLE_ID ESNORACALLEID, E.ESNOMBRE_CALLE ESNOMBRECALLE, "
						+ "E.ESNORA_CP_ID ESNORACPID, E.ESNOMBRE_CP ESNOMBRECP, E.ESNORA_PORTAL_ID ESNORAPORTALID, E.ESNOMBRE_PORTAL ESNOMBREPORTAL, "
						+ "E.ESNOMBRE_PISO ESNOMBREPISO, E.ESDIRECCION_NOCAPV ESDIRECCION_NOCAPV, AH.AHNRDI AHNRDI "
						+ "FROM ESTABLEC E, ADHEESTA AH, ESTASECT ES, SECTORES S "
						+ "WHERE AH.AHCOES = E.ESCODIGO "
						+ "AND E.ESCODIGO = ES.EACOES (+) "
						+ "AND ES.EACOSE = S.SECODIGO (+) "
						+ "AND E.ESFEBA IS NULL ");

		if (establec != null && establec.getEsinadar() != null
				&& ("S").equals(establec.getEsinadar())) {
			where.append(" AND AH.AHFEBA IS NULL");
		}
		if (establec != null && establec.getEsinadar() != null
				&& ("N").equals(establec.getEsinadar())) {
			where.append(" AND NOT AH.AHFEBA IS NULL");
		}
		if (establec != null && establec.getEsnif() != null) {
			where.append(" AND E.ESNIF = ? ");
			params.add(establec.getEsnif());
		}
		if (establec != null && establec.getAhnrdi() != null) {
			where.append(" AND AH.AHNRDI = ? ");
			params.add(establec.getAhnrdi());
		}

		if (establec != null && establec.getEscodigo() != null) {
			where.append(" AND E.ESCODIGO = ? ");
			params.add(establec.getEscodigo());
			where.append(" AND E.ESCODIGO IS NOT NULL");
		}

		if (establec != null && establec.getEsextranjero() != null) {
			where.append(" AND E.ESEXTRANJERO = 'S'");
		} else if (establec != null && establec.getEsestado() != null) {
			where.append(" AND E.ESEXTRANJERO = 'N'");
		}
		// else {
		// where.append(" AND E.ESEXTRANJERO IS NOT NULL");
		// }

		if (establec != null && establec.getEsnoraPaisId() != null) {
			where.append(" AND E.ESNORA_PAIS_ID = ?");
			params.add(establec.getEsnoraPaisId());
		}

		if (establec != null && establec.getEsnoraProvinciaId() != null) {
			where.append(" AND E.ESNORA_PROVINCIA_ID = ?");
			params.add(establec.getEsnoraProvinciaId());
		}
		if (establec != null && establec.getEsnoraMunicipioId() != null) {
			where.append(" AND E.ESNORA_MUNICIPIO_ID = ?");
			params.add(establec.getEsnoraMunicipioId());
		}
		if (establec != null && establec.getEsnoraLocalidadId() != null) {
			where.append(" AND E.ESNORA_LOCALIDAD_ID = ?");
			params.add(establec.getEsnoraLocalidadId());

		}

		if (establec != null && establec.getEsnombre() != null) {
			where.append(" AND ((TRANSLATE(UPPER(E.ESNOMBRE),'\u00c1\u00c9\u00cd\u00d3\u00da','AEIOU') like ? ESCAPE  '\\'");

			params.add("%"
					+ establec.getEsnombre().toUpperCase()
							.replaceAll("\u00c1", "A")
							.replaceAll("\u00c9", "E")
							.replaceAll("\u00cd", "I")
							.replaceAll("\u00d3", "O")
							.replaceAll("\u00da", "U") + "%");

			where.append(" AND E.ESNOMBRE IS NOT NULL) ");

			where.append(" OR (TRANSLATE(UPPER(E.ESNOCO),'\u00c1\u00c9\u00cd\u00d3\u00da','AEIOU') like ? ESCAPE  '\\'");

			params.add("%"
					+ establec.getEsnombre().toUpperCase()
							.replaceAll("\u00c1", "A")
							.replaceAll("\u00c9", "E")
							.replaceAll("\u00cd", "I")
							.replaceAll("\u00d3", "O")
							.replaceAll("\u00da", "U") + "%");

			where.append(" AND E.ESNOCO IS NOT NULL)) ");
		}

		if (establec != null && establec.getCodsector() != null) {
			where.append(" AND S.SECOL0  IN ( ");
			where.append(establec.getCodsector());
			// where.append(" :codsector");
			where.append(" )");
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		logger.info("!!!!!!transformacion!!!!!!!!" + transformacion);
		logger.info("!!!!!!query.toString()!!!!!!!!" + query.toString());
		logger.info("!!!!!!params.toArray().toString()!!!!!!!!"
				+ params.toArray().toString());

		return (List<Establec>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Establec table using like.
	 * 
	 * @param establec
	 *            Establec
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Establec> findAllLikeEstablecDistintivo(Establec establec,
			Pagination pagination, Boolean startsWith) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		String transformacion = "";
		// where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  AH.AHFEBA BAJA, s.secodigo CODSECTOR, "
						+ "E.ESCODIGO ESCODIGO,E.ESNOMBRE ESNOMBRE,E.ESNIF ESNIF,E.ESNOAN ESNOAN, "
						+ "E.ESNOCO ESNOCO,E.ESNODIR ESNODIR,E.ESCOLO ESCOLO,E.ESNRCOPO ESNRCOPO,E.ESNRTEL ESNRTEL, "
						+ "E.ESNRFAX ESNRFAX,E.ESCOPA ESCOPA,E.ESINCAPR ESINCAPR,E.ESINDEMP ESINDEMP,E.ESTECO ESTECO, "
						+ "E.ESINADAR ESINADAR,E.ESFEADAR ESFEADAR,E.ESCOEM ESCOEM,E.ESINEMPR ESINEMPR, "
						+ "E.ESNRTEL2 ESNRTEL2,E.ESFEBA ESFEBA,E.ESNOAP1 ESNOAP1,E.ESNOAP2 ESNOAP2, "
						+ "E.ESNOLO ESNOLO,E.ESCOMAPV ESCOMAPV,E.ESCOCA ESCOCA,E.ESNOPECO ESNOPECO,E.ESCOIDCO ESCOIDCO, "
						+ "E.ESINRECO ESINRECO,E.ESCOZS ESCOZS,E.ESFEMOD ESFEMOD,E.ESINESCO ESINESCO,E.ESNOMU ESNOMU, "
						+ "E.ESNOREP ESNOREP,E.ESNIFREP ESNIFREP,E.DTTEEMR DTTEEMR,E.ESCAREP ESCAREP,E.ESTEURL ESTEURL, "
						+ "E.ESCOOE ESCOOE,E.ESNODECO ESNODECO,E.ESINTIAR ESINTIAR,E.ESFEPLAD ESFEPLAD,E.ESINDEME ESINDEME, "
						+ "E.ESINDEME LIMITACIONES, E.ESEXTRANJERO ESEXTRANJERO, E.ESNORA_PAIS_ID ESNORAPAISID, E.ESNORA_PAIS_NOMBRE ESNORAPAISNOMBRE, "
						+ "E.ESNORA_PROVINCIA_ID ESNORAPROVINCIAID, E.ESNOMBRE_PROVINCIA ESNOMBREPROVINCIA, "
						+ "E.ESNORA_MUNICIPIO_ID ESNORAMUNICIPIOID, E.ESNOMBRE_MUNICIPIO ESNOMBREMUNICIPIO, "
						+ "E.ESNORA_LOCALIDAD_ID ESNORALOCALIDADID, E.ESNOMBRE_LOCALIDAD ESNOMBRELOCALIDAD, "
						+ "E.ESNORA_CALLE_ID ESNORACALLEID, E.ESNOMBRE_CALLE ESNOMBRECALLE, "
						+ "E.ESNORA_CP_ID ESNORACPID, E.ESNOMBRE_CP ESNOMBRECP, E.ESNORA_PORTAL_ID ESNORAPORTALID, E.ESNOMBRE_PORTAL ESNOMBREPORTAL, "
						+ "E.ESNOMBRE_PISO ESNOMBREPISO, E.ESDIRECCION_NOCAPV ESDIRECCION_NOCAPV, AH.AHNRDI AHNRDI "
						+ "FROM ESTABLEC E, ADHEESTA AH, ESTASECT ES, SECTORES S "
						+ "WHERE AH.AHCOES = E.ESCODIGO "
						+ "AND E.ESCODIGO = ES.EACOES (+) "
						+ "AND ES.EACOSE = S.SECODIGO (+) ");

		if (establec != null && establec.getEsinadar() != null
				&& ("S").equals(establec.getEsinadar())) {
			where.append(" AND AH.AHFEBA IS NULL");
		}
		if (establec != null && establec.getEsinadar() != null
				&& ("N").equals(establec.getEsinadar())) {
			where.append(" AND NOT AH.AHFEBA IS NULL");
		}
		if (establec != null && establec.getEsnif() != null) {
			where.append(" AND UPPER(E.ESNIF) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(establec.getEsnif().toUpperCase() + "%");
			} else {
				params.add("%" + establec.getEsnif().toUpperCase() + "%");
			}
			where.append(" AND E.ESNIF IS NOT NULL");
		}
		if (establec != null && establec.getEscodigo() != null) {
			where.append(" AND E.ESCODIGO = ? ");
			params.add(establec.getEscodigo());
			where.append(" AND E.ESCODIGO IS NOT NULL");
		}
		if (establec != null && establec.getEslocalidad() != null) {
			where.append(" AND L.LOCOMU = ?");
			params.add(establec.getEslocalidad());
		}
		if (establec != null && establec.getEsnolo() != null) {

			if (establec.getEsnolo() == Y38aEstablecAdheConstantes.BIZKAIA) {
				where.append(" AND P.PVCODIGO = ");
				where.append(Y38aEstablecAdheConstantes.BIZKAIA);
			} else if (establec.getEsnolo() == Y38aEstablecAdheConstantes.GIPUZKOA) {
				where.append(" AND P.PVCODIGO = ");
				where.append(Y38aEstablecAdheConstantes.GIPUZKOA);
			} else if (establec.getEsnolo() == Y38aEstablecAdheConstantes.ALAVA) {
				where.append(" AND P.PVCODIGO = ");
				where.append(Y38aEstablecAdheConstantes.ALAVA);
			} else if (establec.getEsnolo() == Y38aEstablecAdheConstantes.OTRAS) {
				where.append(" AND P.PVCODIGO  not in ('20','01','48') ");

			}
		}
		// Fechas
		where.append(" AND E.ESFEBA IS NULL ");
		where.append(" AND AH.AHFEBA IS NULL ");

		if (establec != null && establec.getEsnombre() != null) {
			String label = "'ÁÉÍÓÚÀÈÌÒÙÜ'";

			Properties prop = Y38aUtils
					.loadProperties(Y38aEstablecAdheConstantes.CONFIG_PATH);
			String local = (String) prop
					.getProperty("y38aVistaWar.entorno.local");
			if ("true".equals(local)) {
				transformacion = label;
			} else {
				transformacion = Y38aUtils.convertToUTF8(label);
			}

			where.append(" AND ( TRANSLATE(TRIM(UPPER(E.ESNOMBRE)),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU')");
			where.append(" LIKE ");
			where.append(" TRANSLATE(TRIM(UPPER(");
			where.append("'%");
			where.append(establec.getEsnombre());
			where.append("%'");
			where.append(")),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU') ");

			where.append(" OR TRANSLATE(TRIM(UPPER(E.ESNOCO)),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU')");
			where.append(" LIKE ");
			where.append(" TRANSLATE(TRIM(UPPER(");
			where.append("'%");
			where.append(establec.getEsnombre());
			where.append("%'");
			where.append(")),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU') ");

			where.append(" ) ");

		}
		if (establec != null && establec.getCodsector() != null) {
			where.append(" AND S.SECOL0  IN ( ");
			where.append(establec.getCodsector());
			// where.append(" :codsector");
			where.append(" )");
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		logger.info("!!!!!!transformacion!!!!!!!!" + transformacion);
		logger.info("!!!!!!query.toString()!!!!!!!!" + query.toString());
		logger.info("!!!!!!params.toArray().toString()!!!!!!!!"
				+ params.toArray().toString());

		return (List<Establec>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Establec table using like.
	 * 
	 * @param establec
	 *            Establec
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCountLikeEstablec(Establec establec) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		// where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT COUNT(DISTINCT E.ESCODIGO) "
						+ "FROM ESTABLEC E, ADHEESTA AH, ESTASECT ES, SECTORES S, SECAGRUP SA "
						+ "WHERE AH.AHCOES = E.ESCODIGO "
						+ "AND E.ESCODIGO = ES.EACOES (+) "
						+ "AND ES.EACOSE = S.SECODIGO (+) "
						+ "AND E.ESFEBA IS NULL  ");

		if (establec != null && establec.getEsinadar() != null
				&& ("S").equals(establec.getEsinadar())) {
			where.append(" AND AH.AHFEBA IS NULL");
		}
		if (establec != null && establec.getEsinadar() != null
				&& ("N").equals(establec.getEsinadar())) {
			where.append(" AND NOT AH.AHFEBA IS NULL");
		}
		if (establec != null && establec.getEsnif() != null) {
			where.append(" AND E.ESNIF = ? ");
			params.add(establec.getEsnif());
		}
		if (establec != null && establec.getAhnrdi() != null) {
			where.append(" AND AH.AHNRDI = ? ");
			params.add(establec.getAhnrdi());
		}

		if (establec != null && establec.getEscodigo() != null) {
			where.append(" AND E.ESCODIGO = ? ");
			params.add(establec.getEscodigo());
			where.append(" AND E.ESCODIGO IS NOT NULL");
		}

		if (establec != null && establec.getEsextranjero() != null) {
			where.append(" AND E.ESEXTRANJERO = 'S'");
		} else if (establec != null && establec.getEsestado() != null) {
			where.append(" AND E.ESEXTRANJERO = 'N'");
		}
		// else {
		// where.append(" AND E.ESEXTRANJERO IS NOT NULL");
		// }

		if (establec != null && establec.getEsnoraPaisId() != null) {
			where.append(" AND E.ESNORA_PAIS_ID = ?");
			params.add(establec.getEsnoraPaisId());
		}
		if (establec != null && establec.getEsnoraProvinciaId() != null) {
			where.append(" AND E.ESNORA_PROVINCIA_ID = ?");
			params.add(establec.getEsnoraProvinciaId());
		}
		if (establec != null && establec.getEsnoraMunicipioId() != null) {
			where.append(" AND E.ESNORA_MUNICIPIO_ID = ?");
			params.add(establec.getEsnoraMunicipioId());
		}
		if (establec != null && establec.getEsnoraLocalidadId() != null) {
			where.append(" AND E.ESNORA_LOCALIDAD_ID = ?");
			params.add(establec.getEsnoraLocalidadId());
		}

		if (establec != null && establec.getEsnombre() != null) {
			where.append(" AND ((TRANSLATE(UPPER(E.ESNOMBRE),'\u00c1\u00c9\u00cd\u00d3\u00da','AEIOU') like ? ESCAPE  '\\'");

			params.add("%"
					+ establec.getEsnombre().toUpperCase()
							.replaceAll("\u00c1", "A")
							.replaceAll("\u00c9", "E")
							.replaceAll("\u00cd", "I")
							.replaceAll("\u00d3", "O")
							.replaceAll("\u00da", "U") + "%");

			where.append(" AND E.ESNOMBRE IS NOT NULL) ");

			where.append(" OR (TRANSLATE(UPPER(E.ESNOCO),'\u00c1\u00c9\u00cd\u00d3\u00da','AEIOU') like ? ESCAPE  '\\'");

			params.add("%"
					+ establec.getEsnombre().toUpperCase()
							.replaceAll("\u00c1", "A")
							.replaceAll("\u00c9", "E")
							.replaceAll("\u00cd", "I")
							.replaceAll("\u00d3", "O")
							.replaceAll("\u00da", "U") + "%");

			where.append(" AND E.ESNOCO IS NOT NULL)) ");
		}

		if (establec != null && establec.getCodsector() != null) {
			where.append(" AND  S.SECOL0  IN ( ");
			where.append(establec.getCodsector());
			// where.append(" :codsector");
			where.append(" )");

		}
		query.append(where);

		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());
	}

	/**
	 * Finds a single row in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @param establecFiltro
	 *            Establec
	 * @return Establec
	 */
	@Transactional(readOnly = true)
	public Establec findLimitaciones(Establec establec, Establec establecFiltro) {
		StringBuffer query = new StringBuffer(
				"SELECT AHTELIMI LIMITACIONES FROM ADHEESTA WHERE AHCOES = ?");

		List<Object> params = new ArrayList<Object>();
		params.add(establec.getEscodigo());

		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);

		if (establecFiltro != null && establecFiltro.getEsinadar() != null
				&& ("S").equals(establecFiltro.getEsinadar())) {
			where.append(" AND AHFEBA IS NULL");
			where.append(" ORDER BY  AHFEPUCD DESC ");

		}
		if (establecFiltro != null && establecFiltro.getEsinadar() != null
				&& ("N").equals(establecFiltro.getEsinadar())) {
			where.append(" AND NOT AHFEBA IS NULL ");
			where.append(" ORDER BY AHFEBA DESC ");
		}

		query.append(where);

		List<Establec> listEstablec = this.jdbcTemplate.query(query.toString(),
				new RowMapper<Establec>() {
					public Establec mapRow(ResultSet resultSet, int rowNum)
							throws SQLException {
						return new Establec(null, null, null, null, null, null,
								null, null, null, null, null, null, null, null,
								null, null, null, null, null, null, null, null,
								null, null, null, null, null, null, null, null,
								null, null, null, null, null, null, null, null,
								null, null, null, null, null, null, null, null,
								null, null,
								resultSet.getString("LIMITACIONES"), null,
								null, null, null, null, null, null, null, null,
								null, null, null, null, null, null, null, null,
								null, null);
					}
				}, params.toArray());

		if (listEstablec.size() > 0) {
			return listEstablec.get(0);
		} else {
			return new Establec();
		}

	}

	/**
	 * Finds rows in the Establec table using like.
	 * 
	 * @param establec
	 *            Establec
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCountLikeEstablecDistintivo(Establec establec) {

		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		String transformacion = "";
		// where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer("SELECT COUNT(1) "
				+ "FROM ESTABLEC E, ADHEESTA AH, ESTASECT ES, SECTORES S "
				+ "WHERE AH.AHCOES = E.ESCODIGO "
				+ "AND E.ESCODIGO = ES.EACOES (+) "
				+ "AND ES.EACOSE = S.SECODIGO (+) ");

		if (establec != null && establec.getEsinadar() != null
				&& ("S").equals(establec.getEsinadar())) {
			where.append(" AND AH.AHFEBA IS NULL");
		}
		if (establec != null && establec.getEsinadar() != null
				&& ("N").equals(establec.getEsinadar())) {
			where.append(" AND NOT AH.AHFEBA IS NULL");
		}
		if (establec != null && establec.getEsnif() != null) {
			where.append(" AND UPPER(E.ESNIF) like ? ESCAPE  '\\'");
			params.add("%" + establec.getEsnif().toUpperCase() + "%");
			where.append(" AND E.ESNIF IS NOT NULL");
		}
		if (establec != null && establec.getEscodigo() != null) {
			where.append(" AND E.ESCODIGO = ? ");
			params.add(establec.getEscodigo());
			where.append(" AND E.ESCODIGO IS NOT NULL");
		}
		if (establec != null && establec.getEslocalidad() != null) {
			where.append(" AND L.LOCOMU = ?");
			params.add(establec.getEslocalidad());
		}
		if (establec != null && establec.getEsnolo() != null) {

			if (establec.getEsnolo() == Y38aEstablecAdheConstantes.BIZKAIA) {
				where.append(" AND P.PVCODIGO = ");
				where.append(Y38aEstablecAdheConstantes.BIZKAIA);
			} else if (establec.getEsnolo() == Y38aEstablecAdheConstantes.GIPUZKOA) {
				where.append(" AND P.PVCODIGO = ");
				where.append(Y38aEstablecAdheConstantes.GIPUZKOA);
			} else if (establec.getEsnolo() == Y38aEstablecAdheConstantes.ALAVA) {
				where.append(" AND P.PVCODIGO = ");
				where.append(Y38aEstablecAdheConstantes.ALAVA);
			} else if (establec.getEsnolo() == Y38aEstablecAdheConstantes.OTRAS) {
				where.append(" AND P.PVCODIGO  not in ('20','01','48') ");

			}
		}
		// Fechas
		where.append(" AND E.ESFEBA IS NULL ");
		where.append(" AND AH.AHFEBA IS NULL ");

		if (establec != null && establec.getEsnombre() != null) {
			String label = "'ÁÉÍÓÚÀÈÌÒÙÜ'";

			Properties prop = Y38aUtils
					.loadProperties(Y38aEstablecAdheConstantes.CONFIG_PATH);
			String local = (String) prop
					.getProperty("y38aVistaWar.entorno.local");
			if ("true".equals(local)) {
				transformacion = label;
			} else {
				transformacion = Y38aUtils.convertToUTF8(label);
			}

			where.append(" AND ( TRANSLATE(TRIM(UPPER(E.ESNOMBRE)),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU')");
			where.append(" LIKE ");
			where.append(" TRANSLATE(TRIM(UPPER(");
			where.append("'%");
			where.append(establec.getEsnombre());
			where.append("%'");
			where.append(")),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU') ");

			where.append(" OR TRANSLATE(TRIM(UPPER(E.ESNOCO)),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU')");
			where.append(" LIKE ");
			where.append(" TRANSLATE(TRIM(UPPER(");
			where.append("'%");
			where.append(establec.getEsnombre());
			where.append("%'");
			where.append(")),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU') ");

			where.append(" ) ");
		}
		if (establec != null && establec.getCodsector() != null) {
			where.append(" AND S.SECODIGO  IN ( '");
			where.append(establec.getCodsector());
			// where.append(" :codsector");
			where.append("' )");

		}
		query.append(where);

		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());
	}
}
