package com.ejie.y38a.dao;

import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.PaginationManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.constantes.Y38aEstablecAdheConstantes;
import com.ejie.y38a.model.Estasect;

/**
 * * EstasectDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class EstasectDaoImpl implements EstasectDao {
	private SimpleJdbcTemplate jdbcTemplate;
	private RowMapper<Estasect> rwMap = new RowMapper<Estasect>() {
		public Estasect mapRow(ResultSet resultSet, int rowNum)
				throws SQLException {
			return new Estasect(resultSet.getString("EACODIGO"),
					resultSet.getString("EACOES"),
					resultSet.getString("EACOAV"),
					resultSet.getString("EACOSE"),
					resultSet.getString("EAINPRSE"));
		}
	};

	/**
	 * Method use to set the datasource.
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new SimpleJdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the Estasect table.
	 * 
	 * @param estasect
	 *            Pagination
	 * @return Estasect
	 */
	public Estasect add(Estasect estasect) {

		String query = "INSERT INTO ESTASECT( EACODIGO,EACOES,EACOAV,EACOSE,EAINPRSE)"
				+ "VALUES (?,?,?,?,?)";

		this.jdbcTemplate.update(query, estasect.getEacodigo(),
				estasect.getEacoes(), estasect.getEacoav(),
				estasect.getEacose(), estasect.getEainprse());
		return estasect;
	}

	/**
	 * Updates a single row in the Estasect table.
	 * 
	 * @param estasect
	 *            Pagination
	 * @return Estasect
	 */
	public Estasect update(Estasect estasect) {
		String query = "UPDATE ESTASECT SET EACOES=?,EACOAV=?,EACOSE=?,EAINPRSE=? WHERE EACODIGO=?";
		this.jdbcTemplate.update(query, estasect.getEacoes(),
				estasect.getEacoav(), estasect.getEacose(),
				estasect.getEainprse(), estasect.getEacodigo());
		return estasect;
	}

	/**
	 * Finds a single row in the Estasect table.
	 * 
	 * @param estasect
	 *            Pagination
	 * @return Estasect
	 */
	@Transactional(readOnly = true)
	public Estasect find(Estasect estasect) {
		String query = "SELECT t1.EACODIGO EACODIGO, t1.EACOES EACOES, t1.EACOAV EACOAV, t1.EACOSE EACOSE, t1.EAINPRSE EAINPRSE "
				+ "FROM ESTASECT t1  " + "WHERE t1.EACODIGO = ?    ";
		return (Estasect) this.jdbcTemplate.queryForObject(query, rwMap,
				estasect.getEacodigo());
	}

	/**
	 * Removes a single row in the Estasect table.
	 * 
	 * @param estasect
	 *            Pagination
	 * @return
	 */
	public void remove(Estasect estasect) {
		String query = "DELETE  FROM ESTASECT WHERE EACODIGO=?";
		this.jdbcTemplate.update(query, estasect.getEacodigo());
	}

	/**
	 * Finds a List of rows in the Estasect table.
	 * 
	 * @param estasect
	 *            Estasect
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Estasect> findAll(Estasect estasect, Pagination pagination) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.EACODIGO EACODIGO,t1.EACOES EACOES,t1.EACOAV EACOAV,t1.EACOSE EACOSE,t1.EAINPRSE EAINPRSE "
						+ "FROM ESTASECT t1 ");

		if (estasect != null && estasect.getEacodigo() != null) {
			where.append(" AND t1.EACODIGO = ?");
			params.add(estasect.getEacodigo());
		}
		if (estasect != null && estasect.getEacoes() != null) {
			where.append(" AND t1.EACOES = ?");
			params.add(estasect.getEacoes());
		}
		if (estasect != null && estasect.getEacoav() != null) {
			where.append(" AND t1.EACOAV = ?");
			params.add(estasect.getEacoav());
		}
		if (estasect != null && estasect.getEacose() != null) {
			where.append(" AND t1.EACOSE = ?");
			params.add(estasect.getEacose());
		}
		if (estasect != null && estasect.getEainprse() != null) {
			where.append(" AND t1.EAINPRSE = ?");
			params.add(estasect.getEainprse());
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Estasect>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Counts rows in the Estasect table.
	 * 
	 * @param estasect
	 *            Estasect
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Estasect estasect) {

		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1  ");

		StringBuffer query = new StringBuffer(
				"SELECT COUNT(1) FROM  ESTASECT t1  ");
		if (estasect != null && estasect.getEacodigo() != null) {
			where.append(" AND t1.EACODIGO = ?");
			params.add(estasect.getEacodigo());
		}
		if (estasect != null && estasect.getEacoes() != null) {
			where.append(" AND t1.EACOES = ?");
			params.add(estasect.getEacoes());
		}
		if (estasect != null && estasect.getEacoav() != null) {
			where.append(" AND t1.EACOAV = ?");
			params.add(estasect.getEacoav());
		}
		if (estasect != null && estasect.getEacose() != null) {
			where.append(" AND t1.EACOSE = ?");
			params.add(estasect.getEacose());
		}
		if (estasect != null && estasect.getEainprse() != null) {
			where.append(" AND t1.EAINPRSE = ?");
			params.add(estasect.getEainprse());
		}
		query.append(where);
		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());
	}

	/**
	 * Finds rows in the Estasect table using like.
	 * 
	 * @param estasect
	 *            Estasect
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Estasect> findAllLike(Estasect estasect, Pagination pagination,
			Boolean startsWith) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.EACODIGO EACODIGO,t1.EACOES EACOES,t1.EACOAV EACOAV,t1.EACOSE EACOSE,t1.EAINPRSE EAINPRSE "
						+ "FROM ESTASECT t1 ");

		if (estasect != null && estasect.getEacodigo() != null) {
			where.append(" AND UPPER(t1.EACODIGO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(estasect.getEacodigo().toUpperCase() + "%");
			} else {
				params.add("%" + estasect.getEacodigo().toUpperCase() + "%");
			}
			where.append(" AND t1.EACODIGO IS NOT NULL");
		}
		if (estasect != null && estasect.getEacoes() != null) {
			where.append(" AND UPPER(t1.EACOES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(estasect.getEacoes().toUpperCase() + "%");
			} else {
				params.add("%" + estasect.getEacoes().toUpperCase() + "%");
			}
			where.append(" AND t1.EACOES IS NOT NULL");
		}
		if (estasect != null && estasect.getEacoav() != null) {
			where.append(" AND UPPER(t1.EACOAV) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(estasect.getEacoav().toUpperCase() + "%");
			} else {
				params.add("%" + estasect.getEacoav().toUpperCase() + "%");
			}
			where.append(" AND t1.EACOAV IS NOT NULL");
		}
		if (estasect != null && estasect.getEacose() != null) {
			where.append(" AND UPPER(t1.EACOSE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(estasect.getEacose().toUpperCase() + "%");
			} else {
				params.add("%" + estasect.getEacose().toUpperCase() + "%");
			}
			where.append(" AND t1.EACOSE IS NOT NULL");
		}
		if (estasect != null && estasect.getEainprse() != null) {
			where.append(" AND UPPER(t1.EAINPRSE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(estasect.getEainprse().toUpperCase() + "%");
			} else {
				params.add("%" + estasect.getEainprse().toUpperCase() + "%");
			}
			where.append(" AND t1.EAINPRSE IS NOT NULL");
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Estasect>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}
}
