package com.ejie.y38a.dao;

import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.PaginationManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.constantes.Y38aEstablecAdheConstantes;
import com.ejie.y38a.model.Localida;

/**
 * * LocalidaDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class LocalidaDaoImpl implements LocalidaDao {
	private SimpleJdbcTemplate jdbcTemplate;
	private RowMapper<Localida> rwMap = new RowMapper<Localida>() {
		public Localida mapRow(ResultSet resultSet, int rowNum)
				throws SQLException {
			return new Localida(resultSet.getString("LOCODIGO"),
					resultSet.getString("CODLOCALID"),
					resultSet.getString("LOCOPV"),
					resultSet.getString("LOCOMU"),
					resultSet.getString("LOCOPA"),
					resultSet.getString("LONOMBRE"),
					resultSet.getString("LONRCOPO"));
		}
	};

	/**
	 * Method use to set the datasource.
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new SimpleJdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the Localida table.
	 * 
	 * @param localida
	 *            Pagination
	 * @return Localida
	 */
	public Localida add(Localida localida) {

		String query = "INSERT INTO LOCALIDA( LOCODIGO,CODLOCALID,LOCOPV,LOCOMU,LOCOPA,LONOMBRE,LONRCOPO)"
				+ "VALUES (?,?,?,?,?,?,?)";

		this.jdbcTemplate.update(query, localida.getLocodigo(),
				localida.getCodlocalid(), localida.getLocopv(),
				localida.getLocomu(), localida.getLocopa(),
				localida.getLonombre(), localida.getLonrcopo());
		return localida;
	}

	/**
	 * Updates a single row in the Localida table.
	 * 
	 * @param localida
	 *            Pagination
	 * @return Localida
	 */
	public Localida update(Localida localida) {
		String query = "UPDATE LOCALIDA SET CODLOCALID=?,LOCOPV=?,LOCOMU=?,LOCOPA=?,LONOMBRE=?,LONRCOPO=? WHERE LOCODIGO=?";
		this.jdbcTemplate.update(query, localida.getCodlocalid(),
				localida.getLocopv(), localida.getLocomu(),
				localida.getLocopa(), localida.getLonombre(),
				localida.getLonrcopo(), localida.getLocodigo());
		return localida;
	}

	/**
	 * Finds a single row in the Localida table.
	 * 
	 * @param localida
	 *            Pagination
	 * @return Localida
	 */
	@Transactional(readOnly = true)
	public Localida find(Localida localida) {
		String query = "SELECT t1.LOCODIGO LOCODIGO, t1.CODLOCALID CODLOCALID, t1.LOCOPV LOCOPV, t1.LOCOMU LOCOMU, t1.LOCOPA LOCOPA, t1.LONOMBRE LONOMBRE, t1.LONRCOPO LONRCOPO "
				+ "FROM LOCALIDA t1  " + "WHERE t1.LOCODIGO = ?    ";
		return (Localida) this.jdbcTemplate.queryForObject(query, rwMap,
				localida.getLocodigo());
	}

	/**
	 * Removes a single row in the Localida table.
	 * 
	 * @param localida
	 *            Pagination
	 * @return
	 */
	public void remove(Localida localida) {
		String query = "DELETE  FROM LOCALIDA WHERE LOCODIGO=?";
		this.jdbcTemplate.update(query, localida.getLocodigo());
	}

	/**
	 * Finds a List of rows in the Localida table.
	 * 
	 * @param localida
	 *            Localida
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Localida> findAll(Localida localida, Pagination pagination) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.LOCODIGO LOCODIGO,t1.CODLOCALID CODLOCALID,t1.LOCOPV LOCOPV,t1.LOCOMU LOCOMU,t1.LOCOPA LOCOPA,t1.LONOMBRE LONOMBRE,t1.LONRCOPO LONRCOPO "
						+ "FROM LOCALIDA t1 ");

		if (localida != null && localida.getLocodigo() != null) {
			where.append(" AND t1.LOCODIGO = ?");
			params.add(localida.getLocodigo());
		}
		if (localida != null && localida.getCodlocalid() != null) {
			where.append(" AND t1.CODLOCALID = ?");
			params.add(localida.getCodlocalid());
		}
		if (localida != null && localida.getLocopv() != null) {
			where.append(" AND t1.LOCOPV = ?");
			params.add(localida.getLocopv());
		}
		if (localida != null && localida.getLocomu() != null) {
			where.append(" AND t1.LOCOMU = ?");
			params.add(localida.getLocomu());
		}
		if (localida != null && localida.getLocopa() != null) {
			where.append(" AND t1.LOCOPA = ?");
			params.add(localida.getLocopa());
		}
		if (localida != null && localida.getLonombre() != null) {
			where.append(" AND t1.LONOMBRE = ?");
			params.add(localida.getLonombre());
		}
		if (localida != null && localida.getLonrcopo() != null) {
			where.append(" AND t1.LONRCOPO = ?");
			params.add(localida.getLonrcopo());
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Localida>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Counts rows in the Localida table.
	 * 
	 * @param localida
	 *            Localida
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Localida localida) {

		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1  ");

		StringBuffer query = new StringBuffer(
				"SELECT COUNT(1) FROM  LOCALIDA t1  ");
		if (localida != null && localida.getLocodigo() != null) {
			where.append(" AND t1.LOCODIGO = ?");
			params.add(localida.getLocodigo());
		}
		if (localida != null && localida.getCodlocalid() != null) {
			where.append(" AND t1.CODLOCALID = ?");
			params.add(localida.getCodlocalid());
		}
		if (localida != null && localida.getLocopv() != null) {
			where.append(" AND t1.LOCOPV = ?");
			params.add(localida.getLocopv());
		}
		if (localida != null && localida.getLocomu() != null) {
			where.append(" AND t1.LOCOMU = ?");
			params.add(localida.getLocomu());
		}
		if (localida != null && localida.getLocopa() != null) {
			where.append(" AND t1.LOCOPA = ?");
			params.add(localida.getLocopa());
		}
		if (localida != null && localida.getLonombre() != null) {
			where.append(" AND t1.LONOMBRE = ?");
			params.add(localida.getLonombre());
		}
		if (localida != null && localida.getLonrcopo() != null) {
			where.append(" AND t1.LONRCOPO = ?");
			params.add(localida.getLonrcopo());
		}
		query.append(where);
		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());
	}

	/**
	 * Finds rows in the Localida table using like.
	 * 
	 * @param localida
	 *            Localida
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Localida> findAllLike(Localida localida, Pagination pagination,
			Boolean startsWith) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.LOCODIGO LOCODIGO,t1.CODLOCALID CODLOCALID,t1.LOCOPV LOCOPV,t1.LOCOMU LOCOMU,t1.LOCOPA LOCOPA,t1.LONOMBRE LONOMBRE,t1.LONRCOPO LONRCOPO "
						+ "FROM LOCALIDA t1 ");

		if (localida != null && localida.getLocodigo() != null) {
			where.append(" AND UPPER(t1.LOCODIGO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(localida.getLocodigo().toUpperCase() + "%");
			} else {
				params.add("%" + localida.getLocodigo().toUpperCase() + "%");
			}
			where.append(" AND t1.LOCODIGO IS NOT NULL");
		}
		if (localida != null && localida.getCodlocalid() != null) {
			where.append(" AND UPPER(t1.CODLOCALID) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(localida.getCodlocalid().toUpperCase() + "%");
			} else {
				params.add("%" + localida.getCodlocalid().toUpperCase() + "%");
			}
			where.append(" AND t1.CODLOCALID IS NOT NULL");
		}
		if (localida != null && localida.getLocopv() != null) {
			where.append(" AND UPPER(t1.LOCOPV) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(localida.getLocopv().toUpperCase() + "%");
			} else {
				params.add("%" + localida.getLocopv().toUpperCase() + "%");
			}
			where.append(" AND t1.LOCOPV IS NOT NULL");
		}
		if (localida != null && localida.getLocomu() != null) {
			where.append(" AND UPPER(t1.LOCOMU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(localida.getLocomu().toUpperCase() + "%");
			} else {
				params.add("%" + localida.getLocomu().toUpperCase() + "%");
			}
			where.append(" AND t1.LOCOMU IS NOT NULL");
		}
		if (localida != null && localida.getLocopa() != null) {
			where.append(" AND UPPER(t1.LOCOPA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(localida.getLocopa().toUpperCase() + "%");
			} else {
				params.add("%" + localida.getLocopa().toUpperCase() + "%");
			}
			where.append(" AND t1.LOCOPA IS NOT NULL");
		}
		if (localida != null && localida.getLonombre() != null) {
			where.append(" AND UPPER(t1.LONOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(localida.getLonombre().toUpperCase() + "%");
			} else {
				params.add("%" + localida.getLonombre().toUpperCase() + "%");
			}
			where.append(" AND t1.LONOMBRE IS NOT NULL");
		}
		if (localida != null && localida.getLonrcopo() != null) {
			where.append(" AND UPPER(t1.LONRCOPO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(localida.getLonrcopo().toUpperCase() + "%");
			} else {
				params.add("%" + localida.getLonrcopo().toUpperCase() + "%");
			}
			where.append(" AND t1.LONRCOPO IS NOT NULL");
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Localida>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}
}
