package com.ejie.y38a.dao;

import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.PaginationManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.constantes.Y38aEstablecAdheConstantes;
import com.ejie.y38a.model.Municipi;

/**
 * * MunicipiDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class MunicipiDaoImpl implements MunicipiDao {
	private SimpleJdbcTemplate jdbcTemplate;
	private RowMapper<Municipi> rwMap = new RowMapper<Municipi>() {
		public Municipi mapRow(ResultSet resultSet, int rowNum)
				throws SQLException {
			return new Municipi(resultSet.getString("MUCODIGO"),
					resultSet.getString("MUNOMBRE"),
					resultSet.getString("MUCOMU"),
					resultSet.getString("MUCOPV"));
		}
	};

	/**
	 * Method use to set the datasource.
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new SimpleJdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the Municipi table.
	 * 
	 * @param municipi
	 *            Pagination
	 * @return Municipi
	 */
	public Municipi add(Municipi municipi) {

		String query = "INSERT INTO MUNICIPI( MUCODIGO,MUNOMBRE,MUCOMU,MUCOPV)"
				+ "VALUES (?,?,?,?)";

		this.jdbcTemplate.update(query, municipi.getMucodigo(),
				municipi.getMunombre(), municipi.getMucomu(),
				municipi.getMucopv());
		return municipi;
	}

	/**
	 * Updates a single row in the Municipi table.
	 * 
	 * @param municipi
	 *            Pagination
	 * @return Municipi
	 */
	public Municipi update(Municipi municipi) {
		String query = "UPDATE MUNICIPI SET MUNOMBRE=?,MUCOMU=?,MUCOPV=? WHERE MUCODIGO=?";
		this.jdbcTemplate.update(query, municipi.getMunombre(),
				municipi.getMucomu(), municipi.getMucopv(),
				municipi.getMucodigo());
		return municipi;
	}

	/**
	 * Finds a single row in the Municipi table.
	 * 
	 * @param municipi
	 *            Pagination
	 * @return Municipi
	 */
	@Transactional(readOnly = true)
	public Municipi find(Municipi municipi) {
		String query = "SELECT t1.MUCODIGO MUCODIGO, t1.MUNOMBRE MUNOMBRE, t1.MUCOMU MUCOMU, t1.MUCOPV MUCOPV "
				+ "FROM MUNICIPI t1  " + "WHERE t1.MUCODIGO = ?    ";
		return (Municipi) this.jdbcTemplate.queryForObject(query, rwMap,
				municipi.getMucodigo());
	}

	/**
	 * Removes a single row in the Municipi table.
	 * 
	 * @param municipi
	 *            Pagination
	 * @return
	 */
	public void remove(Municipi municipi) {
		String query = "DELETE  FROM MUNICIPI WHERE MUCODIGO=?";
		this.jdbcTemplate.update(query, municipi.getMucodigo());
	}

	/**
	 * Finds a List of rows in the Municipi table.
	 * 
	 * @param municipi
	 *            Municipi
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Municipi> findAll(Municipi municipi, Pagination pagination) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.MUCODIGO MUCODIGO,t1.MUNOMBRE MUNOMBRE,t1.MUCOMU MUCOMU,t1.MUCOPV MUCOPV "
						+ "FROM MUNICIPI t1 ");

		if (municipi != null && municipi.getMucodigo() != null) {
			where.append(" AND t1.MUCODIGO = ?");
			params.add(municipi.getMucodigo());
		}
		if (municipi != null && municipi.getMunombre() != null) {
			where.append(" AND t1.MUNOMBRE = ?");
			params.add(municipi.getMunombre());
		}
		if (municipi != null && municipi.getMucomu() != null) {
			where.append(" AND t1.MUCOMU = ?");
			params.add(municipi.getMucomu());
		}
		if (municipi != null && municipi.getMucopv() != null) {
			if ("XX".equals(municipi.getMucopv())) {
				where.append(" AND t1.MUCOPV NOT IN ('01','20','48')");
			} else {
				where.append(" AND t1.MUCOPV = ?");
				params.add(municipi.getMucopv());
			}
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Municipi>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Counts rows in the Municipi table.
	 * 
	 * @param municipi
	 *            Municipi
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Municipi municipi) {

		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1  ");

		StringBuffer query = new StringBuffer(
				"SELECT COUNT(1) FROM  MUNICIPI t1  ");
		if (municipi != null && municipi.getMucodigo() != null) {
			where.append(" AND t1.MUCODIGO = ?");
			params.add(municipi.getMucodigo());
		}
		if (municipi != null && municipi.getMunombre() != null) {
			where.append(" AND t1.MUNOMBRE = ?");
			params.add(municipi.getMunombre());
		}
		if (municipi != null && municipi.getMucomu() != null) {
			where.append(" AND t1.MUCOMU = ?");
			params.add(municipi.getMucomu());
		}
		if (municipi != null && municipi.getMucopv() != null) {
			where.append(" AND t1.MUCOPV = ?");
			params.add(municipi.getMucopv());
		}
		query.append(where);
		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());
	}

	/**
	 * Finds rows in the Municipi table using like.
	 * 
	 * @param municipi
	 *            Municipi
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Municipi> findAllLike(Municipi municipi, Pagination pagination,
			Boolean startsWith) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.MUCODIGO MUCODIGO,t1.MUNOMBRE MUNOMBRE,t1.MUCOMU MUCOMU,t1.MUCOPV MUCOPV "
						+ "FROM MUNICIPI t1 ");

		if (municipi != null && municipi.getMucodigo() != null) {
			where.append(" AND UPPER(t1.MUCODIGO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(municipi.getMucodigo().toUpperCase() + "%");
			} else {
				params.add("%" + municipi.getMucodigo().toUpperCase() + "%");
			}
			where.append(" AND t1.MUCODIGO IS NOT NULL");
		}
		if (municipi != null && municipi.getMunombre() != null) {
			where.append(" AND UPPER(t1.MUNOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(municipi.getMunombre().toUpperCase() + "%");
			} else {
				params.add("%" + municipi.getMunombre().toUpperCase() + "%");
			}
			where.append(" AND t1.MUNOMBRE IS NOT NULL");
		}
		if (municipi != null && municipi.getMucomu() != null) {
			where.append(" AND UPPER(t1.MUCOMU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(municipi.getMucomu().toUpperCase() + "%");
			} else {
				params.add("%" + municipi.getMucomu().toUpperCase() + "%");
			}
			where.append(" AND t1.MUCOMU IS NOT NULL");
		}
		if (municipi != null && municipi.getMucopv() != null) {
			where.append(" AND UPPER(t1.MUCOPV) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(municipi.getMucopv().toUpperCase() + "%");
			} else {
				params.add("%" + municipi.getMucopv().toUpperCase() + "%");
			}
			where.append(" AND t1.MUCOPV IS NOT NULL");
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Municipi>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}
}
