package com.ejie.y38a.dao;

import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.PaginationManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.constantes.Y38aEstablecAdheConstantes;
import com.ejie.y38a.model.Paisesto;

/**
 * * PaisestoDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class PaisestoDaoImpl implements PaisestoDao {
	private SimpleJdbcTemplate jdbcTemplate;
	private RowMapper<Paisesto> rwMap = new RowMapper<Paisesto>() {
		public Paisesto mapRow(ResultSet resultSet, int rowNum)
				throws SQLException {
			return new Paisesto(resultSet.getString("PACODIGO"),
					resultSet.getString("PACOAL2"),
					resultSet.getString("PACOAL3"),
					resultSet.getString("PANOMBRE"));
		}
	};

	/**
	 * Method use to set the datasource.
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new SimpleJdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the Paisesto table.
	 * 
	 * @param paisesto
	 *            Pagination
	 * @return Paisesto
	 */
	public Paisesto add(Paisesto paisesto) {

		String query = "INSERT INTO PAISESTO( PACODIGO,PACOAL2,PACOAL3,PANOMBRE)"
				+ "VALUES (?,?,?,?)";

		this.jdbcTemplate.update(query, paisesto.getPacodigo(),
				paisesto.getPacoal2(), paisesto.getPacoal3(),
				paisesto.getPanombre());
		return paisesto;
	}

	/**
	 * Updates a single row in the Paisesto table.
	 * 
	 * @param paisesto
	 *            Pagination
	 * @return Paisesto
	 */
	public Paisesto update(Paisesto paisesto) {
		String query = "UPDATE PAISESTO SET PACOAL2=?,PACOAL3=?,PANOMBRE=? WHERE PACODIGO=?";
		this.jdbcTemplate.update(query, paisesto.getPacoal2(),
				paisesto.getPacoal3(), paisesto.getPanombre(),
				paisesto.getPacodigo());
		return paisesto;
	}

	/**
	 * Finds a single row in the Paisesto table.
	 * 
	 * @param paisesto
	 *            Pagination
	 * @return Paisesto
	 */
	@Transactional(readOnly = true)
	public Paisesto find(Paisesto paisesto) {
		String query = "SELECT t1.PACODIGO PACODIGO, t1.PACOAL2 PACOAL2, t1.PACOAL3 PACOAL3, t1.PANOMBRE PANOMBRE "
				+ "FROM PAISESTO t1  " + "WHERE t1.PACODIGO = ?    ";
		return (Paisesto) this.jdbcTemplate.queryForObject(query, rwMap,
				paisesto.getPacodigo());
	}

	/**
	 * Removes a single row in the Paisesto table.
	 * 
	 * @param paisesto
	 *            Pagination
	 * @return
	 */
	public void remove(Paisesto paisesto) {
		String query = "DELETE  FROM PAISESTO WHERE PACODIGO=?";
		this.jdbcTemplate.update(query, paisesto.getPacodigo());
	}

	/**
	 * Finds a List of rows in the Paisesto table.
	 * 
	 * @param paisesto
	 *            Paisesto
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Paisesto> findAll(Paisesto paisesto, Pagination pagination) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.PACODIGO PACODIGO,t1.PACOAL2 PACOAL2,t1.PACOAL3 PACOAL3,t1.PANOMBRE PANOMBRE "
						+ "FROM PAISESTO t1 ");

		if (paisesto != null && paisesto.getPacodigo() != null) {
			where.append(" AND t1.PACODIGO = ?");
			params.add(paisesto.getPacodigo());
		}
		if (paisesto != null && paisesto.getPacoal2() != null) {
			where.append(" AND t1.PACOAL2 = ?");
			params.add(paisesto.getPacoal2());
		}
		if (paisesto != null && paisesto.getPacoal3() != null) {
			where.append(" AND t1.PACOAL3 = ?");
			params.add(paisesto.getPacoal3());
		}
		if (paisesto != null && paisesto.getPanombre() != null) {
			where.append(" AND t1.PANOMBRE = ?");
			params.add(paisesto.getPanombre());
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Paisesto>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Counts rows in the Paisesto table.
	 * 
	 * @param paisesto
	 *            Paisesto
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Paisesto paisesto) {

		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1  ");

		StringBuffer query = new StringBuffer(
				"SELECT COUNT(1) FROM  PAISESTO t1  ");
		if (paisesto != null && paisesto.getPacodigo() != null) {
			where.append(" AND t1.PACODIGO = ?");
			params.add(paisesto.getPacodigo());
		}
		if (paisesto != null && paisesto.getPacoal2() != null) {
			where.append(" AND t1.PACOAL2 = ?");
			params.add(paisesto.getPacoal2());
		}
		if (paisesto != null && paisesto.getPacoal3() != null) {
			where.append(" AND t1.PACOAL3 = ?");
			params.add(paisesto.getPacoal3());
		}
		if (paisesto != null && paisesto.getPanombre() != null) {
			where.append(" AND t1.PANOMBRE = ?");
			params.add(paisesto.getPanombre());
		}
		query.append(where);
		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());
	}

	/**
	 * Finds rows in the Paisesto table using like.
	 * 
	 * @param paisesto
	 *            Paisesto
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Paisesto> findAllLike(Paisesto paisesto, Pagination pagination,
			Boolean startsWith) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.PACODIGO PACODIGO,t1.PACOAL2 PACOAL2,t1.PACOAL3 PACOAL3,t1.PANOMBRE PANOMBRE "
						+ "FROM PAISESTO t1 ");

		if (paisesto != null && paisesto.getPacodigo() != null) {
			where.append(" AND UPPER(t1.PACODIGO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(paisesto.getPacodigo().toUpperCase() + "%");
			} else {
				params.add("%" + paisesto.getPacodigo().toUpperCase() + "%");
			}
			where.append(" AND t1.PACODIGO IS NOT NULL");
		}
		if (paisesto != null && paisesto.getPacoal2() != null) {
			where.append(" AND UPPER(t1.PACOAL2) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(paisesto.getPacoal2().toUpperCase() + "%");
			} else {
				params.add("%" + paisesto.getPacoal2().toUpperCase() + "%");
			}
			where.append(" AND t1.PACOAL2 IS NOT NULL");
		}
		if (paisesto != null && paisesto.getPacoal3() != null) {
			where.append(" AND UPPER(t1.PACOAL3) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(paisesto.getPacoal3().toUpperCase() + "%");
			} else {
				params.add("%" + paisesto.getPacoal3().toUpperCase() + "%");
			}
			where.append(" AND t1.PACOAL3 IS NOT NULL");
		}
		if (paisesto != null && paisesto.getPanombre() != null) {
			where.append(" AND UPPER(t1.PANOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(paisesto.getPanombre().toUpperCase() + "%");
			} else {
				params.add("%" + paisesto.getPanombre().toUpperCase() + "%");
			}
			where.append(" AND t1.PANOMBRE IS NOT NULL");
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Paisesto>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}
}
