package com.ejie.y38a.dao;

import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.PaginationManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.constantes.Y38aEstablecAdheConstantes;
import com.ejie.y38a.model.Provinci;

/**
 * * ProvinciDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ProvinciDaoImpl implements ProvinciDao {
	private SimpleJdbcTemplate jdbcTemplate;
	private RowMapper<Provinci> rwMap = new RowMapper<Provinci>() {
		public Provinci mapRow(ResultSet resultSet, int rowNum)
				throws SQLException {
			return new Provinci(resultSet.getString("PVCODIGO"),
					resultSet.getString("PVNOMBRE"),
					resultSet.getString("PVCOCA"),
					resultSet.getString("PVCOMA"),
					resultSet.getString("PVNRPRTE"),
					resultSet.getString("PVNOCA"));
		}
	};

	/**
	 * Method use to set the datasource.
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new SimpleJdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the Provinci table.
	 * 
	 * @param provinci
	 *            Pagination
	 * @return Provinci
	 */
	public Provinci add(Provinci provinci) {

		String query = "INSERT INTO PROVINCI( PVCODIGO,PVNOMBRE,PVCOCA,PVCOMA,PVNRPRTE,PVNOCA)"
				+ "VALUES (?,?,?,?,?,?)";

		this.jdbcTemplate.update(query, provinci.getPvcodigo(),
				provinci.getPvnombre(), provinci.getPvcoca(),
				provinci.getPvcoma(), provinci.getPvnrprte(),
				provinci.getPvnoca());
		return provinci;
	}

	/**
	 * Updates a single row in the Provinci table.
	 * 
	 * @param provinci
	 *            Pagination
	 * @return Provinci
	 */
	public Provinci update(Provinci provinci) {
		String query = "UPDATE PROVINCI SET PVNOMBRE=?,PVCOCA=?,PVCOMA=?,PVNRPRTE=?,PVNOCA=? WHERE PVCODIGO=?";
		this.jdbcTemplate.update(query, provinci.getPvnombre(),
				provinci.getPvcoca(), provinci.getPvcoma(),
				provinci.getPvnrprte(), provinci.getPvnoca(),
				provinci.getPvcodigo());
		return provinci;
	}

	/**
	 * Finds a single row in the Provinci table.
	 * 
	 * @param provinci
	 *            Pagination
	 * @return Provinci
	 */
	@Transactional(readOnly = true)
	public Provinci find(Provinci provinci) {
		String query = "SELECT t1.PVCODIGO PVCODIGO, t1.PVNOMBRE PVNOMBRE, t1.PVCOCA PVCOCA, t1.PVCOMA PVCOMA, t1.PVNRPRTE PVNRPRTE, t1.PVNOCA PVNOCA "
				+ "FROM PROVINCI t1  " + "WHERE t1.PVCODIGO = ?    ";
		return (Provinci) this.jdbcTemplate.queryForObject(query, rwMap,
				provinci.getPvcodigo());
	}

	/**
	 * Removes a single row in the Provinci table.
	 * 
	 * @param provinci
	 *            Pagination
	 * @return
	 */
	public void remove(Provinci provinci) {
		String query = "DELETE  FROM PROVINCI WHERE PVCODIGO=?";
		this.jdbcTemplate.update(query, provinci.getPvcodigo());
	}

	/**
	 * Finds a List of rows in the Provinci table.
	 * 
	 * @param provinci
	 *            Provinci
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Provinci> findAll(Provinci provinci, Pagination pagination) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.PVCODIGO PVCODIGO,t1.PVNOMBRE PVNOMBRE,t1.PVCOCA PVCOCA,t1.PVCOMA PVCOMA,t1.PVNRPRTE PVNRPRTE,t1.PVNOCA PVNOCA "
						+ "FROM PROVINCI t1 ");

		if (provinci != null && provinci.getPvcodigo() != null) {
			where.append(" AND t1.PVCODIGO = ?");
			params.add(provinci.getPvcodigo());
		}
		if (provinci != null && provinci.getPvnombre() != null) {
			where.append(" AND t1.PVNOMBRE = ?");
			params.add(provinci.getPvnombre());
		}
		if (provinci != null && provinci.getPvcoca() != null) {
			where.append(" AND t1.PVCOCA = ?");
			params.add(provinci.getPvcoca());
		}
		if (provinci != null && provinci.getPvcoma() != null) {
			where.append(" AND t1.PVCOMA = ?");
			params.add(provinci.getPvcoma());
		}
		if (provinci != null && provinci.getPvnrprte() != null) {
			where.append(" AND t1.PVNRPRTE = ?");
			params.add(provinci.getPvnrprte());
		}
		if (provinci != null && provinci.getPvnoca() != null) {
			where.append(" AND t1.PVNOCA = ?");
			params.add(provinci.getPvnoca());
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Provinci>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Counts rows in the Provinci table.
	 * 
	 * @param provinci
	 *            Provinci
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Provinci provinci) {

		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1  ");

		StringBuffer query = new StringBuffer(
				"SELECT COUNT(1) FROM  PROVINCI t1  ");
		if (provinci != null && provinci.getPvcodigo() != null) {
			where.append(" AND t1.PVCODIGO = ?");
			params.add(provinci.getPvcodigo());
		}
		if (provinci != null && provinci.getPvnombre() != null) {
			where.append(" AND t1.PVNOMBRE = ?");
			params.add(provinci.getPvnombre());
		}
		if (provinci != null && provinci.getPvcoca() != null) {
			where.append(" AND t1.PVCOCA = ?");
			params.add(provinci.getPvcoca());
		}
		if (provinci != null && provinci.getPvcoma() != null) {
			where.append(" AND t1.PVCOMA = ?");
			params.add(provinci.getPvcoma());
		}
		if (provinci != null && provinci.getPvnrprte() != null) {
			where.append(" AND t1.PVNRPRTE = ?");
			params.add(provinci.getPvnrprte());
		}
		if (provinci != null && provinci.getPvnoca() != null) {
			where.append(" AND t1.PVNOCA = ?");
			params.add(provinci.getPvnoca());
		}
		query.append(where);
		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());
	}

	/**
	 * Finds rows in the Provinci table using like.
	 * 
	 * @param provinci
	 *            Provinci
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Provinci> findAllLike(Provinci provinci, Pagination pagination,
			Boolean startsWith) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.PVCODIGO PVCODIGO,t1.PVNOMBRE PVNOMBRE,t1.PVCOCA PVCOCA,t1.PVCOMA PVCOMA,t1.PVNRPRTE PVNRPRTE,t1.PVNOCA PVNOCA "
						+ "FROM PROVINCI t1 ");

		if (provinci != null && provinci.getPvcodigo() != null) {
			where.append(" AND UPPER(t1.PVCODIGO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(provinci.getPvcodigo().toUpperCase() + "%");
			} else {
				params.add("%" + provinci.getPvcodigo().toUpperCase() + "%");
			}
			where.append(" AND t1.PVCODIGO IS NOT NULL");
		}
		if (provinci != null && provinci.getPvnombre() != null) {
			where.append(" AND UPPER(t1.PVNOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(provinci.getPvnombre().toUpperCase() + "%");
			} else {
				params.add("%" + provinci.getPvnombre().toUpperCase() + "%");
			}
			where.append(" AND t1.PVNOMBRE IS NOT NULL");
		}
		if (provinci != null && provinci.getPvcoca() != null) {
			where.append(" AND UPPER(t1.PVCOCA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(provinci.getPvcoca().toUpperCase() + "%");
			} else {
				params.add("%" + provinci.getPvcoca().toUpperCase() + "%");
			}
			where.append(" AND t1.PVCOCA IS NOT NULL");
		}
		if (provinci != null && provinci.getPvcoma() != null) {
			where.append(" AND UPPER(t1.PVCOMA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(provinci.getPvcoma().toUpperCase() + "%");
			} else {
				params.add("%" + provinci.getPvcoma().toUpperCase() + "%");
			}
			where.append(" AND t1.PVCOMA IS NOT NULL");
		}
		if (provinci != null && provinci.getPvnrprte() != null) {
			where.append(" AND UPPER(t1.PVNRPRTE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(provinci.getPvnrprte().toUpperCase() + "%");
			} else {
				params.add("%" + provinci.getPvnrprte().toUpperCase() + "%");
			}
			where.append(" AND t1.PVNRPRTE IS NOT NULL");
		}
		if (provinci != null && provinci.getPvnoca() != null) {
			where.append(" AND UPPER(t1.PVNOCA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(provinci.getPvnoca().toUpperCase() + "%");
			} else {
				params.add("%" + provinci.getPvnoca().toUpperCase() + "%");
			}
			where.append(" AND t1.PVNOCA IS NOT NULL");
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Provinci>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}
}
