package com.ejie.y38a.dao;

import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.PaginationManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.constantes.Y38aEstablecAdheConstantes;
import com.ejie.y38a.model.Secagrup;

/**
 * * SecagrupDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class SecagrupDaoImpl implements SecagrupDao {
	private SimpleJdbcTemplate jdbcTemplate;
	private RowMapper<Secagrup> rwMap = new RowMapper<Secagrup>() {
		public Secagrup mapRow(ResultSet resultSet, int rowNum)
				throws SQLException {
			return new Secagrup(resultSet.getString("L0CODIGO"),
					resultSet.getString("L0NOMBRE"),
					resultSet.getString("L0NOMBREE"),
					resultSet.getString("L0NOMBREI"),
					resultSet.getString("L0NOMBREF"));
		}
	};

	/**
	 * Method use to set the datasource.
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new SimpleJdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the Secagrup table.
	 * 
	 * @param secagrup
	 *            Pagination
	 * @return Secagrup
	 */
	public Secagrup add(Secagrup secagrup) {

		String query = "INSERT INTO SECAGRUP( L0CODIGO,L0NOMBRE,L0NOMBREE,L0NOMBREI,L0NOMBREF)"
				+ "VALUES (?,?,?,?,?)";

		this.jdbcTemplate.update(query, secagrup.getL0codigo(),
				secagrup.getL0nombre(), secagrup.getL0nombree(),
				secagrup.getL0nombrei(), secagrup.getL0nombref());
		return secagrup;
	}

	/**
	 * Updates a single row in the Secagrup table.
	 * 
	 * @param secagrup
	 *            Pagination
	 * @return Secagrup
	 */
	public Secagrup update(Secagrup secagrup) {
		String query = "UPDATE SECAGRUP SET L0NOMBRE=?,L0NOMBREE=?,L0NOMBREI=?,L0NOMBREF=? WHERE L0CODIGO=?";
		this.jdbcTemplate.update(query, secagrup.getL0nombre(),
				secagrup.getL0nombree(), secagrup.getL0nombrei(),
				secagrup.getL0nombref(), secagrup.getL0codigo());
		return secagrup;
	}

	/**
	 * Finds a single row in the Secagrup table.
	 * 
	 * @param secagrup
	 *            Pagination
	 * @return Secagrup
	 */
	@Transactional(readOnly = true)
	public Secagrup find(Secagrup secagrup) {
		String query = "SELECT t1.L0CODIGO L0CODIGO, t1.L0NOMBRE L0NOMBRE, t1.L0NOMBREE L0NOMBREE, t1.L0NOMBREI L0NOMBREI, t1.L0NOMBREF L0NOMBREF "
				+ "FROM SECAGRUP t1  " + "WHERE t1.L0CODIGO = ?    ";
		return (Secagrup) this.jdbcTemplate.queryForObject(query, rwMap,
				secagrup.getL0codigo());
	}

	/**
	 * Removes a single row in the Secagrup table.
	 * 
	 * @param secagrup
	 *            Pagination
	 * @return
	 */
	public void remove(Secagrup secagrup) {
		String query = "DELETE  FROM SECAGRUP WHERE L0CODIGO=?";
		this.jdbcTemplate.update(query, secagrup.getL0codigo());
	}

	/**
	 * Finds a List of rows in the Secagrup table.
	 * 
	 * @param secagrup
	 *            Secagrup
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Secagrup> findAll(Secagrup secagrup, Pagination pagination) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.L0CODIGO L0CODIGO,t1.L0NOMBRE L0NOMBRE,t1.L0NOMBREE L0NOMBREE,t1.L0NOMBREI L0NOMBREI,t1.L0NOMBREF L0NOMBREF "
						+ "FROM SECAGRUP t1 ");

		if (secagrup != null && secagrup.getL0codigo() != null) {
			where.append(" AND t1.L0CODIGO = ?");
			params.add(secagrup.getL0codigo());
		}

		if (secagrup != null && secagrup.getL0nombre() != null) {
			where.append(" AND TRANSLATE(UPPER(t1.L0NOMBRE),'','AEIOU') like ? ESCAPE  '\\'");
			params.add("%"
					+ secagrup.getL0nombre().toUpperCase().replaceAll("", "A")
							.replaceAll("", "E").replaceAll("", "I")
							.replaceAll("", "O").replaceAll("", "U") + "%");
			where.append(" AND t1.L0NOMBRE IS NOT NULL");
		}

		if (secagrup != null && secagrup.getL0nombree() != null) {
			where.append(" AND TRANSLATE(UPPER(t1.L0NOMBREE),'','AEIOU') like ? ESCAPE  '\\'");
			params.add("%"
					+ secagrup.getL0nombree().toUpperCase()
							.replaceAll("", "A").replaceAll("", "E")
							.replaceAll("", "I").replaceAll("", "O")
							.replaceAll("", "U") + "%");

			where.append(" AND t1.L0NOMBREE IS NOT NULL");
		}

		if (secagrup != null && secagrup.getL0nombrei() != null) {
			where.append(" AND TRANSLATE(UPPER(t1.L0NOMBREI),'','AEIOU') like ? ESCAPE  '\\'");
			params.add("%"
					+ secagrup.getL0nombree().toUpperCase()
							.replaceAll("", "A").replaceAll("", "E")
							.replaceAll("", "I").replaceAll("", "O")
							.replaceAll("", "U") + "%");

			where.append(" AND t1.L0NOMBREI IS NOT NULL");
		}

		if (secagrup != null && secagrup.getL0nombref() != null) {
			where.append(" AND TRANSLATE(UPPER(t1.L0NOMBREF),'','AEIOU') like ? ESCAPE  '\\'");
			params.add("%"
					+ secagrup.getL0nombree().toUpperCase()
							.replaceAll("", "A").replaceAll("", "E")
							.replaceAll("", "I").replaceAll("", "O")
							.replaceAll("", "U") + "%");

			where.append(" AND t1.L0NOMBREF IS NOT NULL");
		}

		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Secagrup>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Counts rows in the Secagrup table.
	 * 
	 * @param secagrup
	 *            Secagrup
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Secagrup secagrup) {

		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1  ");

		StringBuffer query = new StringBuffer(
				"SELECT COUNT(1) FROM  SECAGRUP t1  ");
		if (secagrup != null && secagrup.getL0codigo() != null) {
			where.append(" AND t1.L0CODIGO = ?");
			params.add(secagrup.getL0codigo());
		}
		if (secagrup != null && secagrup.getL0nombre() != null) {
			where.append(" AND t1.L0NOMBRE = ?");
			params.add(secagrup.getL0nombre());
		}
		if (secagrup != null && secagrup.getL0nombree() != null) {
			where.append(" AND t1.L0NOMBREE = ?");
			params.add(secagrup.getL0nombree());
		}
		if (secagrup != null && secagrup.getL0nombrei() != null) {
			where.append(" AND t1.L0NOMBREI = ?");
			params.add(secagrup.getL0nombrei());
		}
		if (secagrup != null && secagrup.getL0nombref() != null) {
			where.append(" AND t1.L0NOMBREF = ?");
			params.add(secagrup.getL0nombref());
		}
		query.append(where);
		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());
	}

	/**
	 * Finds rows in the Secagrup table using like.
	 * 
	 * @param secagrup
	 *            Secagrup
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Secagrup> findAllLike(Secagrup secagrup, Pagination pagination,
			Boolean startsWith) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.L0CODIGO L0CODIGO,t1.L0NOMBRE L0NOMBRE,t1.L0NOMBREE L0NOMBREE,t1.L0NOMBREI L0NOMBREI,t1.L0NOMBREF L0NOMBREF "
						+ "FROM SECAGRUP t1 ");

		if (secagrup != null && secagrup.getL0codigo() != null) {
			where.append(" AND UPPER(t1.L0CODIGO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(secagrup.getL0codigo().toUpperCase() + "%");
			} else {
				params.add("%" + secagrup.getL0codigo().toUpperCase() + "%");
			}
			where.append(" AND t1.L0CODIGO IS NOT NULL");
		}
		if (secagrup != null && secagrup.getL0nombre() != null) {
			where.append(" AND UPPER(t1.L0NOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(secagrup.getL0nombre().toUpperCase() + "%");
			} else {
				params.add("%" + secagrup.getL0nombre().toUpperCase() + "%");
			}
			where.append(" AND t1.L0NOMBRE IS NOT NULL");
		}
		if (secagrup != null && secagrup.getL0nombree() != null) {
			where.append(" AND UPPER(t1.L0NOMBREE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(secagrup.getL0nombree().toUpperCase() + "%");
			} else {
				params.add("%" + secagrup.getL0nombree().toUpperCase() + "%");
			}
			where.append(" AND t1.L0NOMBREE IS NOT NULL");
		}
		if (secagrup != null && secagrup.getL0nombrei() != null) {
			where.append(" AND UPPER(t1.L0NOMBREI) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(secagrup.getL0nombrei().toUpperCase() + "%");
			} else {
				params.add("%" + secagrup.getL0nombrei().toUpperCase() + "%");
			}
			where.append(" AND t1.L0NOMBREI IS NOT NULL");
		}
		if (secagrup != null && secagrup.getL0nombref() != null) {
			where.append(" AND UPPER(t1.L0NOMBREF) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(secagrup.getL0nombref().toUpperCase() + "%");
			} else {
				params.add("%" + secagrup.getL0nombref().toUpperCase() + "%");
			}
			where.append(" AND t1.L0NOMBREF IS NOT NULL");
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Secagrup>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}
}
