package com.ejie.y38a.dao;

import com.ejie.x38.dto.Pagination;
import com.ejie.x38.util.PaginationManager;
import com.ejie.y38a.constantes.Y38aEstablecAdheConstantes;
import com.ejie.y38a.model.Secagrup;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;

import javax.annotation.Resource;
import javax.sql.DataSource;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.model.Sectores;
import com.ejie.y38a.utils.Y38aUtils;

/**
 * * SectoresDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class SectoresDaoImpl implements SectoresDao {
	private SimpleJdbcTemplate jdbcTemplate;
	private RowMapper<Sectores> rwMap = new RowMapper<Sectores>() {
		public Sectores mapRow(ResultSet resultSet, int rowNum)
				throws SQLException {
			return new Sectores(resultSet.getString("SECODIGO"),
					resultSet.getString("SENOMBRE"),
					resultSet.getString("SENOCO"),
					resultSet.getString("SEDESCRI"),
					resultSet.getString("SECOSE"),
					resultSet.getString("SENOCO2"),
					resultSet.getString("SEINSEL1"),
					resultSet.getString("SENOMBREE"),
					resultSet.getString("SENOMBREI"),
					resultSet.getString("SENOMBREF"),
					resultSet.getString("SENOCOE"),
					resultSet.getString("SENOCOI"),
					resultSet.getString("SENOCOF"),
					resultSet.getString("SEDESCRIE"),
					resultSet.getString("SEDESCRII"),
					resultSet.getString("SEDESCRIF"),
					resultSet.getString("SENOMBREA"),
					resultSet.getString("SEDESCRIA"),
					resultSet.getString("SENOCOA"), new Secagrup(
							resultSet.getString("SecagrupL0CODIGO"),
							resultSet.getString("SecagrupL0NOMBRE"),
							resultSet.getString("SecagrupL0NOMBREE"),
							resultSet.getString("SecagrupL0NOMBREI"),
							resultSet.getString("SecagrupL0NOMBREF")),
					new Secagrup(resultSet.getString("SecagrupL0CODIGO"),
							resultSet.getString("SecagrupL0NOMBRE"), resultSet
									.getString("SecagrupL0NOMBREE"), resultSet
									.getString("SecagrupL0NOMBREI"), resultSet
									.getString("SecagrupL0NOMBREF")));
		}
	};

	/**
	 * Method use to set the datasource.
	 * 
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new SimpleJdbcTemplate(dataSource);
	}

	/**
	 * Inserts a single row in the Sectores table.
	 * 
	 * @param sectores
	 *            Pagination
	 * @return Sectores
	 */
	public Sectores add(Sectores sectores) {

		String query = "INSERT INTO SECTORES( SECODIGO,SECOL0,SECODGRUPO,SENOMBRE,SENOCO,SEDESCRI,SECOSE,SENOCO2,SEINSEL1,SENOMBREE,SENOMBREI,SENOMBREF,SENOCOE,SENOCOI,SENOCOF,SEDESCRIE,SEDESCRII,SEDESCRIF,SENOMBREA,SEDESCRIA,SENOCOA)"
				+ "VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";

		Object getSecagrupBySecol0L0codigoAux = null;
		if (sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0codigo() != null) {
			getSecagrupBySecol0L0codigoAux = sectores.getSecagrupBySecol0()
					.getL0codigo();
		}
		Object getSecagrupBySecodgrupoL0codigoAux = null;
		if (sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0codigo() != null) {
			getSecagrupBySecodgrupoL0codigoAux = sectores
					.getSecagrupBySecodgrupo().getL0codigo();
		}
		this.jdbcTemplate.update(query, sectores.getSecodigo(),
				getSecagrupBySecol0L0codigoAux,
				getSecagrupBySecodgrupoL0codigoAux, sectores.getSenombre(),
				sectores.getSenoco(), sectores.getSedescri(),
				sectores.getSecose(), sectores.getSenoco2(),
				sectores.getSeinsel1(), sectores.getSenombree(),
				sectores.getSenombrei(), sectores.getSenombref(),
				sectores.getSenocoe(), sectores.getSenocoi(),
				sectores.getSenocof(), sectores.getSedescrie(),
				sectores.getSedescrii(), sectores.getSedescrif(),
				sectores.getSenombrea(), sectores.getSedescria(),
				sectores.getSenocoa());
		return sectores;
	}

	/**
	 * Updates a single row in the Sectores table.
	 * 
	 * @param sectores
	 *            Pagination
	 * @return Sectores
	 */
	public Sectores update(Sectores sectores) {
		String query = "UPDATE SECTORES SET SECOL0=?,SECODGRUPO=?,SENOMBRE=?,SENOCO=?,SEDESCRI=?,SECOSE=?,SENOCO2=?,SEINSEL1=?,SENOMBREE=?,SENOMBREI=?,SENOMBREF=?,SENOCOE=?,SENOCOI=?,SENOCOF=?,SEDESCRIE=?,SEDESCRII=?,SEDESCRIF=?,SENOMBREA=?,SEDESCRIA=?,SENOCOA=? WHERE SECODIGO=?";
		Object getSecagrupBySecol0L0codigoAux = null;
		if (sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0codigo() != null) {
			getSecagrupBySecol0L0codigoAux = sectores.getSecagrupBySecol0()
					.getL0codigo();
		}
		Object getSecagrupBySecodgrupoL0codigoAux = null;
		if (sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0codigo() != null) {
			getSecagrupBySecodgrupoL0codigoAux = sectores
					.getSecagrupBySecodgrupo().getL0codigo();
		}
		this.jdbcTemplate.update(query, getSecagrupBySecol0L0codigoAux,
				getSecagrupBySecodgrupoL0codigoAux, sectores.getSenombre(),
				sectores.getSenoco(), sectores.getSedescri(),
				sectores.getSecose(), sectores.getSenoco2(),
				sectores.getSeinsel1(), sectores.getSenombree(),
				sectores.getSenombrei(), sectores.getSenombref(),
				sectores.getSenocoe(), sectores.getSenocoi(),
				sectores.getSenocof(), sectores.getSedescrie(),
				sectores.getSedescrii(), sectores.getSedescrif(),
				sectores.getSenombrea(), sectores.getSedescria(),
				sectores.getSenocoa(), sectores.getSecodigo());
		return sectores;
	}

	/**
	 * Finds a single row in the Sectores table.
	 * 
	 * @param sectores
	 *            Pagination
	 * @return Sectores
	 */
	@Transactional(readOnly = true)
	public Sectores find(Sectores sectores) {
		String query = "SELECT t1.SECODIGO SECODIGO, t1.SENOMBRE SENOMBRE, t1.SENOCO SENOCO, t1.SEDESCRI SEDESCRI, t1.SECOSE SECOSE, t1.SENOCO2 SENOCO2, t1.SEINSEL1 SEINSEL1, t1.SENOMBREE SENOMBREE, t1.SENOMBREI SENOMBREI, t1.SENOMBREF SENOMBREF, t1.SENOCOE SENOCOE, t1.SENOCOI SENOCOI, t1.SENOCOF SENOCOF, t1.SEDESCRIE SEDESCRIE, t1.SEDESCRII SEDESCRII, t1.SEDESCRIF SEDESCRIF, t1.SENOMBREA SENOMBREA, t1.SEDESCRIA SEDESCRIA, t1.SENOCOA SENOCOA, t2.L0CODIGO SECAGRUPL0CODIGO, t2.L0NOMBRE SECAGRUPL0NOMBRE, t2.L0NOMBREE SECAGRUPL0NOMBREE, t2.L0NOMBREI SECAGRUPL0NOMBREI, t2.L0NOMBREF SECAGRUPL0NOMBREF, t3.L0CODIGO SECAGRUPL0CODIGO1, t3.L0NOMBRE SECAGRUPL0NOMBRE1, t3.L0NOMBREE SECAGRUPL0NOMBREE1, t3.L0NOMBREI SECAGRUPL0NOMBREI1, t3.L0NOMBREF SECAGRUPL0NOMBREF1 "
				+ "FROM SECTORES t1 , SECAGRUP t2 , SECAGRUP t3  "
				+ "WHERE t1.SECODIGO = ?   AND t1.SECOL0= t2.L0CODIGO(+) AND t1.SECODGRUPO= t3.L0CODIGO(+)  ";
		return (Sectores) this.jdbcTemplate.queryForObject(query, rwMap,
				sectores.getSecodigo());
	}

	/**
	 * Removes a single row in the Sectores table.
	 * 
	 * @param sectores
	 *            Pagination
	 * @return
	 */
	public void remove(Sectores sectores) {
		String query = "DELETE  FROM SECTORES WHERE SECODIGO=?";
		this.jdbcTemplate.update(query, sectores.getSecodigo());
	}

	/**
	 * Finds a List of rows in the Sectores table.
	 * 
	 * @param sectores
	 *            Sectores
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Sectores> findAll(Sectores sectores, Pagination pagination) {
		String transformacion = "";
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 AND t1.SECOL0= t2.L0CODIGO(+) AND t1.SECODGRUPO= t3.L0CODIGO(+) 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.SECODIGO SECODIGO,t1.SENOMBRE SENOMBRE,t1.SENOCO SENOCO,t1.SEDESCRI SEDESCRI,t1.SECOSE SECOSE,t1.SENOCO2 SENOCO2,t1.SEINSEL1 SEINSEL1,t1.SENOMBREE SENOMBREE,t1.SENOMBREI SENOMBREI,t1.SENOMBREF SENOMBREF,t1.SENOCOE SENOCOE,t1.SENOCOI SENOCOI,t1.SENOCOF SENOCOF,t1.SEDESCRIE SEDESCRIE,t1.SEDESCRII SEDESCRII,t1.SEDESCRIF SEDESCRIF,t1.SENOMBREA SENOMBREA,t1.SEDESCRIA SEDESCRIA,t1.SENOCOA SENOCOA,t2.L0CODIGO SECAGRUPL0CODIGO,t2.L0NOMBRE SECAGRUPL0NOMBRE,t2.L0NOMBREE SECAGRUPL0NOMBREE,t2.L0NOMBREI SECAGRUPL0NOMBREI,t2.L0NOMBREF SECAGRUPL0NOMBREF,t3.L0CODIGO SECAGRUPL0CODIGO1,t3.L0NOMBRE SECAGRUPL0NOMBRE1,t3.L0NOMBREE SECAGRUPL0NOMBREE1,t3.L0NOMBREI SECAGRUPL0NOMBREI1,t3.L0NOMBREF SECAGRUPL0NOMBREF1 "
						+ "FROM SECTORES t1 ,SECAGRUP t2 ,SECAGRUP t3 ");

		if (sectores != null && sectores.getSecodigo() != null) {
			where.append(" AND UPPER(t1.SECODIGO) like ? ESCAPE  '\\'");
			params.add("%" + sectores.getSecodigo().toUpperCase() + "%");
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0codigo() != null) {
			where.append(" AND t2.L0CODIGO = ?");
			params.add(sectores.getSecagrupBySecol0().getL0codigo());
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombre() != null) {
			where.append(" AND t2.L0NOMBRE = ?");
			params.add(sectores.getSecagrupBySecol0().getL0nombre());
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombree() != null) {
			where.append(" AND t2.L0NOMBREE = ?");
			params.add(sectores.getSecagrupBySecol0().getL0nombree());
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombrei() != null) {
			where.append(" AND t2.L0NOMBREI = ?");
			params.add(sectores.getSecagrupBySecol0().getL0nombrei());
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombref() != null) {
			where.append(" AND t2.L0NOMBREF = ?");
			params.add(sectores.getSecagrupBySecol0().getL0nombref());
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0codigo() != null) {
			where.append(" AND t3.L0CODIGO = ?");
			params.add(sectores.getSecagrupBySecodgrupo().getL0codigo());
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombre() != null) {
			where.append(" AND t3.L0NOMBRE = ?");
			params.add(sectores.getSecagrupBySecodgrupo().getL0nombre());
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombree() != null) {
			where.append(" AND t3.L0NOMBREE = ?");
			params.add(sectores.getSecagrupBySecodgrupo().getL0nombree());
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombrei() != null) {
			where.append(" AND t3.L0NOMBREI = ?");
			params.add(sectores.getSecagrupBySecodgrupo().getL0nombrei());
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombref() != null) {
			where.append(" AND t3.L0NOMBREF = ?");
			params.add(sectores.getSecagrupBySecodgrupo().getL0nombref());
		}
		if (sectores != null && sectores.getSenombre() != null) {
			String label = "'ÁÉÍÓÚÀÈÌÒÙÜ'";
			Properties prop = Y38aUtils
					.loadProperties(Y38aEstablecAdheConstantes.CONFIG_PATH);
			String local = (String) prop
					.getProperty("y38aVistaWar.entorno.local");
			if ("true".equals(local)) {
				transformacion = label;
			} else {
				transformacion = Y38aUtils.convertToUTF8(label);
			}
			where.append(" AND TRANSLATE(TRIM(UPPER(t1.SENOMBRE)),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU')");
			where.append(" LIKE ");
			where.append(" TRANSLATE(TRIM(UPPER(");
			where.append("'%");
			where.append(sectores.getSenombre());
			where.append("%'");
			where.append(")),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU') ");
		}
		if (sectores != null && sectores.getSenoco() != null) {
			where.append(" AND t1.SENOCO = ?");
			params.add(sectores.getSenoco());
		}
		if (sectores != null && sectores.getSedescri() != null) {
			where.append(" AND UPPER(t1.SEDESCRI) like ? ESCAPE  '\\'");
			params.add("%" + sectores.getSedescri().toUpperCase() + "%");
		}
		if (sectores != null && sectores.getSecose() != null) {
			where.append(" AND t1.SECOSE = ?");
			params.add(sectores.getSecose());
		}
		if (sectores != null && sectores.getSenoco2() != null) {
			where.append(" AND t1.SENOCO2 = ?");
			params.add(sectores.getSenoco2());
		}
		if (sectores != null && sectores.getSeinsel1() != null
				&& "S".equals(sectores.getSeinsel1())) {
			where.append(" AND t1.SEINSEL1 = ?");
			params.add(sectores.getSeinsel1());
		}
		if (sectores != null && sectores.getSenombree() != null) {
			where.append(" AND t1.SENOMBREE = ?");
			params.add(sectores.getSenombree());
		}
		if (sectores != null && sectores.getSenombrei() != null) {
			where.append(" AND t1.SENOMBREI = ?");
			params.add(sectores.getSenombrei());
		}
		if (sectores != null && sectores.getSenombref() != null) {
			where.append(" AND t1.SENOMBREF = ?");
			params.add(sectores.getSenombref());
		}
		if (sectores != null && sectores.getSenocoe() != null) {
			where.append(" AND t1.SENOCOE = ?");
			params.add(sectores.getSenocoe());
		}
		if (sectores != null && sectores.getSenocoi() != null) {
			where.append(" AND t1.SENOCOI = ?");
			params.add(sectores.getSenocoi());
		}
		if (sectores != null && sectores.getSenocof() != null) {
			where.append(" AND t1.SENOCOF = ?");
			params.add(sectores.getSenocof());
		}
		if (sectores != null && sectores.getSedescrie() != null) {
			where.append(" AND t1.SEDESCRIE = ?");
			params.add(sectores.getSedescrie());
		}
		if (sectores != null && sectores.getSedescrii() != null) {
			where.append(" AND t1.SEDESCRII = ?");
			params.add(sectores.getSedescrii());
		}
		if (sectores != null && sectores.getSedescrif() != null) {
			where.append(" AND t1.SEDESCRIF = ?");
			params.add(sectores.getSedescrif());
		}
		if (sectores != null && sectores.getSenombrea() != null) {
			where.append(" AND t1.SENOMBREA = ?");
			params.add(sectores.getSenombrea());
		}
		if (sectores != null && sectores.getSedescria() != null) {
			where.append(" AND t1.SEDESCRIA = ?");
			params.add(sectores.getSedescria());
		}
		if (sectores != null && sectores.getSenocoa() != null) {
			where.append(" AND t1.SENOCOA = ?");
			params.add(sectores.getSenocoa());
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Sectores>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}

	/**
	 * Counts rows in the Sectores table.
	 * 
	 * @param sectores
	 *            Sectores
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Sectores sectores) {
		String transformacion = "";
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1  and t1.SECOL0= t2.L0CODIGO(+) and t1.SECODGRUPO= t3.L0CODIGO(+) ");

		StringBuffer query = new StringBuffer(
				"SELECT COUNT(1) FROM  SECTORES t1   ,  SECAGRUP t2   ,  SECAGRUP t3  ");
		if (sectores != null && sectores.getSecodigo() != null) {
			where.append(" AND UPPER(t1.SECODIGO) like ? ESCAPE  '\\'");
			params.add("%" + sectores.getSecodigo().toUpperCase() + "%");
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0codigo() != null) {
			where.append(" AND t2.L0CODIGO = ?");
			params.add(sectores.getSecagrupBySecol0().getL0codigo());
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombre() != null) {
			where.append(" AND t2.L0NOMBRE = ?");
			params.add(sectores.getSecagrupBySecol0().getL0nombre());
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombree() != null) {
			where.append(" AND t2.L0NOMBREE = ?");
			params.add(sectores.getSecagrupBySecol0().getL0nombree());
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombrei() != null) {
			where.append(" AND t2.L0NOMBREI = ?");
			params.add(sectores.getSecagrupBySecol0().getL0nombrei());
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombref() != null) {
			where.append(" AND t2.L0NOMBREF = ?");
			params.add(sectores.getSecagrupBySecol0().getL0nombref());
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0codigo() != null) {
			where.append(" AND t3.L0CODIGO = ?");
			params.add(sectores.getSecagrupBySecodgrupo().getL0codigo());
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombre() != null) {
			where.append(" AND t3.L0NOMBRE = ?");
			params.add(sectores.getSecagrupBySecodgrupo().getL0nombre());
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombree() != null) {
			where.append(" AND t3.L0NOMBREE = ?");
			params.add(sectores.getSecagrupBySecodgrupo().getL0nombree());
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombrei() != null) {
			where.append(" AND t3.L0NOMBREI = ?");
			params.add(sectores.getSecagrupBySecodgrupo().getL0nombrei());
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombref() != null) {
			where.append(" AND t3.L0NOMBREF = ?");
			params.add(sectores.getSecagrupBySecodgrupo().getL0nombref());
		}
		if (sectores != null && sectores.getSenombre() != null) {
			String label = "'ÁÉÍÓÚÀÈÌÒÙÜ'";

			Properties prop = Y38aUtils
					.loadProperties(Y38aEstablecAdheConstantes.CONFIG_PATH);
			String local = (String) prop
					.getProperty("y38aVistaWar.entorno.local");
			if ("true".equals(local)) {
				transformacion = label;
			} else {
				transformacion = Y38aUtils.convertToUTF8(label);
			}

			where.append(" AND TRANSLATE(TRIM(UPPER(t1.SENOMBRE)),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU')");
			where.append(" LIKE ");
			where.append(" TRANSLATE(TRIM(UPPER(");
			where.append("'%");
			where.append(sectores.getSenombre());
			where.append("%'");
			where.append(")),");
			where.append(transformacion);
			where.append(",'AEIOUAEIOUU') ");

			where.append(" AND t1.SENOMBRE IS NOT NULL");
		}
		if (sectores != null && sectores.getSenoco() != null) {
			where.append(" AND t1.SENOCO = ?");
			params.add(sectores.getSenoco());
		}
		if (sectores != null && sectores.getSedescri() != null) {
			where.append(" AND UPPER(t1.SEDESCRI) like ? ESCAPE  '\\'");
			params.add("%" + sectores.getSedescri().toUpperCase() + "%");
		}
		if (sectores != null && sectores.getSecose() != null) {
			where.append(" AND t1.SECOSE = ?");
			params.add(sectores.getSecose());
		}
		if (sectores != null && sectores.getSenoco2() != null) {
			where.append(" AND t1.SENOCO2 = ?");
			params.add(sectores.getSenoco2());
		}
		if (sectores != null && sectores.getSeinsel1() != null
				&& "S".equals(sectores.getSeinsel1())) {
			where.append(" AND t1.SEINSEL1 = ?");
			params.add(sectores.getSeinsel1());
		}
		if (sectores != null && sectores.getSenombree() != null) {
			where.append(" AND t1.SENOMBREE = ?");
			params.add(sectores.getSenombree());
		}
		if (sectores != null && sectores.getSenombrei() != null) {
			where.append(" AND t1.SENOMBREI = ?");
			params.add(sectores.getSenombrei());
		}
		if (sectores != null && sectores.getSenombref() != null) {
			where.append(" AND t1.SENOMBREF = ?");
			params.add(sectores.getSenombref());
		}
		if (sectores != null && sectores.getSenocoe() != null) {
			where.append(" AND t1.SENOCOE = ?");
			params.add(sectores.getSenocoe());
		}
		if (sectores != null && sectores.getSenocoi() != null) {
			where.append(" AND t1.SENOCOI = ?");
			params.add(sectores.getSenocoi());
		}
		if (sectores != null && sectores.getSenocof() != null) {
			where.append(" AND t1.SENOCOF = ?");
			params.add(sectores.getSenocof());
		}
		if (sectores != null && sectores.getSedescrie() != null) {
			where.append(" AND t1.SEDESCRIE = ?");
			params.add(sectores.getSedescrie());
		}
		if (sectores != null && sectores.getSedescrii() != null) {
			where.append(" AND t1.SEDESCRII = ?");
			params.add(sectores.getSedescrii());
		}
		if (sectores != null && sectores.getSedescrif() != null) {
			where.append(" AND t1.SEDESCRIF = ?");
			params.add(sectores.getSedescrif());
		}
		if (sectores != null && sectores.getSenombrea() != null) {
			where.append(" AND t1.SENOMBREA = ?");
			params.add(sectores.getSenombrea());
		}
		if (sectores != null && sectores.getSedescria() != null) {
			where.append(" AND t1.SEDESCRIA = ?");
			params.add(sectores.getSedescria());
		}
		if (sectores != null && sectores.getSenocoa() != null) {
			where.append(" AND t1.SENOCOA = ?");
			params.add(sectores.getSenocoa());
		}
		query.append(where);
		return this.jdbcTemplate.queryForLong(query.toString(),
				params.toArray());
	}

	/**
	 * Finds rows in the Sectores table using like.
	 * 
	 * @param sectores
	 *            Sectores
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<Sectores> findAllLike(Sectores sectores, Pagination pagination,
			Boolean startsWith) {
		StringBuffer where = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		List<Object> params = new ArrayList<Object>();
		where.append(" WHERE 1=1 AND t1.SECOL0= t2.L0CODIGO(+) AND t1.SECODGRUPO= t3.L0CODIGO(+) 	");

		StringBuffer query = new StringBuffer(
				"SELECT  t1.SECODIGO SECODIGO,t1.SENOMBRE SENOMBRE,t1.SENOCO SENOCO,t1.SEDESCRI SEDESCRI,t1.SECOSE SECOSE,t1.SENOCO2 SENOCO2,t1.SEINSEL1 SEINSEL1,t1.SENOMBREE SENOMBREE,t1.SENOMBREI SENOMBREI,t1.SENOMBREF SENOMBREF,t1.SENOCOE SENOCOE,t1.SENOCOI SENOCOI,t1.SENOCOF SENOCOF,t1.SEDESCRIE SEDESCRIE,t1.SEDESCRII SEDESCRII,t1.SEDESCRIF SEDESCRIF,t1.SENOMBREA SENOMBREA,t1.SEDESCRIA SEDESCRIA,t1.SENOCOA SENOCOA,t2.L0CODIGO SECAGRUPL0CODIGO,t2.L0NOMBRE SECAGRUPL0NOMBRE,t2.L0NOMBREE SECAGRUPL0NOMBREE,t2.L0NOMBREI SECAGRUPL0NOMBREI,t2.L0NOMBREF SECAGRUPL0NOMBREF,t3.L0CODIGO SECAGRUPL0CODIGO1,t3.L0NOMBRE SECAGRUPL0NOMBRE1,t3.L0NOMBREE SECAGRUPL0NOMBREE1,t3.L0NOMBREI SECAGRUPL0NOMBREI1,t3.L0NOMBREF SECAGRUPL0NOMBREF1 "
						+ "FROM SECTORES t1 ,SECAGRUP t2 ,SECAGRUP t3 ");

		if (sectores != null && sectores.getSecodigo() != null) {
			where.append(" AND UPPER(t1.SECODIGO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecodigo().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSecodigo().toUpperCase() + "%");
			}
			where.append(" AND t1.SECODIGO IS NOT NULL");
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0codigo() != null) {
			where.append(" AND t2.L0CODIGO like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecagrupBySecol0().getL0codigo() + "%");
			} else {
				params.add("%" + sectores.getSecagrupBySecol0().getL0codigo()
						+ "%");
			}
			where.append(" AND t2.L0CODIGO IS NOT NULL");
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombre() != null) {
			where.append(" AND UPPER(t2.L0NOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecagrupBySecol0().getL0nombre()
						.toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ sectores.getSecagrupBySecol0().getL0nombre()
								.toUpperCase() + "%");
			}
			where.append(" AND t2.L0NOMBRE IS NOT NULL");
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombree() != null) {
			where.append(" AND UPPER(t2.L0NOMBREE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecagrupBySecol0().getL0nombree()
						.toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ sectores.getSecagrupBySecol0().getL0nombree()
								.toUpperCase() + "%");
			}
			where.append(" AND t2.L0NOMBREE IS NOT NULL");
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombrei() != null) {
			where.append(" AND UPPER(t2.L0NOMBREI) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecagrupBySecol0().getL0nombrei()
						.toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ sectores.getSecagrupBySecol0().getL0nombrei()
								.toUpperCase() + "%");
			}
			where.append(" AND t2.L0NOMBREI IS NOT NULL");
		}
		if (sectores != null && sectores.getSecagrupBySecol0() != null
				&& sectores.getSecagrupBySecol0().getL0nombref() != null) {
			where.append(" AND UPPER(t2.L0NOMBREF) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecagrupBySecol0().getL0nombref()
						.toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ sectores.getSecagrupBySecol0().getL0nombref()
								.toUpperCase() + "%");
			}
			where.append(" AND t2.L0NOMBREF IS NOT NULL");
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0codigo() != null) {
			where.append(" AND t3.L0CODIGO like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecagrupBySecodgrupo().getL0codigo()
						+ "%");
			} else {
				params.add("%"
						+ sectores.getSecagrupBySecodgrupo().getL0codigo()
						+ "%");
			}
			where.append(" AND t3.L0CODIGO IS NOT NULL");
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombre() != null) {
			where.append(" AND UPPER(t3.L0NOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecagrupBySecodgrupo().getL0nombre()
						.toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ sectores.getSecagrupBySecodgrupo().getL0nombre()
								.toUpperCase() + "%");
			}
			where.append(" AND t3.L0NOMBRE IS NOT NULL");
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombree() != null) {
			where.append(" AND UPPER(t3.L0NOMBREE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecagrupBySecodgrupo().getL0nombree()
						.toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ sectores.getSecagrupBySecodgrupo().getL0nombree()
								.toUpperCase() + "%");
			}
			where.append(" AND t3.L0NOMBREE IS NOT NULL");
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombrei() != null) {
			where.append(" AND UPPER(t3.L0NOMBREI) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecagrupBySecodgrupo().getL0nombrei()
						.toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ sectores.getSecagrupBySecodgrupo().getL0nombrei()
								.toUpperCase() + "%");
			}
			where.append(" AND t3.L0NOMBREI IS NOT NULL");
		}
		if (sectores != null && sectores.getSecagrupBySecodgrupo() != null
				&& sectores.getSecagrupBySecodgrupo().getL0nombref() != null) {
			where.append(" AND UPPER(t3.L0NOMBREF) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecagrupBySecodgrupo().getL0nombref()
						.toUpperCase()
						+ "%");
			} else {
				params.add("%"
						+ sectores.getSecagrupBySecodgrupo().getL0nombref()
								.toUpperCase() + "%");
			}
			where.append(" AND t3.L0NOMBREF IS NOT NULL");
		}
		if (sectores != null && sectores.getSenombre() != null) {
			where.append(" AND UPPER(t1.SENOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenombre().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenombre().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOMBRE IS NOT NULL");
		}
		if (sectores != null && sectores.getSenoco() != null) {
			where.append(" AND UPPER(t1.SENOCO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenoco().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenoco().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOCO IS NOT NULL");
		}
		if (sectores != null && sectores.getSedescri() != null) {
			where.append(" AND UPPER(t1.SEDESCRI) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSedescri().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSedescri().toUpperCase() + "%");
			}
			where.append(" AND t1.SEDESCRI IS NOT NULL");
		}
		if (sectores != null && sectores.getSecose() != null) {
			where.append(" AND UPPER(t1.SECOSE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSecose().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSecose().toUpperCase() + "%");
			}
			where.append(" AND t1.SECOSE IS NOT NULL");
		}
		if (sectores != null && sectores.getSenoco2() != null) {
			where.append(" AND UPPER(t1.SENOCO2) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenoco2().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenoco2().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOCO2 IS NOT NULL");
		}
		if (sectores != null && sectores.getSeinsel1() != null) {
			where.append(" AND UPPER(t1.SEINSEL1) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSeinsel1().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSeinsel1().toUpperCase() + "%");
			}
			where.append(" AND t1.SEINSEL1 IS NOT NULL");
		}
		if (sectores != null && sectores.getSenombree() != null) {
			where.append(" AND UPPER(t1.SENOMBREE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenombree().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenombree().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOMBREE IS NOT NULL");
		}
		if (sectores != null && sectores.getSenombrei() != null) {
			where.append(" AND UPPER(t1.SENOMBREI) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenombrei().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenombrei().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOMBREI IS NOT NULL");
		}
		if (sectores != null && sectores.getSenombref() != null) {
			where.append(" AND UPPER(t1.SENOMBREF) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenombref().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenombref().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOMBREF IS NOT NULL");
		}
		if (sectores != null && sectores.getSenocoe() != null) {
			where.append(" AND UPPER(t1.SENOCOE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenocoe().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenocoe().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOCOE IS NOT NULL");
		}
		if (sectores != null && sectores.getSenocoi() != null) {
			where.append(" AND UPPER(t1.SENOCOI) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenocoi().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenocoi().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOCOI IS NOT NULL");
		}
		if (sectores != null && sectores.getSenocof() != null) {
			where.append(" AND UPPER(t1.SENOCOF) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenocof().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenocof().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOCOF IS NOT NULL");
		}
		if (sectores != null && sectores.getSedescrie() != null) {
			where.append(" AND UPPER(t1.SEDESCRIE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSedescrie().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSedescrie().toUpperCase() + "%");
			}
			where.append(" AND t1.SEDESCRIE IS NOT NULL");
		}
		if (sectores != null && sectores.getSedescrii() != null) {
			where.append(" AND UPPER(t1.SEDESCRII) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSedescrii().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSedescrii().toUpperCase() + "%");
			}
			where.append(" AND t1.SEDESCRII IS NOT NULL");
		}
		if (sectores != null && sectores.getSedescrif() != null) {
			where.append(" AND UPPER(t1.SEDESCRIF) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSedescrif().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSedescrif().toUpperCase() + "%");
			}
			where.append(" AND t1.SEDESCRIF IS NOT NULL");
		}
		if (sectores != null && sectores.getSenombrea() != null) {
			where.append(" AND UPPER(t1.SENOMBREA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenombrea().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenombrea().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOMBREA IS NOT NULL");
		}
		if (sectores != null && sectores.getSedescria() != null) {
			where.append(" AND UPPER(t1.SEDESCRIA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSedescria().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSedescria().toUpperCase() + "%");
			}
			where.append(" AND t1.SEDESCRIA IS NOT NULL");
		}
		if (sectores != null && sectores.getSenocoa() != null) {
			where.append(" AND UPPER(t1.SENOCOA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(sectores.getSenocoa().toUpperCase() + "%");
			} else {
				params.add("%" + sectores.getSenocoa().toUpperCase() + "%");
			}
			where.append(" AND t1.SENOCOA IS NOT NULL");
		}
		query.append(where);

		StringBuffer order = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (pagination != null) {
			if (pagination.getSort() != null) {
				order.append(" ORDER BY " + pagination.getSort() + " "
						+ pagination.getAscDsc());
				query.append(order);
			}
			query = new StringBuffer(PaginationManager.getQueryLimits(
					pagination, query.toString()));
		}
		return (List<Sectores>) this.jdbcTemplate.query(query.toString(),
				rwMap, params.toArray());
	}
}
