package com.ejie.y38a.service;
import com.ejie.x38.dto.Pagination;
import com.ejie.y38a.dao.AdheestaDao;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.model.Adheesta;

/**
 *  * AdheestaServiceImpl  
 *  
 */

@Service(value = "adheestaService")
public  class AdheestaServiceImpl implements AdheestaService {

	private static final  Logger logger = LoggerFactory.getLogger(AdheestaServiceImpl.class);
	@Autowired
	private AdheestaDao adheestaDao;

	/**
	 * Inserts a single row in the Adheesta table.
	 *
	 * @param adheesta Adheesta
	 * @return Adheesta
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Adheesta add(Adheesta adheesta) {
		return this.adheestaDao.add(adheesta);
	}

	/**
	 * Updates a single row in the Adheesta table.
	 *
	 * @param adheesta Adheesta
	 * @return Adheesta
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Adheesta update(Adheesta adheesta) {
		return this.adheestaDao.update(adheesta);
	 }

	/**
	 * Finds a single row in the Adheesta table.
	 *
	 * @param adheesta Adheesta
	 * @return Adheesta
	 */
	public Adheesta find(Adheesta adheesta) {
		return (Adheesta) this.adheestaDao.find(adheesta);
	}

	/**
	 * Finds a List of rows in the Adheesta table.
	 *
	 * @param adheesta Adheesta
	 * @param pagination Pagination
	 * @return List
	 */
	public List<Adheesta> findAll(Adheesta adheesta, Pagination pagination) {
		return (List<Adheesta>) this.adheestaDao.findAll(adheesta, pagination);
	}
    
	/**
	 * Counts rows in the Adheesta table.
	 *
	 * @param adheesta Adheesta
	 * @return Long
	 */
	public Long findAllCount(Adheesta adheesta) {        
		return  this.adheestaDao.findAllCount(adheesta);
	}

	/**
	 * Finds rows in the Adheesta table using like.
	 *
	 * @param adheesta Adheesta
	 * @param pagination Pagination
	 * @param startsWith Boolean
	 * @return List
	 */
	public List<Adheesta> findAllLike(Adheesta adheesta, Pagination pagination, Boolean startsWith) {
		return (List<Adheesta>) this.adheestaDao.findAllLike(adheesta, pagination, startsWith);
	}
    
	/**
	 * Deletes a single row in the Adheesta table.
	 *
	 * @param adheesta Adheesta
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Adheesta adheesta) {
		this.adheestaDao.remove(adheesta);
	}
	
	/**
	 * Deletes multiple rows in the Adheesta table.
	 *
	 * @param adheestaList ArrayList
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeMultiple(ArrayList<Adheesta> adheestaList) {
		for (Adheesta  adheestaAux:adheestaList) {
			this.adheestaDao.remove(adheestaAux);
		}
	}


	/**
	 * Getter method for AdheestaDao
	 *
	 * @return AdheestaDao
	 */
	public AdheestaDao getAdheestaDao() {
		return this.adheestaDao;
	}
    
	/**
	 * Setter method for AdheestaDao.
	 *
	 * @param  adheestaDao AdheestaDao
	 * @return
	 */
	public void setAdheestaDao(AdheestaDao adheestaDao) {
		logger.info("Setting Dependency "+adheestaDao);
		this.adheestaDao = adheestaDao;
	}
}

