package com.ejie.y38a.service;

import com.ejie.x38.control.exception.ResourceNotFoundException;
import com.ejie.x38.dto.Pagination;
import com.ejie.y38a.constantes.Y38aEstablecAdheConstantes;
import com.ejie.y38a.dao.EstablecDao;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Properties;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.model.Establec;
import com.ejie.y38a.utils.Y38aSendMail;
import com.ejie.y38a.utils.Y38aUtils;
import com.ejie.y38a.utils.beans.MailItemBean;

/**
 * * EstablecServiceImpl  
 * 
 *  
 */

@Service(value = "establecService")
public class EstablecServiceImpl implements EstablecService {

	private static final Logger logger = LoggerFactory
			.getLogger(EstablecServiceImpl.class);
	@Autowired
	private EstablecDao establecDao;

	@Autowired()
	private Properties appConfiguration;

	@Resource
	private ReloadableResourceBundleMessageSource appMessageSource;

	/**
	 * Inserts a single row in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @return Establec
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Establec add(Establec establec) {
		return this.establecDao.add(establec);
	}

	/**
	 * Updates a single row in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @return Establec
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Establec update(Establec establec) {
		return this.establecDao.update(establec);
	}

	/**
	 * Finds a single row in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @return Establec
	 */
	public Establec find(Establec establec) {
		return (Establec) this.establecDao.find(establec);
	}

	/**
	 * Finds a single row in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @return Establec
	 */
	public Establec findEstablecimiento(Establec establec) {
		Establec estab = this.establecDao.findEstablecimiento(establec);
		Establec establecTemp = new Establec();// NOPMD NEcesario
		establecTemp = this.establecDao.findLimitaciones(estab, establec);
		estab.setLimitaciones(establecTemp.getLimitaciones());
		return estab;
	}

	/**
	 * Finds a List of rows in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @param pagination
	 *            Pagination
	 * @return List
	 */
	public List<Establec> findAll(Establec establec, Pagination pagination) {
		return (List<Establec>) this.establecDao.findAll(establec, pagination);
	}

	/**
	 * Counts rows in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @return Long
	 */
	public Long findAllCount(Establec establec) {
		return this.establecDao.findAllCount(establec);
	}

	/**
	 * Finds rows in the Establec table using like.
	 * 
	 * @param establec
	 *            Establec
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	public List<Establec> findAllLike(Establec establec, Pagination pagination,
			Boolean startsWith) {
		return (List<Establec>) this.establecDao.findAllLike(establec,
				pagination, startsWith);
	}

	/**
	 * Deletes a single row in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Establec establec) {
		this.establecDao.remove(establec);
	}

	/**
	 * Deletes multiple rows in the Establec table.
	 * 
	 * @param establecList
	 *            ArrayList
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeMultiple(ArrayList<Establec> establecList) {
		for (Establec establecAux : establecList) {
			this.establecDao.remove(establecAux);
		}
	}

	/**
	 * Getter method for EstablecDao
	 * 
	 * @return EstablecDao
	 */
	public EstablecDao getEstablecDao() {
		return this.establecDao;
	}

	/**
	 * Setter method for EstablecDao.
	 * 
	 * @param establecDao
	 *            EstablecDao
	 * @return
	 */
	public void setEstablecDao(EstablecDao establecDao) {
		logger.info("Setting Dependency " + establecDao);
		this.establecDao = establecDao;
	}

	@Override
	public Establec find(String esnif) {
		// TODO Auto-generated method stub
		return null;
	}

	/**
	 * Finds rows in the Establec table using like.
	 * 
	 * @param establec
	 *            Establec
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	public List<Establec> findAllLikeEstablec(Establec establec,
			Pagination pagination, Boolean startsWith) {
		List<Establec> listaEstablec = this.establecDao.findAllLikeEstablec(
				establec, pagination, startsWith);
		for (Establec estab : listaEstablec) {
			Establec establecTemp = new Establec();// NOPMD NEcesario
			establecTemp = this.establecDao.findLimitaciones(estab, establec);
			estab.setLimitaciones(establecTemp.getLimitaciones());
			if (estab.getAhfeba() != null) {
				estab.setEnArbitraje(false);
			} else {
				estab.setEnArbitraje(true);
			}
		}
		return listaEstablec;
	}

	/**
	 * Finds rows in the Establec table using like.
	 * 
	 * @param establec
	 *            Establec
	 * @param pagination
	 *            Pagination
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	public List<Establec> findAllLikeEstablecDistintivo(Establec establec,
			Pagination pagination, Boolean startsWith) {
		List<Establec> listaEstablec = this.establecDao
				.findAllLikeEstablecDistintivo(establec, pagination, startsWith);
		for (Establec estab : listaEstablec) {
			Establec establecTemp = new Establec();// NOPMD NEcesario
			establecTemp = this.establecDao.findLimitaciones(estab, establec);
			estab.setLimitaciones(establecTemp.getLimitaciones());
			if (estab.getAhfeba() != null) {
				estab.setEnArbitraje(false);
			} else {
				estab.setEnArbitraje(true);
			}
		}
		return listaEstablec;
	}

	/**
	 * Counts rows in the Establec table.
	 * 
	 * @param establec
	 *            Establec
	 * @return Long
	 */
	public Long findAllCountLikeEstablec(Establec establec) {
		return this.establecDao.findAllCountLikeEstablec(establec);
	}

	/**
	 * Envia por email la solicitud de distintivo.
	 * 
	 * @param establecDef
	 *            Establec
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void emailSolicitudDistintivo(Establec establecDef) {

		Properties prop = Y38aUtils
				.loadProperties(Y38aEstablecAdheConstantes.CONFIG_PATH);
		// Datos de cuenta de correo -Tomar del fichero properties
		String flag = prop
				.getProperty(Y38aEstablecAdheConstantes.ACTIVAR_CORREO);

		try {
			if ((Y38aEstablecAdheConstantes.UNO).equals(flag)) {

				StringBuffer asunto = new StringBuffer();
				StringBuffer cuerpo = new StringBuffer();

				// Idioma
				Locale locale = LocaleContextHolder.getLocale();
				// Castellano
				if ((Y38aEstablecAdheConstantes.CASTELLANO).equals(locale
						.getLanguage())) {

					asunto.append(appMessageSource.getMessage(
							"solicitud.distintivo.asunto", null, new Locale(
									Y38aEstablecAdheConstantes.CASTELLANO)));
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.datosEmpresa",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append("</B><BR>");
					cuerpo.append("<BR><BR>");
					// A PARTIR DE AQUI HAY QUE PONER LOS DATOS DE LA EMPRESA
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.cifnif",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append(" ").append(establecDef.getEsnif())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.fealta",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append(" ").append(establecDef.getEsfeadar())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.noco",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append(" ").append(establecDef.getEsnoco())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.raso",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append(" ").append(establecDef.getEsnombre())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.loca",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append(" ").append(establecDef.getLocalizacion())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.tele",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append(" ").append(establecDef.getEsnrtel())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.fax",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append(" ").append(establecDef.getEsnrfax())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.mail",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append(" ").append(establecDef.getEscoem())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.web",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append(" ").append(establecDef.getEsteurl())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.limi",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append(" ").append(establecDef.getLimitaciones())
							.append("</B><BR>");

					// ///
					cuerpo.append("<BR><BR><B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.uno",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append("</B><BR>");

					String URL_LOGOTIPO = Y38aUtils
							.normalizarVacio((String) this.appConfiguration
									.get("URL_LOGOTIPO"));

					cuerpo.append("<BR><BR><B>").append(URL_LOGOTIPO)
							.append("</B><BR>");

					cuerpo.append("<BR><BR><B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.dos",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append("</B><BR>");
					cuerpo.append("<BR><BR><B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.tres",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append("</B><BR>");

					String URL = Y38aUtils
							.normalizarVacio((String) this.appConfiguration
									.get("URL_BUSQUEDA_EMPRESAS"));
					// reemplazamos por el idioma y el cif
					URL = URL.replace("%XX%", establecDef.getEsnif());
					URL = URL.replace("%YY%",
							Y38aEstablecAdheConstantes.CASTELLANO);

					cuerpo.append("<BR><BR><B>").append(URL).append("</B><BR>");

					cuerpo.append("<BR><BR><B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.cuatro",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.CASTELLANO)))
							.append("</B><BR>");

					String URL_E = Y38aUtils
							.normalizarVacio((String) this.appConfiguration
									.get("URL_BUSQUEDA_EMPRESAS"));
					// reemplazamos por el idioma y el cif
					URL_E = URL_E.replace("%XX%", establecDef.getEsnif());
					URL_E = URL_E.replace("%YY%",
							Y38aEstablecAdheConstantes.EUSKERA);

					cuerpo.append("<BR><BR><B>").append(URL_E)
							.append("</B><BR>");

				} else {
					asunto.append(appMessageSource.getMessage(
							"solicitud.distintivo.asunto", null, new Locale(
									Y38aEstablecAdheConstantes.EUSKERA)));
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.uno",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append("</B><BR>");
					cuerpo.append("<BR><BR>");
					// A PARTIR DE AQUI HAY QUE PONER LOS DATOS DE LA EMPRESA
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.cifnif",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append(" ").append(establecDef.getEsnif())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.fealta",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append(" ").append(establecDef.getEsfeadar())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.noco",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append(" ").append(establecDef.getEsnoco())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.raso",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append(" ").append(establecDef.getEsnombre())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.loca",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append(" ").append(establecDef.getLocalizacion())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.tele",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append(" ").append(establecDef.getEsnrtel())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.fax",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append(" ").append(establecDef.getEsnrfax())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.mail",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append(" ").append(establecDef.getEscoem())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.web",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append(" ").append(establecDef.getEsteurl())
							.append("</B><BR>");
					cuerpo.append("<B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.limi",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append(" ").append(establecDef.getLimitaciones())
							.append("</B><BR>");

					// ///
					cuerpo.append("<BR><BR><B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.uno",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append("</B><BR>");

					String URL_LOGOTIPO = Y38aUtils
							.normalizarVacio((String) this.appConfiguration
									.get("URL_LOGOTIPO"));

					cuerpo.append("<BR><BR><B>").append(URL_LOGOTIPO)
							.append("</B><BR>");

					cuerpo.append("<BR><BR><B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.dos",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append("</B><BR>");

					cuerpo.append("<BR><BR><B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.tres",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append("</B><BR>");

					String URL = Y38aUtils
							.normalizarVacio((String) this.appConfiguration
									.get("URL_BUSQUEDA_EMPRESAS"));
					// reemplazamos por el idioma y el cif
					URL = URL.replace("%XX%", establecDef.getEsnif());
					URL = URL.replace("%YY%",
							Y38aEstablecAdheConstantes.CASTELLANO);

					cuerpo.append("<BR><BR><B>").append(URL).append("</B><BR>");

					cuerpo.append("<BR><BR><B>")
							.append(appMessageSource
									.getMessage(
											"solicitud.distintivo.cuerpo.cuatro",
											null,
											new Locale(
													Y38aEstablecAdheConstantes.EUSKERA)))
							.append("</B><BR>");

					String URL_E = Y38aUtils
							.normalizarVacio((String) this.appConfiguration
									.get("URL_BUSQUEDA_EMPRESAS"));
					// reemplazamos por el idioma y el cif
					URL_E = URL_E.replace("%XX%", establecDef.getEsnif());
					URL_E = URL_E.replace("%YY%",
							Y38aEstablecAdheConstantes.EUSKERA);

					cuerpo.append("<BR><BR><B>").append(URL_E)
							.append("</B><BR>");

				}

				MailItemBean mailItemBean = new MailItemBean();
				mailItemBean.setDestinatario(establecDef.getEscoem());
				// HAy que poner un asunto
				mailItemBean.setAsunto(asunto.toString());
				mailItemBean.setMensaje(cuerpo.toString());

				logger.info("#########Destinatario:########## "
						+ mailItemBean.getDestinatario());

				if (Y38aUtils.normalizarVacio(mailItemBean.getDestinatario())
						.length() == 0) {
					logger.info("mailItemBean.getDestinatario()"
							+ mailItemBean.getDestinatario());
					throw new ResourceNotFoundException(
							"Se presentaron errores al validar la entidad");
				} else {
					Y38aSendMail sendMail = new Y38aSendMail();
					sendMail.sendItem(mailItemBean);
				}

			}

		} catch (Exception e) {
			logger.info("" + e.getMessage());
			throw new ResourceNotFoundException(
					"Se presentaron errores al validar la entidad");
		}

	}

	@Override
	public Long findAllCountLikeEstablecDistintivo(Establec establec) {
		return this.establecDao.findAllCountLikeEstablecDistintivo(establec);
	}

}
