package com.ejie.y38a.service;
import com.ejie.x38.dto.Pagination;
import com.ejie.y38a.dao.EstasectDao;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.model.Estasect;

/**
 *  * EstasectServiceImpl  
 *  
 */

@Service(value = "estasectService")
public  class EstasectServiceImpl implements EstasectService {

	private static final  Logger logger = LoggerFactory.getLogger(EstasectServiceImpl.class);
	@Autowired
	private EstasectDao estasectDao;

	/**
	 * Inserts a single row in the Estasect table.
	 *
	 * @param estasect Estasect
	 * @return Estasect
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Estasect add(Estasect estasect) {
		return this.estasectDao.add(estasect);
	}

	/**
	 * Updates a single row in the Estasect table.
	 *
	 * @param estasect Estasect
	 * @return Estasect
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Estasect update(Estasect estasect) {
		return this.estasectDao.update(estasect);
	 }

	/**
	 * Finds a single row in the Estasect table.
	 *
	 * @param estasect Estasect
	 * @return Estasect
	 */
	public Estasect find(Estasect estasect) {
		return (Estasect) this.estasectDao.find(estasect);
	}

	/**
	 * Finds a List of rows in the Estasect table.
	 *
	 * @param estasect Estasect
	 * @param pagination Pagination
	 * @return List
	 */
	public List<Estasect> findAll(Estasect estasect, Pagination pagination) {
		return (List<Estasect>) this.estasectDao.findAll(estasect, pagination);
	}
    
	/**
	 * Counts rows in the Estasect table.
	 *
	 * @param estasect Estasect
	 * @return Long
	 */
	public Long findAllCount(Estasect estasect) {        
		return  this.estasectDao.findAllCount(estasect);
	}

	/**
	 * Finds rows in the Estasect table using like.
	 *
	 * @param estasect Estasect
	 * @param pagination Pagination
	 * @param startsWith Boolean
	 * @return List
	 */
	public List<Estasect> findAllLike(Estasect estasect, Pagination pagination, Boolean startsWith) {
		return (List<Estasect>) this.estasectDao.findAllLike(estasect, pagination, startsWith);
	}
    
	/**
	 * Deletes a single row in the Estasect table.
	 *
	 * @param estasect Estasect
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Estasect estasect) {
		this.estasectDao.remove(estasect);
	}
	
	/**
	 * Deletes multiple rows in the Estasect table.
	 *
	 * @param estasectList ArrayList
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeMultiple(ArrayList<Estasect> estasectList) {
		for (Estasect  estasectAux:estasectList) {
			this.estasectDao.remove(estasectAux);
		}
	}


	/**
	 * Getter method for EstasectDao
	 *
	 * @return EstasectDao
	 */
	public EstasectDao getEstasectDao() {
		return this.estasectDao;
	}
    
	/**
	 * Setter method for EstasectDao.
	 *
	 * @param  estasectDao EstasectDao
	 * @return
	 */
	public void setEstasectDao(EstasectDao estasectDao) {
		logger.info("Setting Dependency "+estasectDao);
		this.estasectDao = estasectDao;
	}
}

