package com.ejie.y38a.service;
import com.ejie.x38.dto.Pagination;
import com.ejie.y38a.dao.LocalidaDao;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.model.Localida;

/**
 *  * LocalidaServiceImpl  
 *  
 */

@Service(value = "localidaService")
public  class LocalidaServiceImpl implements LocalidaService {

	private static final  Logger logger = LoggerFactory.getLogger(LocalidaServiceImpl.class);
	@Autowired
	private LocalidaDao localidaDao;

	/**
	 * Inserts a single row in the Localida table.
	 *
	 * @param localida Localida
	 * @return Localida
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Localida add(Localida localida) {
		return this.localidaDao.add(localida);
	}

	/**
	 * Updates a single row in the Localida table.
	 *
	 * @param localida Localida
	 * @return Localida
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Localida update(Localida localida) {
		return this.localidaDao.update(localida);
	 }

	/**
	 * Finds a single row in the Localida table.
	 *
	 * @param localida Localida
	 * @return Localida
	 */
	public Localida find(Localida localida) {
		return (Localida) this.localidaDao.find(localida);
	}

	/**
	 * Finds a List of rows in the Localida table.
	 *
	 * @param localida Localida
	 * @param pagination Pagination
	 * @return List
	 */
	public List<Localida> findAll(Localida localida, Pagination pagination) {
		return (List<Localida>) this.localidaDao.findAll(localida, pagination);
	}
    
	/**
	 * Counts rows in the Localida table.
	 *
	 * @param localida Localida
	 * @return Long
	 */
	public Long findAllCount(Localida localida) {        
		return  this.localidaDao.findAllCount(localida);
	}

	/**
	 * Finds rows in the Localida table using like.
	 *
	 * @param localida Localida
	 * @param pagination Pagination
	 * @param startsWith Boolean
	 * @return List
	 */
	public List<Localida> findAllLike(Localida localida, Pagination pagination, Boolean startsWith) {
		return (List<Localida>) this.localidaDao.findAllLike(localida, pagination, startsWith);
	}
    
	/**
	 * Deletes a single row in the Localida table.
	 *
	 * @param localida Localida
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Localida localida) {
		this.localidaDao.remove(localida);
	}
	
	/**
	 * Deletes multiple rows in the Localida table.
	 *
	 * @param localidaList ArrayList
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeMultiple(ArrayList<Localida> localidaList) {
		for (Localida  localidaAux:localidaList) {
			this.localidaDao.remove(localidaAux);
		}
	}


	/**
	 * Getter method for LocalidaDao
	 *
	 * @return LocalidaDao
	 */
	public LocalidaDao getLocalidaDao() {
		return this.localidaDao;
	}
    
	/**
	 * Setter method for LocalidaDao.
	 *
	 * @param  localidaDao LocalidaDao
	 * @return
	 */
	public void setLocalidaDao(LocalidaDao localidaDao) {
		logger.info("Setting Dependency "+localidaDao);
		this.localidaDao = localidaDao;
	}
}

