package com.ejie.y38a.service;
import com.ejie.x38.dto.Pagination;
import com.ejie.y38a.dao.MunicipiDao;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.model.Municipi;

/**
 *  * MunicipiServiceImpl  
 *  
 */

@Service(value = "municipiService")
public  class MunicipiServiceImpl implements MunicipiService {

	private static final  Logger logger = LoggerFactory.getLogger(MunicipiServiceImpl.class);
	@Autowired
	private MunicipiDao municipiDao;

	/**
	 * Inserts a single row in the Municipi table.
	 *
	 * @param municipi Municipi
	 * @return Municipi
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Municipi add(Municipi municipi) {
		return this.municipiDao.add(municipi);
	}

	/**
	 * Updates a single row in the Municipi table.
	 *
	 * @param municipi Municipi
	 * @return Municipi
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Municipi update(Municipi municipi) {
		return this.municipiDao.update(municipi);
	 }

	/**
	 * Finds a single row in the Municipi table.
	 *
	 * @param municipi Municipi
	 * @return Municipi
	 */
	public Municipi find(Municipi municipi) {
		return (Municipi) this.municipiDao.find(municipi);
	}

	/**
	 * Finds a List of rows in the Municipi table.
	 *
	 * @param municipi Municipi
	 * @param pagination Pagination
	 * @return List
	 */
	public List<Municipi> findAll(Municipi municipi, Pagination pagination) {
		return (List<Municipi>) this.municipiDao.findAll(municipi, pagination);
	}
    
	/**
	 * Counts rows in the Municipi table.
	 *
	 * @param municipi Municipi
	 * @return Long
	 */
	public Long findAllCount(Municipi municipi) {        
		return  this.municipiDao.findAllCount(municipi);
	}

	/**
	 * Finds rows in the Municipi table using like.
	 *
	 * @param municipi Municipi
	 * @param pagination Pagination
	 * @param startsWith Boolean
	 * @return List
	 */
	public List<Municipi> findAllLike(Municipi municipi, Pagination pagination, Boolean startsWith) {
		return (List<Municipi>) this.municipiDao.findAllLike(municipi, pagination, startsWith);
	}
    
	/**
	 * Deletes a single row in the Municipi table.
	 *
	 * @param municipi Municipi
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Municipi municipi) {
		this.municipiDao.remove(municipi);
	}
	
	/**
	 * Deletes multiple rows in the Municipi table.
	 *
	 * @param municipiList ArrayList
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeMultiple(ArrayList<Municipi> municipiList) {
		for (Municipi  municipiAux:municipiList) {
			this.municipiDao.remove(municipiAux);
		}
	}


	/**
	 * Getter method for MunicipiDao
	 *
	 * @return MunicipiDao
	 */
	public MunicipiDao getMunicipiDao() {
		return this.municipiDao;
	}
    
	/**
	 * Setter method for MunicipiDao.
	 *
	 * @param  municipiDao MunicipiDao
	 * @return
	 */
	public void setMunicipiDao(MunicipiDao municipiDao) {
		logger.info("Setting Dependency "+municipiDao);
		this.municipiDao = municipiDao;
	}
}

