package com.ejie.y38a.service;
import com.ejie.x38.dto.Pagination;
import com.ejie.y38a.dao.PaisestoDao;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.model.Paisesto;

/**
 *  * PaisestoServiceImpl  
 *  
 */

@Service(value = "paisestoService")
public  class PaisestoServiceImpl implements PaisestoService {

	private static final  Logger logger = LoggerFactory.getLogger(PaisestoServiceImpl.class);
	@Autowired
	private PaisestoDao paisestoDao;

	/**
	 * Inserts a single row in the Paisesto table.
	 *
	 * @param paisesto Paisesto
	 * @return Paisesto
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Paisesto add(Paisesto paisesto) {
		return this.paisestoDao.add(paisesto);
	}

	/**
	 * Updates a single row in the Paisesto table.
	 *
	 * @param paisesto Paisesto
	 * @return Paisesto
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Paisesto update(Paisesto paisesto) {
		return this.paisestoDao.update(paisesto);
	 }

	/**
	 * Finds a single row in the Paisesto table.
	 *
	 * @param paisesto Paisesto
	 * @return Paisesto
	 */
	public Paisesto find(Paisesto paisesto) {
		return (Paisesto) this.paisestoDao.find(paisesto);
	}

	/**
	 * Finds a List of rows in the Paisesto table.
	 *
	 * @param paisesto Paisesto
	 * @param pagination Pagination
	 * @return List
	 */
	public List<Paisesto> findAll(Paisesto paisesto, Pagination pagination) {
		return (List<Paisesto>) this.paisestoDao.findAll(paisesto, pagination);
	}
    
	/**
	 * Counts rows in the Paisesto table.
	 *
	 * @param paisesto Paisesto
	 * @return Long
	 */
	public Long findAllCount(Paisesto paisesto) {        
		return  this.paisestoDao.findAllCount(paisesto);
	}

	/**
	 * Finds rows in the Paisesto table using like.
	 *
	 * @param paisesto Paisesto
	 * @param pagination Pagination
	 * @param startsWith Boolean
	 * @return List
	 */
	public List<Paisesto> findAllLike(Paisesto paisesto, Pagination pagination, Boolean startsWith) {
		return (List<Paisesto>) this.paisestoDao.findAllLike(paisesto, pagination, startsWith);
	}
    
	/**
	 * Deletes a single row in the Paisesto table.
	 *
	 * @param paisesto Paisesto
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Paisesto paisesto) {
		this.paisestoDao.remove(paisesto);
	}
	
	/**
	 * Deletes multiple rows in the Paisesto table.
	 *
	 * @param paisestoList ArrayList
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeMultiple(ArrayList<Paisesto> paisestoList) {
		for (Paisesto  paisestoAux:paisestoList) {
			this.paisestoDao.remove(paisestoAux);
		}
	}


	/**
	 * Getter method for PaisestoDao
	 *
	 * @return PaisestoDao
	 */
	public PaisestoDao getPaisestoDao() {
		return this.paisestoDao;
	}
    
	/**
	 * Setter method for PaisestoDao.
	 *
	 * @param  paisestoDao PaisestoDao
	 * @return
	 */
	public void setPaisestoDao(PaisestoDao paisestoDao) {
		logger.info("Setting Dependency "+paisestoDao);
		this.paisestoDao = paisestoDao;
	}
}

