package com.ejie.y38a.service;
import com.ejie.x38.dto.Pagination;
import com.ejie.y38a.dao.ProvinciDao;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.model.Provinci;

/**
 *  * ProvinciServiceImpl  
 *  
 */

@Service(value = "provinciService")
public  class ProvinciServiceImpl implements ProvinciService {

	private static final  Logger logger = LoggerFactory.getLogger(ProvinciServiceImpl.class);
	@Autowired
	private ProvinciDao provinciDao;

	/**
	 * Inserts a single row in the Provinci table.
	 *
	 * @param provinci Provinci
	 * @return Provinci
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Provinci add(Provinci provinci) {
		return this.provinciDao.add(provinci);
	}

	/**
	 * Updates a single row in the Provinci table.
	 *
	 * @param provinci Provinci
	 * @return Provinci
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Provinci update(Provinci provinci) {
		return this.provinciDao.update(provinci);
	 }

	/**
	 * Finds a single row in the Provinci table.
	 *
	 * @param provinci Provinci
	 * @return Provinci
	 */
	public Provinci find(Provinci provinci) {
		return (Provinci) this.provinciDao.find(provinci);
	}

	/**
	 * Finds a List of rows in the Provinci table.
	 *
	 * @param provinci Provinci
	 * @param pagination Pagination
	 * @return List
	 */
	public List<Provinci> findAll(Provinci provinci, Pagination pagination) {
		return (List<Provinci>) this.provinciDao.findAll(provinci, pagination);
	}
    
	/**
	 * Counts rows in the Provinci table.
	 *
	 * @param provinci Provinci
	 * @return Long
	 */
	public Long findAllCount(Provinci provinci) {        
		return  this.provinciDao.findAllCount(provinci);
	}

	/**
	 * Finds rows in the Provinci table using like.
	 *
	 * @param provinci Provinci
	 * @param pagination Pagination
	 * @param startsWith Boolean
	 * @return List
	 */
	public List<Provinci> findAllLike(Provinci provinci, Pagination pagination, Boolean startsWith) {
		return (List<Provinci>) this.provinciDao.findAllLike(provinci, pagination, startsWith);
	}
    
	/**
	 * Deletes a single row in the Provinci table.
	 *
	 * @param provinci Provinci
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Provinci provinci) {
		this.provinciDao.remove(provinci);
	}
	
	/**
	 * Deletes multiple rows in the Provinci table.
	 *
	 * @param provinciList ArrayList
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeMultiple(ArrayList<Provinci> provinciList) {
		for (Provinci  provinciAux:provinciList) {
			this.provinciDao.remove(provinciAux);
		}
	}


	/**
	 * Getter method for ProvinciDao
	 *
	 * @return ProvinciDao
	 */
	public ProvinciDao getProvinciDao() {
		return this.provinciDao;
	}
    
	/**
	 * Setter method for ProvinciDao.
	 *
	 * @param  provinciDao ProvinciDao
	 * @return
	 */
	public void setProvinciDao(ProvinciDao provinciDao) {
		logger.info("Setting Dependency "+provinciDao);
		this.provinciDao = provinciDao;
	}
}

