package com.ejie.y38a.service;
import com.ejie.x38.dto.Pagination;
import com.ejie.y38a.dao.SecagrupDao;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.model.Secagrup;

/**
 *  * SecagrupServiceImpl  
 *  
 */

@Service(value = "secagrupService")
public  class SecagrupServiceImpl implements SecagrupService {

	private static final  Logger logger = LoggerFactory.getLogger(SecagrupServiceImpl.class);
	@Autowired
	private SecagrupDao secagrupDao;

	/**
	 * Inserts a single row in the Secagrup table.
	 *
	 * @param secagrup Secagrup
	 * @return Secagrup
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Secagrup add(Secagrup secagrup) {
		return this.secagrupDao.add(secagrup);
	}

	/**
	 * Updates a single row in the Secagrup table.
	 *
	 * @param secagrup Secagrup
	 * @return Secagrup
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Secagrup update(Secagrup secagrup) {
		return this.secagrupDao.update(secagrup);
	 }

	/**
	 * Finds a single row in the Secagrup table.
	 *
	 * @param secagrup Secagrup
	 * @return Secagrup
	 */
	public Secagrup find(Secagrup secagrup) {
		return (Secagrup) this.secagrupDao.find(secagrup);
	}

	/**
	 * Finds a List of rows in the Secagrup table.
	 *
	 * @param secagrup Secagrup
	 * @param pagination Pagination
	 * @return List
	 */
	public List<Secagrup> findAll(Secagrup secagrup, Pagination pagination) {
		return (List<Secagrup>) this.secagrupDao.findAll(secagrup, pagination);
	}
    
	/**
	 * Counts rows in the Secagrup table.
	 *
	 * @param secagrup Secagrup
	 * @return Long
	 */
	public Long findAllCount(Secagrup secagrup) {        
		return  this.secagrupDao.findAllCount(secagrup);
	}

	/**
	 * Finds rows in the Secagrup table using like.
	 *
	 * @param secagrup Secagrup
	 * @param pagination Pagination
	 * @param startsWith Boolean
	 * @return List
	 */
	public List<Secagrup> findAllLike(Secagrup secagrup, Pagination pagination, Boolean startsWith) {
		return (List<Secagrup>) this.secagrupDao.findAllLike(secagrup, pagination, startsWith);
	}
    
	/**
	 * Deletes a single row in the Secagrup table.
	 *
	 * @param secagrup Secagrup
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Secagrup secagrup) {
		this.secagrupDao.remove(secagrup);
	}
	
	/**
	 * Deletes multiple rows in the Secagrup table.
	 *
	 * @param secagrupList ArrayList
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeMultiple(ArrayList<Secagrup> secagrupList) {
		for (Secagrup  secagrupAux:secagrupList) {
			this.secagrupDao.remove(secagrupAux);
		}
	}


	/**
	 * Getter method for SecagrupDao
	 *
	 * @return SecagrupDao
	 */
	public SecagrupDao getSecagrupDao() {
		return this.secagrupDao;
	}
    
	/**
	 * Setter method for SecagrupDao.
	 *
	 * @param  secagrupDao SecagrupDao
	 * @return
	 */
	public void setSecagrupDao(SecagrupDao secagrupDao) {
		logger.info("Setting Dependency "+secagrupDao);
		this.secagrupDao = secagrupDao;
	}
}

