package com.ejie.y38a.service;
import com.ejie.x38.dto.Pagination;
import com.ejie.y38a.dao.SectoresDao;
import java.util.ArrayList;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.y38a.model.Sectores;

/**
 *  * SectoresServiceImpl  
 *  
 */

@Service(value = "sectoresService")
public  class SectoresServiceImpl implements SectoresService {

	private static final  Logger logger = LoggerFactory.getLogger(SectoresServiceImpl.class);
	@Autowired
	private SectoresDao sectoresDao;

	/**
	 * Inserts a single row in the Sectores table.
	 *
	 * @param sectores Sectores
	 * @return Sectores
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Sectores add(Sectores sectores) {
		return this.sectoresDao.add(sectores);
	}

	/**
	 * Updates a single row in the Sectores table.
	 *
	 * @param sectores Sectores
	 * @return Sectores
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Sectores update(Sectores sectores) {
		return this.sectoresDao.update(sectores);
	 }

	/**
	 * Finds a single row in the Sectores table.
	 *
	 * @param sectores Sectores
	 * @return Sectores
	 */
	public Sectores find(Sectores sectores) {
		return (Sectores) this.sectoresDao.find(sectores);
	}

	/**
	 * Finds a List of rows in the Sectores table.
	 *
	 * @param sectores Sectores
	 * @param pagination Pagination
	 * @return List
	 */
	public List<Sectores> findAll(Sectores sectores, Pagination pagination) {
		return (List<Sectores>) this.sectoresDao.findAll(sectores, pagination);
	}
    
	/**
	 * Counts rows in the Sectores table.
	 *
	 * @param sectores Sectores
	 * @return Long
	 */
	public Long findAllCount(Sectores sectores) {        
		return  this.sectoresDao.findAllCount(sectores);
	}

	/**
	 * Finds rows in the Sectores table using like.
	 *
	 * @param sectores Sectores
	 * @param pagination Pagination
	 * @param startsWith Boolean
	 * @return List
	 */
	public List<Sectores> findAllLike(Sectores sectores, Pagination pagination, Boolean startsWith) {
		return (List<Sectores>) this.sectoresDao.findAllLike(sectores, pagination, startsWith);
	}
    
	/**
	 * Deletes a single row in the Sectores table.
	 *
	 * @param sectores Sectores
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Sectores sectores) {
		this.sectoresDao.remove(sectores);
	}
	
	/**
	 * Deletes multiple rows in the Sectores table.
	 *
	 * @param sectoresList ArrayList
	 * @return
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void removeMultiple(ArrayList<Sectores> sectoresList) {
		for (Sectores  sectoresAux:sectoresList) {
			this.sectoresDao.remove(sectoresAux);
		}
	}


	/**
	 * Getter method for SectoresDao
	 *
	 * @return SectoresDao
	 */
	public SectoresDao getSectoresDao() {
		return this.sectoresDao;
	}
    
	/**
	 * Setter method for SectoresDao.
	 *
	 * @param  sectoresDao SectoresDao
	 * @return
	 */
	public void setSectoresDao(SectoresDao sectoresDao) {
		logger.info("Setting Dependency "+sectoresDao);
		this.sectoresDao = sectoresDao;
	}
}

