package com.ejie.y38a.utils;

import java.io.IOException;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.Properties;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.i18n.LocaleContextHolder;

import com.ejie.y38a.constantes.Y38aEstablecAdheConstantes;

/**
 * 
 *  
 * 
 */
public class Y38aUtils {

	/**
	 * Constructor
	 */
	private Y38aUtils() {

	}

	private static final Logger logger = LoggerFactory
			.getLogger(Y38aUtils.class);

	/**
	 * 
	 * @param string
	 *            String
	 * @return ""
	 */
	public static boolean isValid(String string) {
		return (string != null && !"".equals(string));
	}

	/**
	 * Static method to obtain properties
	 * 
	 * @param nombreFichero
	 *            String
	 * @return properties Properties
	 */
	public static Properties loadProperties(String nombreFichero) {
		Y38aUtils u = new Y38aUtils();
		return u.getProperties(nombreFichero);

	}

	/**
	 * Normaliza datos de entrada de formularios a "" - excepto combos
	 * 
	 * @param input
	 *            String
	 * @return String
	 */
	public static String normalizarVacio(String input) {

		String rt = Y38aEstablecAdheConstantes.VACIO;
		if (input != null) {
			if (!"null".equals(input)) {
				rt = input;
			}
		}

		return rt;
	}

	/**
	 * Método que carga el fichero de propiedades
	 * 
	 * @param nombreFichero
	 *            String
	 * @return Properties
	 */
	public Properties getProperties(String nombreFichero) {
		Properties pLog = new Properties();
		InputStream configLog = null;
		try {
			String propertiesLog = nombreFichero;
			configLog = this.getClass().getResourceAsStream(propertiesLog);
			pLog.load(configLog);
			configLog.close();
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				configLog.close();
			} catch (IOException e1) {
				e1.printStackTrace();
			}
		}

		return pLog;
	}

	/**
	 * Monta una cadena SQL que transforma el texto a mayusculas y quita las
	 * tildes
	 * 
	 * @param nombrecampo
	 *            nombre del campo de la tabla que se desea transformar
	 * @return StringBuffer Devuelve la cadena SQL resultante de las
	 *         transformaciones.
	 */
	public static String devuelveMayusculasSinAcentos(String nombrecampo) {
		StringBuffer cadena = new StringBuffer(
				Y38aEstablecAdheConstantes.NUM_3000);
		if (Y38aUtils.isFilled(nombrecampo)) {
			cadena.append(" TRANSLATE(TRIM(UPPER(").append(nombrecampo)
					.append(")),'ÁÉÍÓÚÀÈÌÒÙÜ','AEIOUAEIOUU') ");
		}
		return cadena.toString();
	}

	/**
	 * Devuelve true si el string vienen informado y false si el string es nulo
	 * o vacio
	 * 
	 * @param stringIn
	 *            Dato a evaluar
	 * @return boolean true o false
	 */
	public static boolean isFilled(String stringIn) {
		if (stringIn == null || stringIn.equals("")) {
			return false;
		}
		return true;
	}

	/**
	 * Convierte a UTF8
	 * 
	 * @param label
	 *            String
	 * @return temp
	 */
	public static String convertToUTF8(String label) {
		String temp = "";

		try {
			temp = new String(label.getBytes("ISO-8859-1"), "UTF8");
		} catch (UnsupportedEncodingException e) {
			e.printStackTrace();
		}

		return temp;
	}

	/**
	 * Convierte de UTF8 a ISO
	 * 
	 * @param label
	 *            String
	 * @return temp
	 */
	public static String convertToISO(String label) {
		String temp = "";
		if (label == null) {
			return "";
		}
		try {

			// temp = new String(label.getBytes("UTF-8"), "windows-1251");
			temp = new String(label.getBytes("UTF-8"), "ISO-8859-1");
			// temp = new String(label.getBytes(), "ISO-8859-1");
		} catch (UnsupportedEncodingException e) {
			Y38aUtils.logger.error(e.getMessage());
		}

		return temp;
	}

	/**
	 * Parsea un string de fecha con el formato correspondiente al idioma del
	 * locale y devuelve la fecha. Recibe un tipo date
	 * 
	 * @param date
	 *            (Date)
	 * @param locale
	 *            Locale
	 * @return Date
	 * @throws Exception
	 *             Exception
	 */
	public static Date parseDate(Date date, Locale locale) throws Exception {
		if (date != null) {
			SimpleDateFormat formatter = null;
			if (Y38aEstablecAdheConstantes.CASTELLANO.equals(locale
					.getLanguage())) {
				formatter = new SimpleDateFormat("dd/MM/yyyy");
			} else if (Y38aEstablecAdheConstantes.EUSKERA.equals(locale
					.getLanguage())) {
				formatter = new SimpleDateFormat("yyyy/MM/dd");
			} else {
				throw new Exception(
						"Language date parse support not implemented for this language.");
			}
			return formatter.parse(formatter.format(date));

		}
		return null;
	}

	/**
	 * Transforma una fecha String a java.sql.Date.
	 * 
	 * @param fecha
	 *            String con la fecha a convertir
	 * @return java.sql.Date fecha convertida
	 */
	public static java.sql.Date formatearStringToDateFormato(String fecha) {

		if (fecha == null || "".equals(fecha)) {
			return null;
		}

		String formato = "";
		Locale locale = LocaleContextHolder.getLocale();
		if (Y38aEstablecAdheConstantes.EUSKERA.equals(locale.getLanguage())) {
			formato = Y38aEstablecAdheConstantes.FORMATO_FECHA_EU;
		} else {
			formato = Y38aEstablecAdheConstantes.FORMATO_FECHA_ES;
		}
		SimpleDateFormat formatoDelTexto = new SimpleDateFormat(formato);
		java.sql.Date dFecha = null;
		try {
			dFecha = new java.sql.Date(formatoDelTexto.parse(fecha).getTime());
		} catch (ParseException e) {
			dFecha = null;
		}

		return dFecha;
	}

	/**
	 * 
	 * @param fecha
	 * @param lang
	 * @return
	 */
	public static String parseDateToString(Date fecha, String lang) {
		String fechaFormateada = "";
		DecimalFormat df = new DecimalFormat("00");

		if (fecha != null) {
			Calendar calendar = Calendar.getInstance();
			calendar.setTime(fecha);

			int dia = calendar.get(Calendar.DAY_OF_MONTH); // dia del mes
			int mes = calendar.get(Calendar.MONTH) + 1; // mes, de 0 a 11
			int anio = calendar.get(Calendar.YEAR); // año

			if (Y38aEstablecAdheConstantes.EUSKERA.equals(lang)) {
				fechaFormateada = anio + "/" + df.format(mes) + "/"
						+ df.format(dia);
			} else {
				fechaFormateada = df.format(dia) + "/" + df.format(mes) + "/"
						+ anio;
			}
		}
		return fechaFormateada;
	}

}
